(function(){const yl=document.createElement("link").relList;if(yl&&yl.supports&&yl.supports("modulepreload"))return;for(const j of document.querySelectorAll('link[rel="modulepreload"]'))o(j);new MutationObserver(j=>{for(const w of j)if(w.type==="childList")for(const ml of w.addedNodes)ml.tagName==="LINK"&&ml.rel==="modulepreload"&&o(ml)}).observe(document,{childList:!0,subtree:!0});function W(j){const w={};return j.integrity&&(w.integrity=j.integrity),j.referrerPolicy&&(w.referrerPolicy=j.referrerPolicy),j.crossOrigin==="use-credentials"?w.credentials="include":j.crossOrigin==="anonymous"?w.credentials="omit":w.credentials="same-origin",w}function o(j){if(j.ep)return;j.ep=!0;const w=W(j);fetch(j.href,w)}})();var ni={exports:{}},ze={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var dv;function Jm(){if(dv)return ze;dv=1;var M=Symbol.for("react.transitional.element"),yl=Symbol.for("react.fragment");function W(o,j,w){var ml=null;if(w!==void 0&&(ml=""+w),j.key!==void 0&&(ml=""+j.key),"key"in j){w={};for(var Ol in j)Ol!=="key"&&(w[Ol]=j[Ol])}else w=j;return j=w.ref,{$$typeof:M,type:o,key:ml,ref:j!==void 0?j:null,props:w}}return ze.Fragment=yl,ze.jsx=W,ze.jsxs=W,ze}var hv;function wm(){return hv||(hv=1,ni.exports=Jm()),ni.exports}var J=wm(),fi={exports:{}},C={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var ov;function Wm(){if(ov)return C;ov=1;var M=Symbol.for("react.transitional.element"),yl=Symbol.for("react.portal"),W=Symbol.for("react.fragment"),o=Symbol.for("react.strict_mode"),j=Symbol.for("react.profiler"),w=Symbol.for("react.consumer"),ml=Symbol.for("react.context"),Ol=Symbol.for("react.forward_ref"),p=Symbol.for("react.suspense"),E=Symbol.for("react.memo"),$=Symbol.for("react.lazy"),R=Symbol.for("react.activity"),il=Symbol.iterator;function Ml(v){return v===null||typeof v!="object"?null:(v=il&&v[il]||v["@@iterator"],typeof v=="function"?v:null)}var Hl={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},Dl=Object.assign,hl={};function Ul(v,T,_){this.props=v,this.context=T,this.refs=hl,this.updater=_||Hl}Ul.prototype.isReactComponent={},Ul.prototype.setState=function(v,T){if(typeof v!="object"&&typeof v!="function"&&v!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,v,T,"setState")},Ul.prototype.forceUpdate=function(v){this.updater.enqueueForceUpdate(this,v,"forceUpdate")};function Et(){}Et.prototype=Ul.prototype;function jl(v,T,_){this.props=v,this.context=T,this.refs=hl,this.updater=_||Hl}var ct=jl.prototype=new Et;ct.constructor=jl,Dl(ct,Ul.prototype),ct.isPureReactComponent=!0;var At=Array.isArray;function Ql(){}var L={H:null,A:null,T:null,S:null},Zl=Object.prototype.hasOwnProperty;function _t(v,T,_){var D=_.ref;return{$$typeof:M,type:v,key:T,ref:D!==void 0?D:null,props:_}}function Qu(v,T){return _t(v.type,T,v.props)}function Ot(v){return typeof v=="object"&&v!==null&&v.$$typeof===M}function Vl(v){var T={"=":"=0",":":"=2"};return"$"+v.replace(/[=:]/g,function(_){return T[_]})}var Tu=/\/+/g;function Nt(v,T){return typeof v=="object"&&v!==null&&v.key!=null?Vl(""+v.key):T.toString(36)}function bt(v){switch(v.status){case"fulfilled":return v.value;case"rejected":throw v.reason;default:switch(typeof v.status=="string"?v.then(Ql,Ql):(v.status="pending",v.then(function(T){v.status==="pending"&&(v.status="fulfilled",v.value=T)},function(T){v.status==="pending"&&(v.status="rejected",v.reason=T)})),v.status){case"fulfilled":return v.value;case"rejected":throw v.reason}}throw v}function b(v,T,_,D,B){var x=typeof v;(x==="undefined"||x==="boolean")&&(v=null);var P=!1;if(v===null)P=!0;else switch(x){case"bigint":case"string":case"number":P=!0;break;case"object":switch(v.$$typeof){case M:case yl:P=!0;break;case $:return P=v._init,b(P(v._payload),T,_,D,B)}}if(P)return B=B(v),P=D===""?"."+Nt(v,0):D,At(B)?(_="",P!=null&&(_=P.replace(Tu,"$&/")+"/"),b(B,T,_,"",function(Ma){return Ma})):B!=null&&(Ot(B)&&(B=Qu(B,_+(B.key==null||v&&v.key===B.key?"":(""+B.key).replace(Tu,"$&/")+"/")+P)),T.push(B)),1;P=0;var xl=D===""?".":D+":";if(At(v))for(var Sl=0;Sl<v.length;Sl++)D=v[Sl],x=xl+Nt(D,Sl),P+=b(D,T,_,x,B);else if(Sl=Ml(v),typeof Sl=="function")for(v=Sl.call(v),Sl=0;!(D=v.next()).done;)D=D.value,x=xl+Nt(D,Sl++),P+=b(D,T,_,x,B);else if(x==="object"){if(typeof v.then=="function")return b(bt(v),T,_,D,B);throw T=String(v),Error("Objects are not valid as a React child (found: "+(T==="[object Object]"?"object with keys {"+Object.keys(v).join(", ")+"}":T)+"). If you meant to render a collection of children, use an array instead.")}return P}function A(v,T,_){if(v==null)return v;var D=[],B=0;return b(v,D,"","",function(x){return T.call(_,x,B++)}),D}function q(v){if(v._status===-1){var T=v._result;T=T(),T.then(function(_){(v._status===0||v._status===-1)&&(v._status=1,v._result=_)},function(_){(v._status===0||v._status===-1)&&(v._status=2,v._result=_)}),v._status===-1&&(v._status=0,v._result=T)}if(v._status===1)return v._result.default;throw v._result}var ul=typeof reportError=="function"?reportError:function(v){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var T=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof v=="object"&&v!==null&&typeof v.message=="string"?String(v.message):String(v),error:v});if(!window.dispatchEvent(T))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",v);return}console.error(v)},fl={map:A,forEach:function(v,T,_){A(v,function(){T.apply(this,arguments)},_)},count:function(v){var T=0;return A(v,function(){T++}),T},toArray:function(v){return A(v,function(T){return T})||[]},only:function(v){if(!Ot(v))throw Error("React.Children.only expected to receive a single React element child.");return v}};return C.Activity=R,C.Children=fl,C.Component=Ul,C.Fragment=W,C.Profiler=j,C.PureComponent=jl,C.StrictMode=o,C.Suspense=p,C.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=L,C.__COMPILER_RUNTIME={__proto__:null,c:function(v){return L.H.useMemoCache(v)}},C.cache=function(v){return function(){return v.apply(null,arguments)}},C.cacheSignal=function(){return null},C.cloneElement=function(v,T,_){if(v==null)throw Error("The argument must be a React element, but you passed "+v+".");var D=Dl({},v.props),B=v.key;if(T!=null)for(x in T.key!==void 0&&(B=""+T.key),T)!Zl.call(T,x)||x==="key"||x==="__self"||x==="__source"||x==="ref"&&T.ref===void 0||(D[x]=T[x]);var x=arguments.length-2;if(x===1)D.children=_;else if(1<x){for(var P=Array(x),xl=0;xl<x;xl++)P[xl]=arguments[xl+2];D.children=P}return _t(v.type,B,D)},C.createContext=function(v){return v={$$typeof:ml,_currentValue:v,_currentValue2:v,_threadCount:0,Provider:null,Consumer:null},v.Provider=v,v.Consumer={$$typeof:w,_context:v},v},C.createElement=function(v,T,_){var D,B={},x=null;if(T!=null)for(D in T.key!==void 0&&(x=""+T.key),T)Zl.call(T,D)&&D!=="key"&&D!=="__self"&&D!=="__source"&&(B[D]=T[D]);var P=arguments.length-2;if(P===1)B.children=_;else if(1<P){for(var xl=Array(P),Sl=0;Sl<P;Sl++)xl[Sl]=arguments[Sl+2];B.children=xl}if(v&&v.defaultProps)for(D in P=v.defaultProps,P)B[D]===void 0&&(B[D]=P[D]);return _t(v,x,B)},C.createRef=function(){return{current:null}},C.forwardRef=function(v){return{$$typeof:Ol,render:v}},C.isValidElement=Ot,C.lazy=function(v){return{$$typeof:$,_payload:{_status:-1,_result:v},_init:q}},C.memo=function(v,T){return{$$typeof:E,type:v,compare:T===void 0?null:T}},C.startTransition=function(v){var T=L.T,_={};L.T=_;try{var D=v(),B=L.S;B!==null&&B(_,D),typeof D=="object"&&D!==null&&typeof D.then=="function"&&D.then(Ql,ul)}catch(x){ul(x)}finally{T!==null&&_.types!==null&&(T.types=_.types),L.T=T}},C.unstable_useCacheRefresh=function(){return L.H.useCacheRefresh()},C.use=function(v){return L.H.use(v)},C.useActionState=function(v,T,_){return L.H.useActionState(v,T,_)},C.useCallback=function(v,T){return L.H.useCallback(v,T)},C.useContext=function(v){return L.H.useContext(v)},C.useDebugValue=function(){},C.useDeferredValue=function(v,T){return L.H.useDeferredValue(v,T)},C.useEffect=function(v,T){return L.H.useEffect(v,T)},C.useEffectEvent=function(v){return L.H.useEffectEvent(v)},C.useId=function(){return L.H.useId()},C.useImperativeHandle=function(v,T,_){return L.H.useImperativeHandle(v,T,_)},C.useInsertionEffect=function(v,T){return L.H.useInsertionEffect(v,T)},C.useLayoutEffect=function(v,T){return L.H.useLayoutEffect(v,T)},C.useMemo=function(v,T){return L.H.useMemo(v,T)},C.useOptimistic=function(v,T){return L.H.useOptimistic(v,T)},C.useReducer=function(v,T,_){return L.H.useReducer(v,T,_)},C.useRef=function(v){return L.H.useRef(v)},C.useState=function(v){return L.H.useState(v)},C.useSyncExternalStore=function(v,T,_){return L.H.useSyncExternalStore(v,T,_)},C.useTransition=function(){return L.H.useTransition()},C.version="19.2.0",C}var gv;function yi(){return gv||(gv=1,fi.exports=Wm()),fi.exports}var ru=yi(),ci={exports:{}},re={},ii={exports:{}},si={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Sv;function $m(){return Sv||(Sv=1,(function(M){function yl(b,A){var q=b.length;b.push(A);l:for(;0<q;){var ul=q-1>>>1,fl=b[ul];if(0<j(fl,A))b[ul]=A,b[q]=fl,q=ul;else break l}}function W(b){return b.length===0?null:b[0]}function o(b){if(b.length===0)return null;var A=b[0],q=b.pop();if(q!==A){b[0]=q;l:for(var ul=0,fl=b.length,v=fl>>>1;ul<v;){var T=2*(ul+1)-1,_=b[T],D=T+1,B=b[D];if(0>j(_,q))D<fl&&0>j(B,_)?(b[ul]=B,b[D]=q,ul=D):(b[ul]=_,b[T]=q,ul=T);else if(D<fl&&0>j(B,q))b[ul]=B,b[D]=q,ul=D;else break l}}return A}function j(b,A){var q=b.sortIndex-A.sortIndex;return q!==0?q:b.id-A.id}if(M.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var w=performance;M.unstable_now=function(){return w.now()}}else{var ml=Date,Ol=ml.now();M.unstable_now=function(){return ml.now()-Ol}}var p=[],E=[],$=1,R=null,il=3,Ml=!1,Hl=!1,Dl=!1,hl=!1,Ul=typeof setTimeout=="function"?setTimeout:null,Et=typeof clearTimeout=="function"?clearTimeout:null,jl=typeof setImmediate<"u"?setImmediate:null;function ct(b){for(var A=W(E);A!==null;){if(A.callback===null)o(E);else if(A.startTime<=b)o(E),A.sortIndex=A.expirationTime,yl(p,A);else break;A=W(E)}}function At(b){if(Dl=!1,ct(b),!Hl)if(W(p)!==null)Hl=!0,Ql||(Ql=!0,Vl());else{var A=W(E);A!==null&&bt(At,A.startTime-b)}}var Ql=!1,L=-1,Zl=5,_t=-1;function Qu(){return hl?!0:!(M.unstable_now()-_t<Zl)}function Ot(){if(hl=!1,Ql){var b=M.unstable_now();_t=b;var A=!0;try{l:{Hl=!1,Dl&&(Dl=!1,Et(L),L=-1),Ml=!0;var q=il;try{t:{for(ct(b),R=W(p);R!==null&&!(R.expirationTime>b&&Qu());){var ul=R.callback;if(typeof ul=="function"){R.callback=null,il=R.priorityLevel;var fl=ul(R.expirationTime<=b);if(b=M.unstable_now(),typeof fl=="function"){R.callback=fl,ct(b),A=!0;break t}R===W(p)&&o(p),ct(b)}else o(p);R=W(p)}if(R!==null)A=!0;else{var v=W(E);v!==null&&bt(At,v.startTime-b),A=!1}}break l}finally{R=null,il=q,Ml=!1}A=void 0}}finally{A?Vl():Ql=!1}}}var Vl;if(typeof jl=="function")Vl=function(){jl(Ot)};else if(typeof MessageChannel<"u"){var Tu=new MessageChannel,Nt=Tu.port2;Tu.port1.onmessage=Ot,Vl=function(){Nt.postMessage(null)}}else Vl=function(){Ul(Ot,0)};function bt(b,A){L=Ul(function(){b(M.unstable_now())},A)}M.unstable_IdlePriority=5,M.unstable_ImmediatePriority=1,M.unstable_LowPriority=4,M.unstable_NormalPriority=3,M.unstable_Profiling=null,M.unstable_UserBlockingPriority=2,M.unstable_cancelCallback=function(b){b.callback=null},M.unstable_forceFrameRate=function(b){0>b||125<b?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):Zl=0<b?Math.floor(1e3/b):5},M.unstable_getCurrentPriorityLevel=function(){return il},M.unstable_next=function(b){switch(il){case 1:case 2:case 3:var A=3;break;default:A=il}var q=il;il=A;try{return b()}finally{il=q}},M.unstable_requestPaint=function(){hl=!0},M.unstable_runWithPriority=function(b,A){switch(b){case 1:case 2:case 3:case 4:case 5:break;default:b=3}var q=il;il=b;try{return A()}finally{il=q}},M.unstable_scheduleCallback=function(b,A,q){var ul=M.unstable_now();switch(typeof q=="object"&&q!==null?(q=q.delay,q=typeof q=="number"&&0<q?ul+q:ul):q=ul,b){case 1:var fl=-1;break;case 2:fl=250;break;case 5:fl=1073741823;break;case 4:fl=1e4;break;default:fl=5e3}return fl=q+fl,b={id:$++,callback:A,priorityLevel:b,startTime:q,expirationTime:fl,sortIndex:-1},q>ul?(b.sortIndex=q,yl(E,b),W(p)===null&&b===W(E)&&(Dl?(Et(L),L=-1):Dl=!0,bt(At,q-ul))):(b.sortIndex=fl,yl(p,b),Hl||Ml||(Hl=!0,Ql||(Ql=!0,Vl()))),b},M.unstable_shouldYield=Qu,M.unstable_wrapCallback=function(b){var A=il;return function(){var q=il;il=A;try{return b.apply(this,arguments)}finally{il=q}}}})(si)),si}var bv;function Fm(){return bv||(bv=1,ii.exports=$m()),ii.exports}var vi={exports:{}},Gl={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var zv;function km(){if(zv)return Gl;zv=1;var M=yi();function yl(p){var E="https://react.dev/errors/"+p;if(1<arguments.length){E+="?args[]="+encodeURIComponent(arguments[1]);for(var $=2;$<arguments.length;$++)E+="&args[]="+encodeURIComponent(arguments[$])}return"Minified React error #"+p+"; visit "+E+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function W(){}var o={d:{f:W,r:function(){throw Error(yl(522))},D:W,C:W,L:W,m:W,X:W,S:W,M:W},p:0,findDOMNode:null},j=Symbol.for("react.portal");function w(p,E,$){var R=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:j,key:R==null?null:""+R,children:p,containerInfo:E,implementation:$}}var ml=M.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function Ol(p,E){if(p==="font")return"";if(typeof E=="string")return E==="use-credentials"?E:""}return Gl.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=o,Gl.createPortal=function(p,E){var $=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!E||E.nodeType!==1&&E.nodeType!==9&&E.nodeType!==11)throw Error(yl(299));return w(p,E,null,$)},Gl.flushSync=function(p){var E=ml.T,$=o.p;try{if(ml.T=null,o.p=2,p)return p()}finally{ml.T=E,o.p=$,o.d.f()}},Gl.preconnect=function(p,E){typeof p=="string"&&(E?(E=E.crossOrigin,E=typeof E=="string"?E==="use-credentials"?E:"":void 0):E=null,o.d.C(p,E))},Gl.prefetchDNS=function(p){typeof p=="string"&&o.d.D(p)},Gl.preinit=function(p,E){if(typeof p=="string"&&E&&typeof E.as=="string"){var $=E.as,R=Ol($,E.crossOrigin),il=typeof E.integrity=="string"?E.integrity:void 0,Ml=typeof E.fetchPriority=="string"?E.fetchPriority:void 0;$==="style"?o.d.S(p,typeof E.precedence=="string"?E.precedence:void 0,{crossOrigin:R,integrity:il,fetchPriority:Ml}):$==="script"&&o.d.X(p,{crossOrigin:R,integrity:il,fetchPriority:Ml,nonce:typeof E.nonce=="string"?E.nonce:void 0})}},Gl.preinitModule=function(p,E){if(typeof p=="string")if(typeof E=="object"&&E!==null){if(E.as==null||E.as==="script"){var $=Ol(E.as,E.crossOrigin);o.d.M(p,{crossOrigin:$,integrity:typeof E.integrity=="string"?E.integrity:void 0,nonce:typeof E.nonce=="string"?E.nonce:void 0})}}else E==null&&o.d.M(p)},Gl.preload=function(p,E){if(typeof p=="string"&&typeof E=="object"&&E!==null&&typeof E.as=="string"){var $=E.as,R=Ol($,E.crossOrigin);o.d.L(p,$,{crossOrigin:R,integrity:typeof E.integrity=="string"?E.integrity:void 0,nonce:typeof E.nonce=="string"?E.nonce:void 0,type:typeof E.type=="string"?E.type:void 0,fetchPriority:typeof E.fetchPriority=="string"?E.fetchPriority:void 0,referrerPolicy:typeof E.referrerPolicy=="string"?E.referrerPolicy:void 0,imageSrcSet:typeof E.imageSrcSet=="string"?E.imageSrcSet:void 0,imageSizes:typeof E.imageSizes=="string"?E.imageSizes:void 0,media:typeof E.media=="string"?E.media:void 0})}},Gl.preloadModule=function(p,E){if(typeof p=="string")if(E){var $=Ol(E.as,E.crossOrigin);o.d.m(p,{as:typeof E.as=="string"&&E.as!=="script"?E.as:void 0,crossOrigin:$,integrity:typeof E.integrity=="string"?E.integrity:void 0})}else o.d.m(p)},Gl.requestFormReset=function(p){o.d.r(p)},Gl.unstable_batchedUpdates=function(p,E){return p(E)},Gl.useFormState=function(p,E,$){return ml.H.useFormState(p,E,$)},Gl.useFormStatus=function(){return ml.H.useHostTransitionStatus()},Gl.version="19.2.0",Gl}var rv;function Im(){if(rv)return vi.exports;rv=1;function M(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(M)}catch(yl){console.error(yl)}}return M(),vi.exports=km(),vi.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Tv;function Pm(){if(Tv)return re;Tv=1;var M=Fm(),yl=yi(),W=Im();function o(l){var t="https://react.dev/errors/"+l;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var u=2;u<arguments.length;u++)t+="&args[]="+encodeURIComponent(arguments[u])}return"Minified React error #"+l+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function j(l){return!(!l||l.nodeType!==1&&l.nodeType!==9&&l.nodeType!==11)}function w(l){var t=l,u=l;if(l.alternate)for(;t.return;)t=t.return;else{l=t;do t=l,(t.flags&4098)!==0&&(u=t.return),l=t.return;while(l)}return t.tag===3?u:null}function ml(l){if(l.tag===13){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function Ol(l){if(l.tag===31){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function p(l){if(w(l)!==l)throw Error(o(188))}function E(l){var t=l.alternate;if(!t){if(t=w(l),t===null)throw Error(o(188));return t!==l?null:l}for(var u=l,a=t;;){var e=u.return;if(e===null)break;var n=e.alternate;if(n===null){if(a=e.return,a!==null){u=a;continue}break}if(e.child===n.child){for(n=e.child;n;){if(n===u)return p(e),l;if(n===a)return p(e),t;n=n.sibling}throw Error(o(188))}if(u.return!==a.return)u=e,a=n;else{for(var f=!1,c=e.child;c;){if(c===u){f=!0,u=e,a=n;break}if(c===a){f=!0,a=e,u=n;break}c=c.sibling}if(!f){for(c=n.child;c;){if(c===u){f=!0,u=n,a=e;break}if(c===a){f=!0,a=n,u=e;break}c=c.sibling}if(!f)throw Error(o(189))}}if(u.alternate!==a)throw Error(o(190))}if(u.tag!==3)throw Error(o(188));return u.stateNode.current===u?l:t}function $(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l;for(l=l.child;l!==null;){if(t=$(l),t!==null)return t;l=l.sibling}return null}var R=Object.assign,il=Symbol.for("react.element"),Ml=Symbol.for("react.transitional.element"),Hl=Symbol.for("react.portal"),Dl=Symbol.for("react.fragment"),hl=Symbol.for("react.strict_mode"),Ul=Symbol.for("react.profiler"),Et=Symbol.for("react.consumer"),jl=Symbol.for("react.context"),ct=Symbol.for("react.forward_ref"),At=Symbol.for("react.suspense"),Ql=Symbol.for("react.suspense_list"),L=Symbol.for("react.memo"),Zl=Symbol.for("react.lazy"),_t=Symbol.for("react.activity"),Qu=Symbol.for("react.memo_cache_sentinel"),Ot=Symbol.iterator;function Vl(l){return l===null||typeof l!="object"?null:(l=Ot&&l[Ot]||l["@@iterator"],typeof l=="function"?l:null)}var Tu=Symbol.for("react.client.reference");function Nt(l){if(l==null)return null;if(typeof l=="function")return l.$$typeof===Tu?null:l.displayName||l.name||null;if(typeof l=="string")return l;switch(l){case Dl:return"Fragment";case Ul:return"Profiler";case hl:return"StrictMode";case At:return"Suspense";case Ql:return"SuspenseList";case _t:return"Activity"}if(typeof l=="object")switch(l.$$typeof){case Hl:return"Portal";case jl:return l.displayName||"Context";case Et:return(l._context.displayName||"Context")+".Consumer";case ct:var t=l.render;return l=l.displayName,l||(l=t.displayName||t.name||"",l=l!==""?"ForwardRef("+l+")":"ForwardRef"),l;case L:return t=l.displayName||null,t!==null?t:Nt(l.type)||"Memo";case Zl:t=l._payload,l=l._init;try{return Nt(l(t))}catch{}}return null}var bt=Array.isArray,b=yl.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,A=W.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,q={pending:!1,data:null,method:null,action:null},ul=[],fl=-1;function v(l){return{current:l}}function T(l){0>fl||(l.current=ul[fl],ul[fl]=null,fl--)}function _(l,t){fl++,ul[fl]=l.current,l.current=t}var D=v(null),B=v(null),x=v(null),P=v(null);function xl(l,t){switch(_(x,t),_(B,l),_(D,null),t.nodeType){case 9:case 11:l=(l=t.documentElement)&&(l=l.namespaceURI)?Ys(l):0;break;default:if(l=t.tagName,t=t.namespaceURI)t=Ys(t),l=js(t,l);else switch(l){case"svg":l=1;break;case"math":l=2;break;default:l=0}}T(D),_(D,l)}function Sl(){T(D),T(B),T(x)}function Ma(l){l.memoizedState!==null&&_(P,l);var t=D.current,u=js(t,l.type);t!==u&&(_(B,l),_(D,u))}function Te(l){B.current===l&&(T(D),T(B)),P.current===l&&(T(P),oe._currentValue=q)}var Xn,mi;function Eu(l){if(Xn===void 0)try{throw Error()}catch(u){var t=u.stack.trim().match(/\n( *(at )?)/);Xn=t&&t[1]||"",mi=-1<u.stack.indexOf(`
    at`)?" (<anonymous>)":-1<u.stack.indexOf("@")?"@unknown:0:0":""}return`
`+Xn+l+mi}var Qn=!1;function Zn(l,t){if(!l||Qn)return"";Qn=!0;var u=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var a={DetermineComponentFrameRoot:function(){try{if(t){var r=function(){throw Error()};if(Object.defineProperty(r.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(r,[])}catch(g){var h=g}Reflect.construct(l,[],r)}else{try{r.call()}catch(g){h=g}l.call(r.prototype)}}else{try{throw Error()}catch(g){h=g}(r=l())&&typeof r.catch=="function"&&r.catch(function(){})}}catch(g){if(g&&h&&typeof g.stack=="string")return[g.stack,h.stack]}return[null,null]}};a.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var e=Object.getOwnPropertyDescriptor(a.DetermineComponentFrameRoot,"name");e&&e.configurable&&Object.defineProperty(a.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var n=a.DetermineComponentFrameRoot(),f=n[0],c=n[1];if(f&&c){var i=f.split(`
`),d=c.split(`
`);for(e=a=0;a<i.length&&!i[a].includes("DetermineComponentFrameRoot");)a++;for(;e<d.length&&!d[e].includes("DetermineComponentFrameRoot");)e++;if(a===i.length||e===d.length)for(a=i.length-1,e=d.length-1;1<=a&&0<=e&&i[a]!==d[e];)e--;for(;1<=a&&0<=e;a--,e--)if(i[a]!==d[e]){if(a!==1||e!==1)do if(a--,e--,0>e||i[a]!==d[e]){var S=`
`+i[a].replace(" at new "," at ");return l.displayName&&S.includes("<anonymous>")&&(S=S.replace("<anonymous>",l.displayName)),S}while(1<=a&&0<=e);break}}}finally{Qn=!1,Error.prepareStackTrace=u}return(u=l?l.displayName||l.name:"")?Eu(u):""}function Av(l,t){switch(l.tag){case 26:case 27:case 5:return Eu(l.type);case 16:return Eu("Lazy");case 13:return l.child!==t&&t!==null?Eu("Suspense Fallback"):Eu("Suspense");case 19:return Eu("SuspenseList");case 0:case 15:return Zn(l.type,!1);case 11:return Zn(l.type.render,!1);case 1:return Zn(l.type,!0);case 31:return Eu("Activity");default:return""}}function di(l){try{var t="",u=null;do t+=Av(l,u),u=l,l=l.return;while(l);return t}catch(a){return`
Error generating stack: `+a.message+`
`+a.stack}}var Vn=Object.prototype.hasOwnProperty,Ln=M.unstable_scheduleCallback,Kn=M.unstable_cancelCallback,_v=M.unstable_shouldYield,Ov=M.unstable_requestPaint,kl=M.unstable_now,Mv=M.unstable_getCurrentPriorityLevel,hi=M.unstable_ImmediatePriority,oi=M.unstable_UserBlockingPriority,Ee=M.unstable_NormalPriority,Dv=M.unstable_LowPriority,gi=M.unstable_IdlePriority,Uv=M.log,pv=M.unstable_setDisableYieldValue,Da=null,Il=null;function $t(l){if(typeof Uv=="function"&&pv(l),Il&&typeof Il.setStrictMode=="function")try{Il.setStrictMode(Da,l)}catch{}}var Pl=Math.clz32?Math.clz32:Rv,Nv=Math.log,Hv=Math.LN2;function Rv(l){return l>>>=0,l===0?32:31-(Nv(l)/Hv|0)|0}var Ae=256,_e=262144,Oe=4194304;function Au(l){var t=l&42;if(t!==0)return t;switch(l&-l){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return l&261888;case 262144:case 524288:case 1048576:case 2097152:return l&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return l&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return l}}function Me(l,t,u){var a=l.pendingLanes;if(a===0)return 0;var e=0,n=l.suspendedLanes,f=l.pingedLanes;l=l.warmLanes;var c=a&134217727;return c!==0?(a=c&~n,a!==0?e=Au(a):(f&=c,f!==0?e=Au(f):u||(u=c&~l,u!==0&&(e=Au(u))))):(c=a&~n,c!==0?e=Au(c):f!==0?e=Au(f):u||(u=a&~l,u!==0&&(e=Au(u)))),e===0?0:t!==0&&t!==e&&(t&n)===0&&(n=e&-e,u=t&-t,n>=u||n===32&&(u&4194048)!==0)?t:e}function Ua(l,t){return(l.pendingLanes&~(l.suspendedLanes&~l.pingedLanes)&t)===0}function qv(l,t){switch(l){case 1:case 2:case 4:case 8:case 64:return t+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function Si(){var l=Oe;return Oe<<=1,(Oe&62914560)===0&&(Oe=4194304),l}function Jn(l){for(var t=[],u=0;31>u;u++)t.push(l);return t}function pa(l,t){l.pendingLanes|=t,t!==268435456&&(l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0)}function Cv(l,t,u,a,e,n){var f=l.pendingLanes;l.pendingLanes=u,l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0,l.expiredLanes&=u,l.entangledLanes&=u,l.errorRecoveryDisabledLanes&=u,l.shellSuspendCounter=0;var c=l.entanglements,i=l.expirationTimes,d=l.hiddenUpdates;for(u=f&~u;0<u;){var S=31-Pl(u),r=1<<S;c[S]=0,i[S]=-1;var h=d[S];if(h!==null)for(d[S]=null,S=0;S<h.length;S++){var g=h[S];g!==null&&(g.lane&=-536870913)}u&=~r}a!==0&&bi(l,a,0),n!==0&&e===0&&l.tag!==0&&(l.suspendedLanes|=n&~(f&~t))}function bi(l,t,u){l.pendingLanes|=t,l.suspendedLanes&=~t;var a=31-Pl(t);l.entangledLanes|=t,l.entanglements[a]=l.entanglements[a]|1073741824|u&261930}function zi(l,t){var u=l.entangledLanes|=t;for(l=l.entanglements;u;){var a=31-Pl(u),e=1<<a;e&t|l[a]&t&&(l[a]|=t),u&=~e}}function ri(l,t){var u=t&-t;return u=(u&42)!==0?1:wn(u),(u&(l.suspendedLanes|t))!==0?0:u}function wn(l){switch(l){case 2:l=1;break;case 8:l=4;break;case 32:l=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:l=128;break;case 268435456:l=134217728;break;default:l=0}return l}function Wn(l){return l&=-l,2<l?8<l?(l&134217727)!==0?32:268435456:8:2}function Ti(){var l=A.p;return l!==0?l:(l=window.event,l===void 0?32:fv(l.type))}function Ei(l,t){var u=A.p;try{return A.p=l,t()}finally{A.p=u}}var Ft=Math.random().toString(36).slice(2),Rl="__reactFiber$"+Ft,Ll="__reactProps$"+Ft,Zu="__reactContainer$"+Ft,$n="__reactEvents$"+Ft,Bv="__reactListeners$"+Ft,Yv="__reactHandles$"+Ft,Ai="__reactResources$"+Ft,Na="__reactMarker$"+Ft;function Fn(l){delete l[Rl],delete l[Ll],delete l[$n],delete l[Bv],delete l[Yv]}function Vu(l){var t=l[Rl];if(t)return t;for(var u=l.parentNode;u;){if(t=u[Zu]||u[Rl]){if(u=t.alternate,t.child!==null||u!==null&&u.child!==null)for(l=Ls(l);l!==null;){if(u=l[Rl])return u;l=Ls(l)}return t}l=u,u=l.parentNode}return null}function Lu(l){if(l=l[Rl]||l[Zu]){var t=l.tag;if(t===5||t===6||t===13||t===31||t===26||t===27||t===3)return l}return null}function Ha(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l.stateNode;throw Error(o(33))}function Ku(l){var t=l[Ai];return t||(t=l[Ai]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function pl(l){l[Na]=!0}var _i=new Set,Oi={};function _u(l,t){Ju(l,t),Ju(l+"Capture",t)}function Ju(l,t){for(Oi[l]=t,l=0;l<t.length;l++)_i.add(t[l])}var jv=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),Mi={},Di={};function Gv(l){return Vn.call(Di,l)?!0:Vn.call(Mi,l)?!1:jv.test(l)?Di[l]=!0:(Mi[l]=!0,!1)}function De(l,t,u){if(Gv(t))if(u===null)l.removeAttribute(t);else{switch(typeof u){case"undefined":case"function":case"symbol":l.removeAttribute(t);return;case"boolean":var a=t.toLowerCase().slice(0,5);if(a!=="data-"&&a!=="aria-"){l.removeAttribute(t);return}}l.setAttribute(t,""+u)}}function Ue(l,t,u){if(u===null)l.removeAttribute(t);else{switch(typeof u){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(t);return}l.setAttribute(t,""+u)}}function Ht(l,t,u,a){if(a===null)l.removeAttribute(u);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(u);return}l.setAttributeNS(t,u,""+a)}}function it(l){switch(typeof l){case"bigint":case"boolean":case"number":case"string":case"undefined":return l;case"object":return l;default:return""}}function Ui(l){var t=l.type;return(l=l.nodeName)&&l.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function xv(l,t,u){var a=Object.getOwnPropertyDescriptor(l.constructor.prototype,t);if(!l.hasOwnProperty(t)&&typeof a<"u"&&typeof a.get=="function"&&typeof a.set=="function"){var e=a.get,n=a.set;return Object.defineProperty(l,t,{configurable:!0,get:function(){return e.call(this)},set:function(f){u=""+f,n.call(this,f)}}),Object.defineProperty(l,t,{enumerable:a.enumerable}),{getValue:function(){return u},setValue:function(f){u=""+f},stopTracking:function(){l._valueTracker=null,delete l[t]}}}}function kn(l){if(!l._valueTracker){var t=Ui(l)?"checked":"value";l._valueTracker=xv(l,t,""+l[t])}}function pi(l){if(!l)return!1;var t=l._valueTracker;if(!t)return!0;var u=t.getValue(),a="";return l&&(a=Ui(l)?l.checked?"true":"false":l.value),l=a,l!==u?(t.setValue(l),!0):!1}function pe(l){if(l=l||(typeof document<"u"?document:void 0),typeof l>"u")return null;try{return l.activeElement||l.body}catch{return l.body}}var Xv=/[\n"\\]/g;function st(l){return l.replace(Xv,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function In(l,t,u,a,e,n,f,c){l.name="",f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"?l.type=f:l.removeAttribute("type"),t!=null?f==="number"?(t===0&&l.value===""||l.value!=t)&&(l.value=""+it(t)):l.value!==""+it(t)&&(l.value=""+it(t)):f!=="submit"&&f!=="reset"||l.removeAttribute("value"),t!=null?Pn(l,f,it(t)):u!=null?Pn(l,f,it(u)):a!=null&&l.removeAttribute("value"),e==null&&n!=null&&(l.defaultChecked=!!n),e!=null&&(l.checked=e&&typeof e!="function"&&typeof e!="symbol"),c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"?l.name=""+it(c):l.removeAttribute("name")}function Ni(l,t,u,a,e,n,f,c){if(n!=null&&typeof n!="function"&&typeof n!="symbol"&&typeof n!="boolean"&&(l.type=n),t!=null||u!=null){if(!(n!=="submit"&&n!=="reset"||t!=null)){kn(l);return}u=u!=null?""+it(u):"",t=t!=null?""+it(t):u,c||t===l.value||(l.value=t),l.defaultValue=t}a=a??e,a=typeof a!="function"&&typeof a!="symbol"&&!!a,l.checked=c?l.checked:!!a,l.defaultChecked=!!a,f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"&&(l.name=f),kn(l)}function Pn(l,t,u){t==="number"&&pe(l.ownerDocument)===l||l.defaultValue===""+u||(l.defaultValue=""+u)}function wu(l,t,u,a){if(l=l.options,t){t={};for(var e=0;e<u.length;e++)t["$"+u[e]]=!0;for(u=0;u<l.length;u++)e=t.hasOwnProperty("$"+l[u].value),l[u].selected!==e&&(l[u].selected=e),e&&a&&(l[u].defaultSelected=!0)}else{for(u=""+it(u),t=null,e=0;e<l.length;e++){if(l[e].value===u){l[e].selected=!0,a&&(l[e].defaultSelected=!0);return}t!==null||l[e].disabled||(t=l[e])}t!==null&&(t.selected=!0)}}function Hi(l,t,u){if(t!=null&&(t=""+it(t),t!==l.value&&(l.value=t),u==null)){l.defaultValue!==t&&(l.defaultValue=t);return}l.defaultValue=u!=null?""+it(u):""}function Ri(l,t,u,a){if(t==null){if(a!=null){if(u!=null)throw Error(o(92));if(bt(a)){if(1<a.length)throw Error(o(93));a=a[0]}u=a}u==null&&(u=""),t=u}u=it(t),l.defaultValue=u,a=l.textContent,a===u&&a!==""&&a!==null&&(l.value=a),kn(l)}function Wu(l,t){if(t){var u=l.firstChild;if(u&&u===l.lastChild&&u.nodeType===3){u.nodeValue=t;return}}l.textContent=t}var Qv=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function qi(l,t,u){var a=t.indexOf("--")===0;u==null||typeof u=="boolean"||u===""?a?l.setProperty(t,""):t==="float"?l.cssFloat="":l[t]="":a?l.setProperty(t,u):typeof u!="number"||u===0||Qv.has(t)?t==="float"?l.cssFloat=u:l[t]=(""+u).trim():l[t]=u+"px"}function Ci(l,t,u){if(t!=null&&typeof t!="object")throw Error(o(62));if(l=l.style,u!=null){for(var a in u)!u.hasOwnProperty(a)||t!=null&&t.hasOwnProperty(a)||(a.indexOf("--")===0?l.setProperty(a,""):a==="float"?l.cssFloat="":l[a]="");for(var e in t)a=t[e],t.hasOwnProperty(e)&&u[e]!==a&&qi(l,e,a)}else for(var n in t)t.hasOwnProperty(n)&&qi(l,n,t[n])}function lf(l){if(l.indexOf("-")===-1)return!1;switch(l){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var Zv=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),Vv=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Ne(l){return Vv.test(""+l)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":l}function Rt(){}var tf=null;function uf(l){return l=l.target||l.srcElement||window,l.correspondingUseElement&&(l=l.correspondingUseElement),l.nodeType===3?l.parentNode:l}var $u=null,Fu=null;function Bi(l){var t=Lu(l);if(t&&(l=t.stateNode)){var u=l[Ll]||null;l:switch(l=t.stateNode,t.type){case"input":if(In(l,u.value,u.defaultValue,u.defaultValue,u.checked,u.defaultChecked,u.type,u.name),t=u.name,u.type==="radio"&&t!=null){for(u=l;u.parentNode;)u=u.parentNode;for(u=u.querySelectorAll('input[name="'+st(""+t)+'"][type="radio"]'),t=0;t<u.length;t++){var a=u[t];if(a!==l&&a.form===l.form){var e=a[Ll]||null;if(!e)throw Error(o(90));In(a,e.value,e.defaultValue,e.defaultValue,e.checked,e.defaultChecked,e.type,e.name)}}for(t=0;t<u.length;t++)a=u[t],a.form===l.form&&pi(a)}break l;case"textarea":Hi(l,u.value,u.defaultValue);break l;case"select":t=u.value,t!=null&&wu(l,!!u.multiple,t,!1)}}}var af=!1;function Yi(l,t,u){if(af)return l(t,u);af=!0;try{var a=l(t);return a}finally{if(af=!1,($u!==null||Fu!==null)&&(bn(),$u&&(t=$u,l=Fu,Fu=$u=null,Bi(t),l)))for(t=0;t<l.length;t++)Bi(l[t])}}function Ra(l,t){var u=l.stateNode;if(u===null)return null;var a=u[Ll]||null;if(a===null)return null;u=a[t];l:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(a=!a.disabled)||(l=l.type,a=!(l==="button"||l==="input"||l==="select"||l==="textarea")),l=!a;break l;default:l=!1}if(l)return null;if(u&&typeof u!="function")throw Error(o(231,t,typeof u));return u}var qt=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),ef=!1;if(qt)try{var qa={};Object.defineProperty(qa,"passive",{get:function(){ef=!0}}),window.addEventListener("test",qa,qa),window.removeEventListener("test",qa,qa)}catch{ef=!1}var kt=null,nf=null,He=null;function ji(){if(He)return He;var l,t=nf,u=t.length,a,e="value"in kt?kt.value:kt.textContent,n=e.length;for(l=0;l<u&&t[l]===e[l];l++);var f=u-l;for(a=1;a<=f&&t[u-a]===e[n-a];a++);return He=e.slice(l,1<a?1-a:void 0)}function Re(l){var t=l.keyCode;return"charCode"in l?(l=l.charCode,l===0&&t===13&&(l=13)):l=t,l===10&&(l=13),32<=l||l===13?l:0}function qe(){return!0}function Gi(){return!1}function Kl(l){function t(u,a,e,n,f){this._reactName=u,this._targetInst=e,this.type=a,this.nativeEvent=n,this.target=f,this.currentTarget=null;for(var c in l)l.hasOwnProperty(c)&&(u=l[c],this[c]=u?u(n):n[c]);return this.isDefaultPrevented=(n.defaultPrevented!=null?n.defaultPrevented:n.returnValue===!1)?qe:Gi,this.isPropagationStopped=Gi,this}return R(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var u=this.nativeEvent;u&&(u.preventDefault?u.preventDefault():typeof u.returnValue!="unknown"&&(u.returnValue=!1),this.isDefaultPrevented=qe)},stopPropagation:function(){var u=this.nativeEvent;u&&(u.stopPropagation?u.stopPropagation():typeof u.cancelBubble!="unknown"&&(u.cancelBubble=!0),this.isPropagationStopped=qe)},persist:function(){},isPersistent:qe}),t}var Ou={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(l){return l.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Ce=Kl(Ou),Ca=R({},Ou,{view:0,detail:0}),Lv=Kl(Ca),ff,cf,Ba,Be=R({},Ca,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:vf,button:0,buttons:0,relatedTarget:function(l){return l.relatedTarget===void 0?l.fromElement===l.srcElement?l.toElement:l.fromElement:l.relatedTarget},movementX:function(l){return"movementX"in l?l.movementX:(l!==Ba&&(Ba&&l.type==="mousemove"?(ff=l.screenX-Ba.screenX,cf=l.screenY-Ba.screenY):cf=ff=0,Ba=l),ff)},movementY:function(l){return"movementY"in l?l.movementY:cf}}),xi=Kl(Be),Kv=R({},Be,{dataTransfer:0}),Jv=Kl(Kv),wv=R({},Ca,{relatedTarget:0}),sf=Kl(wv),Wv=R({},Ou,{animationName:0,elapsedTime:0,pseudoElement:0}),$v=Kl(Wv),Fv=R({},Ou,{clipboardData:function(l){return"clipboardData"in l?l.clipboardData:window.clipboardData}}),kv=Kl(Fv),Iv=R({},Ou,{data:0}),Xi=Kl(Iv),Pv={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},ly={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},ty={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function uy(l){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(l):(l=ty[l])?!!t[l]:!1}function vf(){return uy}var ay=R({},Ca,{key:function(l){if(l.key){var t=Pv[l.key]||l.key;if(t!=="Unidentified")return t}return l.type==="keypress"?(l=Re(l),l===13?"Enter":String.fromCharCode(l)):l.type==="keydown"||l.type==="keyup"?ly[l.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:vf,charCode:function(l){return l.type==="keypress"?Re(l):0},keyCode:function(l){return l.type==="keydown"||l.type==="keyup"?l.keyCode:0},which:function(l){return l.type==="keypress"?Re(l):l.type==="keydown"||l.type==="keyup"?l.keyCode:0}}),ey=Kl(ay),ny=R({},Be,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),Qi=Kl(ny),fy=R({},Ca,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:vf}),cy=Kl(fy),iy=R({},Ou,{propertyName:0,elapsedTime:0,pseudoElement:0}),sy=Kl(iy),vy=R({},Be,{deltaX:function(l){return"deltaX"in l?l.deltaX:"wheelDeltaX"in l?-l.wheelDeltaX:0},deltaY:function(l){return"deltaY"in l?l.deltaY:"wheelDeltaY"in l?-l.wheelDeltaY:"wheelDelta"in l?-l.wheelDelta:0},deltaZ:0,deltaMode:0}),yy=Kl(vy),my=R({},Ou,{newState:0,oldState:0}),dy=Kl(my),hy=[9,13,27,32],yf=qt&&"CompositionEvent"in window,Ya=null;qt&&"documentMode"in document&&(Ya=document.documentMode);var oy=qt&&"TextEvent"in window&&!Ya,Zi=qt&&(!yf||Ya&&8<Ya&&11>=Ya),Vi=" ",Li=!1;function Ki(l,t){switch(l){case"keyup":return hy.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function Ji(l){return l=l.detail,typeof l=="object"&&"data"in l?l.data:null}var ku=!1;function gy(l,t){switch(l){case"compositionend":return Ji(t);case"keypress":return t.which!==32?null:(Li=!0,Vi);case"textInput":return l=t.data,l===Vi&&Li?null:l;default:return null}}function Sy(l,t){if(ku)return l==="compositionend"||!yf&&Ki(l,t)?(l=ji(),He=nf=kt=null,ku=!1,l):null;switch(l){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return Zi&&t.locale!=="ko"?null:t.data;default:return null}}var by={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function wi(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t==="input"?!!by[l.type]:t==="textarea"}function Wi(l,t,u,a){$u?Fu?Fu.push(a):Fu=[a]:$u=a,t=On(t,"onChange"),0<t.length&&(u=new Ce("onChange","change",null,u,a),l.push({event:u,listeners:t}))}var ja=null,Ga=null;function zy(l){Ns(l,0)}function Ye(l){var t=Ha(l);if(pi(t))return l}function $i(l,t){if(l==="change")return t}var Fi=!1;if(qt){var mf;if(qt){var df="oninput"in document;if(!df){var ki=document.createElement("div");ki.setAttribute("oninput","return;"),df=typeof ki.oninput=="function"}mf=df}else mf=!1;Fi=mf&&(!document.documentMode||9<document.documentMode)}function Ii(){ja&&(ja.detachEvent("onpropertychange",Pi),Ga=ja=null)}function Pi(l){if(l.propertyName==="value"&&Ye(Ga)){var t=[];Wi(t,Ga,l,uf(l)),Yi(zy,t)}}function ry(l,t,u){l==="focusin"?(Ii(),ja=t,Ga=u,ja.attachEvent("onpropertychange",Pi)):l==="focusout"&&Ii()}function Ty(l){if(l==="selectionchange"||l==="keyup"||l==="keydown")return Ye(Ga)}function Ey(l,t){if(l==="click")return Ye(t)}function Ay(l,t){if(l==="input"||l==="change")return Ye(t)}function _y(l,t){return l===t&&(l!==0||1/l===1/t)||l!==l&&t!==t}var lt=typeof Object.is=="function"?Object.is:_y;function xa(l,t){if(lt(l,t))return!0;if(typeof l!="object"||l===null||typeof t!="object"||t===null)return!1;var u=Object.keys(l),a=Object.keys(t);if(u.length!==a.length)return!1;for(a=0;a<u.length;a++){var e=u[a];if(!Vn.call(t,e)||!lt(l[e],t[e]))return!1}return!0}function l0(l){for(;l&&l.firstChild;)l=l.firstChild;return l}function t0(l,t){var u=l0(l);l=0;for(var a;u;){if(u.nodeType===3){if(a=l+u.textContent.length,l<=t&&a>=t)return{node:u,offset:t-l};l=a}l:{for(;u;){if(u.nextSibling){u=u.nextSibling;break l}u=u.parentNode}u=void 0}u=l0(u)}}function u0(l,t){return l&&t?l===t?!0:l&&l.nodeType===3?!1:t&&t.nodeType===3?u0(l,t.parentNode):"contains"in l?l.contains(t):l.compareDocumentPosition?!!(l.compareDocumentPosition(t)&16):!1:!1}function a0(l){l=l!=null&&l.ownerDocument!=null&&l.ownerDocument.defaultView!=null?l.ownerDocument.defaultView:window;for(var t=pe(l.document);t instanceof l.HTMLIFrameElement;){try{var u=typeof t.contentWindow.location.href=="string"}catch{u=!1}if(u)l=t.contentWindow;else break;t=pe(l.document)}return t}function hf(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t&&(t==="input"&&(l.type==="text"||l.type==="search"||l.type==="tel"||l.type==="url"||l.type==="password")||t==="textarea"||l.contentEditable==="true")}var Oy=qt&&"documentMode"in document&&11>=document.documentMode,Iu=null,of=null,Xa=null,gf=!1;function e0(l,t,u){var a=u.window===u?u.document:u.nodeType===9?u:u.ownerDocument;gf||Iu==null||Iu!==pe(a)||(a=Iu,"selectionStart"in a&&hf(a)?a={start:a.selectionStart,end:a.selectionEnd}:(a=(a.ownerDocument&&a.ownerDocument.defaultView||window).getSelection(),a={anchorNode:a.anchorNode,anchorOffset:a.anchorOffset,focusNode:a.focusNode,focusOffset:a.focusOffset}),Xa&&xa(Xa,a)||(Xa=a,a=On(of,"onSelect"),0<a.length&&(t=new Ce("onSelect","select",null,t,u),l.push({event:t,listeners:a}),t.target=Iu)))}function Mu(l,t){var u={};return u[l.toLowerCase()]=t.toLowerCase(),u["Webkit"+l]="webkit"+t,u["Moz"+l]="moz"+t,u}var Pu={animationend:Mu("Animation","AnimationEnd"),animationiteration:Mu("Animation","AnimationIteration"),animationstart:Mu("Animation","AnimationStart"),transitionrun:Mu("Transition","TransitionRun"),transitionstart:Mu("Transition","TransitionStart"),transitioncancel:Mu("Transition","TransitionCancel"),transitionend:Mu("Transition","TransitionEnd")},Sf={},n0={};qt&&(n0=document.createElement("div").style,"AnimationEvent"in window||(delete Pu.animationend.animation,delete Pu.animationiteration.animation,delete Pu.animationstart.animation),"TransitionEvent"in window||delete Pu.transitionend.transition);function Du(l){if(Sf[l])return Sf[l];if(!Pu[l])return l;var t=Pu[l],u;for(u in t)if(t.hasOwnProperty(u)&&u in n0)return Sf[l]=t[u];return l}var f0=Du("animationend"),c0=Du("animationiteration"),i0=Du("animationstart"),My=Du("transitionrun"),Dy=Du("transitionstart"),Uy=Du("transitioncancel"),s0=Du("transitionend"),v0=new Map,bf="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");bf.push("scrollEnd");function zt(l,t){v0.set(l,t),_u(t,[l])}var je=typeof reportError=="function"?reportError:function(l){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof l=="object"&&l!==null&&typeof l.message=="string"?String(l.message):String(l),error:l});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",l);return}console.error(l)},vt=[],la=0,zf=0;function Ge(){for(var l=la,t=zf=la=0;t<l;){var u=vt[t];vt[t++]=null;var a=vt[t];vt[t++]=null;var e=vt[t];vt[t++]=null;var n=vt[t];if(vt[t++]=null,a!==null&&e!==null){var f=a.pending;f===null?e.next=e:(e.next=f.next,f.next=e),a.pending=e}n!==0&&y0(u,e,n)}}function xe(l,t,u,a){vt[la++]=l,vt[la++]=t,vt[la++]=u,vt[la++]=a,zf|=a,l.lanes|=a,l=l.alternate,l!==null&&(l.lanes|=a)}function rf(l,t,u,a){return xe(l,t,u,a),Xe(l)}function Uu(l,t){return xe(l,null,null,t),Xe(l)}function y0(l,t,u){l.lanes|=u;var a=l.alternate;a!==null&&(a.lanes|=u);for(var e=!1,n=l.return;n!==null;)n.childLanes|=u,a=n.alternate,a!==null&&(a.childLanes|=u),n.tag===22&&(l=n.stateNode,l===null||l._visibility&1||(e=!0)),l=n,n=n.return;return l.tag===3?(n=l.stateNode,e&&t!==null&&(e=31-Pl(u),l=n.hiddenUpdates,a=l[e],a===null?l[e]=[t]:a.push(t),t.lane=u|536870912),n):null}function Xe(l){if(50<ie)throw ie=0,pc=null,Error(o(185));for(var t=l.return;t!==null;)l=t,t=l.return;return l.tag===3?l.stateNode:null}var ta={};function py(l,t,u,a){this.tag=l,this.key=u,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=a,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function tt(l,t,u,a){return new py(l,t,u,a)}function Tf(l){return l=l.prototype,!(!l||!l.isReactComponent)}function Ct(l,t){var u=l.alternate;return u===null?(u=tt(l.tag,t,l.key,l.mode),u.elementType=l.elementType,u.type=l.type,u.stateNode=l.stateNode,u.alternate=l,l.alternate=u):(u.pendingProps=t,u.type=l.type,u.flags=0,u.subtreeFlags=0,u.deletions=null),u.flags=l.flags&65011712,u.childLanes=l.childLanes,u.lanes=l.lanes,u.child=l.child,u.memoizedProps=l.memoizedProps,u.memoizedState=l.memoizedState,u.updateQueue=l.updateQueue,t=l.dependencies,u.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},u.sibling=l.sibling,u.index=l.index,u.ref=l.ref,u.refCleanup=l.refCleanup,u}function m0(l,t){l.flags&=65011714;var u=l.alternate;return u===null?(l.childLanes=0,l.lanes=t,l.child=null,l.subtreeFlags=0,l.memoizedProps=null,l.memoizedState=null,l.updateQueue=null,l.dependencies=null,l.stateNode=null):(l.childLanes=u.childLanes,l.lanes=u.lanes,l.child=u.child,l.subtreeFlags=0,l.deletions=null,l.memoizedProps=u.memoizedProps,l.memoizedState=u.memoizedState,l.updateQueue=u.updateQueue,l.type=u.type,t=u.dependencies,l.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),l}function Qe(l,t,u,a,e,n){var f=0;if(a=l,typeof l=="function")Tf(l)&&(f=1);else if(typeof l=="string")f=Cm(l,u,D.current)?26:l==="html"||l==="head"||l==="body"?27:5;else l:switch(l){case _t:return l=tt(31,u,t,e),l.elementType=_t,l.lanes=n,l;case Dl:return pu(u.children,e,n,t);case hl:f=8,e|=24;break;case Ul:return l=tt(12,u,t,e|2),l.elementType=Ul,l.lanes=n,l;case At:return l=tt(13,u,t,e),l.elementType=At,l.lanes=n,l;case Ql:return l=tt(19,u,t,e),l.elementType=Ql,l.lanes=n,l;default:if(typeof l=="object"&&l!==null)switch(l.$$typeof){case jl:f=10;break l;case Et:f=9;break l;case ct:f=11;break l;case L:f=14;break l;case Zl:f=16,a=null;break l}f=29,u=Error(o(130,l===null?"null":typeof l,"")),a=null}return t=tt(f,u,t,e),t.elementType=l,t.type=a,t.lanes=n,t}function pu(l,t,u,a){return l=tt(7,l,a,t),l.lanes=u,l}function Ef(l,t,u){return l=tt(6,l,null,t),l.lanes=u,l}function d0(l){var t=tt(18,null,null,0);return t.stateNode=l,t}function Af(l,t,u){return t=tt(4,l.children!==null?l.children:[],l.key,t),t.lanes=u,t.stateNode={containerInfo:l.containerInfo,pendingChildren:null,implementation:l.implementation},t}var h0=new WeakMap;function yt(l,t){if(typeof l=="object"&&l!==null){var u=h0.get(l);return u!==void 0?u:(t={value:l,source:t,stack:di(t)},h0.set(l,t),t)}return{value:l,source:t,stack:di(t)}}var ua=[],aa=0,Ze=null,Qa=0,mt=[],dt=0,It=null,Mt=1,Dt="";function Bt(l,t){ua[aa++]=Qa,ua[aa++]=Ze,Ze=l,Qa=t}function o0(l,t,u){mt[dt++]=Mt,mt[dt++]=Dt,mt[dt++]=It,It=l;var a=Mt;l=Dt;var e=32-Pl(a)-1;a&=~(1<<e),u+=1;var n=32-Pl(t)+e;if(30<n){var f=e-e%5;n=(a&(1<<f)-1).toString(32),a>>=f,e-=f,Mt=1<<32-Pl(t)+e|u<<e|a,Dt=n+l}else Mt=1<<n|u<<e|a,Dt=l}function _f(l){l.return!==null&&(Bt(l,1),o0(l,1,0))}function Of(l){for(;l===Ze;)Ze=ua[--aa],ua[aa]=null,Qa=ua[--aa],ua[aa]=null;for(;l===It;)It=mt[--dt],mt[dt]=null,Dt=mt[--dt],mt[dt]=null,Mt=mt[--dt],mt[dt]=null}function g0(l,t){mt[dt++]=Mt,mt[dt++]=Dt,mt[dt++]=It,Mt=t.id,Dt=t.overflow,It=l}var ql=null,sl=null,K=!1,Pt=null,ht=!1,Mf=Error(o(519));function lu(l){var t=Error(o(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw Za(yt(t,l)),Mf}function S0(l){var t=l.stateNode,u=l.type,a=l.memoizedProps;switch(t[Rl]=l,t[Ll]=a,u){case"dialog":Q("cancel",t),Q("close",t);break;case"iframe":case"object":case"embed":Q("load",t);break;case"video":case"audio":for(u=0;u<ve.length;u++)Q(ve[u],t);break;case"source":Q("error",t);break;case"img":case"image":case"link":Q("error",t),Q("load",t);break;case"details":Q("toggle",t);break;case"input":Q("invalid",t),Ni(t,a.value,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name,!0);break;case"select":Q("invalid",t);break;case"textarea":Q("invalid",t),Ri(t,a.value,a.defaultValue,a.children)}u=a.children,typeof u!="string"&&typeof u!="number"&&typeof u!="bigint"||t.textContent===""+u||a.suppressHydrationWarning===!0||Cs(t.textContent,u)?(a.popover!=null&&(Q("beforetoggle",t),Q("toggle",t)),a.onScroll!=null&&Q("scroll",t),a.onScrollEnd!=null&&Q("scrollend",t),a.onClick!=null&&(t.onclick=Rt),t=!0):t=!1,t||lu(l,!0)}function b0(l){for(ql=l.return;ql;)switch(ql.tag){case 5:case 31:case 13:ht=!1;return;case 27:case 3:ht=!0;return;default:ql=ql.return}}function ea(l){if(l!==ql)return!1;if(!K)return b0(l),K=!0,!1;var t=l.tag,u;if((u=t!==3&&t!==27)&&((u=t===5)&&(u=l.type,u=!(u!=="form"&&u!=="button")||Lc(l.type,l.memoizedProps)),u=!u),u&&sl&&lu(l),b0(l),t===13){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(o(317));sl=Vs(l)}else if(t===31){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(o(317));sl=Vs(l)}else t===27?(t=sl,hu(l.type)?(l=$c,$c=null,sl=l):sl=t):sl=ql?gt(l.stateNode.nextSibling):null;return!0}function Nu(){sl=ql=null,K=!1}function Df(){var l=Pt;return l!==null&&($l===null?$l=l:$l.push.apply($l,l),Pt=null),l}function Za(l){Pt===null?Pt=[l]:Pt.push(l)}var Uf=v(null),Hu=null,Yt=null;function tu(l,t,u){_(Uf,t._currentValue),t._currentValue=u}function jt(l){l._currentValue=Uf.current,T(Uf)}function pf(l,t,u){for(;l!==null;){var a=l.alternate;if((l.childLanes&t)!==t?(l.childLanes|=t,a!==null&&(a.childLanes|=t)):a!==null&&(a.childLanes&t)!==t&&(a.childLanes|=t),l===u)break;l=l.return}}function Nf(l,t,u,a){var e=l.child;for(e!==null&&(e.return=l);e!==null;){var n=e.dependencies;if(n!==null){var f=e.child;n=n.firstContext;l:for(;n!==null;){var c=n;n=e;for(var i=0;i<t.length;i++)if(c.context===t[i]){n.lanes|=u,c=n.alternate,c!==null&&(c.lanes|=u),pf(n.return,u,l),a||(f=null);break l}n=c.next}}else if(e.tag===18){if(f=e.return,f===null)throw Error(o(341));f.lanes|=u,n=f.alternate,n!==null&&(n.lanes|=u),pf(f,u,l),f=null}else f=e.child;if(f!==null)f.return=e;else for(f=e;f!==null;){if(f===l){f=null;break}if(e=f.sibling,e!==null){e.return=f.return,f=e;break}f=f.return}e=f}}function na(l,t,u,a){l=null;for(var e=t,n=!1;e!==null;){if(!n){if((e.flags&524288)!==0)n=!0;else if((e.flags&262144)!==0)break}if(e.tag===10){var f=e.alternate;if(f===null)throw Error(o(387));if(f=f.memoizedProps,f!==null){var c=e.type;lt(e.pendingProps.value,f.value)||(l!==null?l.push(c):l=[c])}}else if(e===P.current){if(f=e.alternate,f===null)throw Error(o(387));f.memoizedState.memoizedState!==e.memoizedState.memoizedState&&(l!==null?l.push(oe):l=[oe])}e=e.return}l!==null&&Nf(t,l,u,a),t.flags|=262144}function Ve(l){for(l=l.firstContext;l!==null;){if(!lt(l.context._currentValue,l.memoizedValue))return!0;l=l.next}return!1}function Ru(l){Hu=l,Yt=null,l=l.dependencies,l!==null&&(l.firstContext=null)}function Cl(l){return z0(Hu,l)}function Le(l,t){return Hu===null&&Ru(l),z0(l,t)}function z0(l,t){var u=t._currentValue;if(t={context:t,memoizedValue:u,next:null},Yt===null){if(l===null)throw Error(o(308));Yt=t,l.dependencies={lanes:0,firstContext:t},l.flags|=524288}else Yt=Yt.next=t;return u}var Ny=typeof AbortController<"u"?AbortController:function(){var l=[],t=this.signal={aborted:!1,addEventListener:function(u,a){l.push(a)}};this.abort=function(){t.aborted=!0,l.forEach(function(u){return u()})}},Hy=M.unstable_scheduleCallback,Ry=M.unstable_NormalPriority,rl={$$typeof:jl,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Hf(){return{controller:new Ny,data:new Map,refCount:0}}function Va(l){l.refCount--,l.refCount===0&&Hy(Ry,function(){l.controller.abort()})}var La=null,Rf=0,fa=0,ca=null;function qy(l,t){if(La===null){var u=La=[];Rf=0,fa=Bc(),ca={status:"pending",value:void 0,then:function(a){u.push(a)}}}return Rf++,t.then(r0,r0),t}function r0(){if(--Rf===0&&La!==null){ca!==null&&(ca.status="fulfilled");var l=La;La=null,fa=0,ca=null;for(var t=0;t<l.length;t++)(0,l[t])()}}function Cy(l,t){var u=[],a={status:"pending",value:null,reason:null,then:function(e){u.push(e)}};return l.then(function(){a.status="fulfilled",a.value=t;for(var e=0;e<u.length;e++)(0,u[e])(t)},function(e){for(a.status="rejected",a.reason=e,e=0;e<u.length;e++)(0,u[e])(void 0)}),a}var T0=b.S;b.S=function(l,t){es=kl(),typeof t=="object"&&t!==null&&typeof t.then=="function"&&qy(l,t),T0!==null&&T0(l,t)};var qu=v(null);function qf(){var l=qu.current;return l!==null?l:cl.pooledCache}function Ke(l,t){t===null?_(qu,qu.current):_(qu,t.pool)}function E0(){var l=qf();return l===null?null:{parent:rl._currentValue,pool:l}}var ia=Error(o(460)),Cf=Error(o(474)),Je=Error(o(542)),we={then:function(){}};function A0(l){return l=l.status,l==="fulfilled"||l==="rejected"}function _0(l,t,u){switch(u=l[u],u===void 0?l.push(t):u!==t&&(t.then(Rt,Rt),t=u),t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,M0(l),l;default:if(typeof t.status=="string")t.then(Rt,Rt);else{if(l=cl,l!==null&&100<l.shellSuspendCounter)throw Error(o(482));l=t,l.status="pending",l.then(function(a){if(t.status==="pending"){var e=t;e.status="fulfilled",e.value=a}},function(a){if(t.status==="pending"){var e=t;e.status="rejected",e.reason=a}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,M0(l),l}throw Bu=t,ia}}function Cu(l){try{var t=l._init;return t(l._payload)}catch(u){throw u!==null&&typeof u=="object"&&typeof u.then=="function"?(Bu=u,ia):u}}var Bu=null;function O0(){if(Bu===null)throw Error(o(459));var l=Bu;return Bu=null,l}function M0(l){if(l===ia||l===Je)throw Error(o(483))}var sa=null,Ka=0;function We(l){var t=Ka;return Ka+=1,sa===null&&(sa=[]),_0(sa,l,t)}function Ja(l,t){t=t.props.ref,l.ref=t!==void 0?t:null}function $e(l,t){throw t.$$typeof===il?Error(o(525)):(l=Object.prototype.toString.call(t),Error(o(31,l==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":l)))}function D0(l){function t(y,s){if(l){var m=y.deletions;m===null?(y.deletions=[s],y.flags|=16):m.push(s)}}function u(y,s){if(!l)return null;for(;s!==null;)t(y,s),s=s.sibling;return null}function a(y){for(var s=new Map;y!==null;)y.key!==null?s.set(y.key,y):s.set(y.index,y),y=y.sibling;return s}function e(y,s){return y=Ct(y,s),y.index=0,y.sibling=null,y}function n(y,s,m){return y.index=m,l?(m=y.alternate,m!==null?(m=m.index,m<s?(y.flags|=67108866,s):m):(y.flags|=67108866,s)):(y.flags|=1048576,s)}function f(y){return l&&y.alternate===null&&(y.flags|=67108866),y}function c(y,s,m,z){return s===null||s.tag!==6?(s=Ef(m,y.mode,z),s.return=y,s):(s=e(s,m),s.return=y,s)}function i(y,s,m,z){var N=m.type;return N===Dl?S(y,s,m.props.children,z,m.key):s!==null&&(s.elementType===N||typeof N=="object"&&N!==null&&N.$$typeof===Zl&&Cu(N)===s.type)?(s=e(s,m.props),Ja(s,m),s.return=y,s):(s=Qe(m.type,m.key,m.props,null,y.mode,z),Ja(s,m),s.return=y,s)}function d(y,s,m,z){return s===null||s.tag!==4||s.stateNode.containerInfo!==m.containerInfo||s.stateNode.implementation!==m.implementation?(s=Af(m,y.mode,z),s.return=y,s):(s=e(s,m.children||[]),s.return=y,s)}function S(y,s,m,z,N){return s===null||s.tag!==7?(s=pu(m,y.mode,z,N),s.return=y,s):(s=e(s,m),s.return=y,s)}function r(y,s,m){if(typeof s=="string"&&s!==""||typeof s=="number"||typeof s=="bigint")return s=Ef(""+s,y.mode,m),s.return=y,s;if(typeof s=="object"&&s!==null){switch(s.$$typeof){case Ml:return m=Qe(s.type,s.key,s.props,null,y.mode,m),Ja(m,s),m.return=y,m;case Hl:return s=Af(s,y.mode,m),s.return=y,s;case Zl:return s=Cu(s),r(y,s,m)}if(bt(s)||Vl(s))return s=pu(s,y.mode,m,null),s.return=y,s;if(typeof s.then=="function")return r(y,We(s),m);if(s.$$typeof===jl)return r(y,Le(y,s),m);$e(y,s)}return null}function h(y,s,m,z){var N=s!==null?s.key:null;if(typeof m=="string"&&m!==""||typeof m=="number"||typeof m=="bigint")return N!==null?null:c(y,s,""+m,z);if(typeof m=="object"&&m!==null){switch(m.$$typeof){case Ml:return m.key===N?i(y,s,m,z):null;case Hl:return m.key===N?d(y,s,m,z):null;case Zl:return m=Cu(m),h(y,s,m,z)}if(bt(m)||Vl(m))return N!==null?null:S(y,s,m,z,null);if(typeof m.then=="function")return h(y,s,We(m),z);if(m.$$typeof===jl)return h(y,s,Le(y,m),z);$e(y,m)}return null}function g(y,s,m,z,N){if(typeof z=="string"&&z!==""||typeof z=="number"||typeof z=="bigint")return y=y.get(m)||null,c(s,y,""+z,N);if(typeof z=="object"&&z!==null){switch(z.$$typeof){case Ml:return y=y.get(z.key===null?m:z.key)||null,i(s,y,z,N);case Hl:return y=y.get(z.key===null?m:z.key)||null,d(s,y,z,N);case Zl:return z=Cu(z),g(y,s,m,z,N)}if(bt(z)||Vl(z))return y=y.get(m)||null,S(s,y,z,N,null);if(typeof z.then=="function")return g(y,s,m,We(z),N);if(z.$$typeof===jl)return g(y,s,m,Le(s,z),N);$e(s,z)}return null}function O(y,s,m,z){for(var N=null,F=null,U=s,G=s=0,V=null;U!==null&&G<m.length;G++){U.index>G?(V=U,U=null):V=U.sibling;var k=h(y,U,m[G],z);if(k===null){U===null&&(U=V);break}l&&U&&k.alternate===null&&t(y,U),s=n(k,s,G),F===null?N=k:F.sibling=k,F=k,U=V}if(G===m.length)return u(y,U),K&&Bt(y,G),N;if(U===null){for(;G<m.length;G++)U=r(y,m[G],z),U!==null&&(s=n(U,s,G),F===null?N=U:F.sibling=U,F=U);return K&&Bt(y,G),N}for(U=a(U);G<m.length;G++)V=g(U,y,G,m[G],z),V!==null&&(l&&V.alternate!==null&&U.delete(V.key===null?G:V.key),s=n(V,s,G),F===null?N=V:F.sibling=V,F=V);return l&&U.forEach(function(zu){return t(y,zu)}),K&&Bt(y,G),N}function H(y,s,m,z){if(m==null)throw Error(o(151));for(var N=null,F=null,U=s,G=s=0,V=null,k=m.next();U!==null&&!k.done;G++,k=m.next()){U.index>G?(V=U,U=null):V=U.sibling;var zu=h(y,U,k.value,z);if(zu===null){U===null&&(U=V);break}l&&U&&zu.alternate===null&&t(y,U),s=n(zu,s,G),F===null?N=zu:F.sibling=zu,F=zu,U=V}if(k.done)return u(y,U),K&&Bt(y,G),N;if(U===null){for(;!k.done;G++,k=m.next())k=r(y,k.value,z),k!==null&&(s=n(k,s,G),F===null?N=k:F.sibling=k,F=k);return K&&Bt(y,G),N}for(U=a(U);!k.done;G++,k=m.next())k=g(U,y,G,k.value,z),k!==null&&(l&&k.alternate!==null&&U.delete(k.key===null?G:k.key),s=n(k,s,G),F===null?N=k:F.sibling=k,F=k);return l&&U.forEach(function(Km){return t(y,Km)}),K&&Bt(y,G),N}function nl(y,s,m,z){if(typeof m=="object"&&m!==null&&m.type===Dl&&m.key===null&&(m=m.props.children),typeof m=="object"&&m!==null){switch(m.$$typeof){case Ml:l:{for(var N=m.key;s!==null;){if(s.key===N){if(N=m.type,N===Dl){if(s.tag===7){u(y,s.sibling),z=e(s,m.props.children),z.return=y,y=z;break l}}else if(s.elementType===N||typeof N=="object"&&N!==null&&N.$$typeof===Zl&&Cu(N)===s.type){u(y,s.sibling),z=e(s,m.props),Ja(z,m),z.return=y,y=z;break l}u(y,s);break}else t(y,s);s=s.sibling}m.type===Dl?(z=pu(m.props.children,y.mode,z,m.key),z.return=y,y=z):(z=Qe(m.type,m.key,m.props,null,y.mode,z),Ja(z,m),z.return=y,y=z)}return f(y);case Hl:l:{for(N=m.key;s!==null;){if(s.key===N)if(s.tag===4&&s.stateNode.containerInfo===m.containerInfo&&s.stateNode.implementation===m.implementation){u(y,s.sibling),z=e(s,m.children||[]),z.return=y,y=z;break l}else{u(y,s);break}else t(y,s);s=s.sibling}z=Af(m,y.mode,z),z.return=y,y=z}return f(y);case Zl:return m=Cu(m),nl(y,s,m,z)}if(bt(m))return O(y,s,m,z);if(Vl(m)){if(N=Vl(m),typeof N!="function")throw Error(o(150));return m=N.call(m),H(y,s,m,z)}if(typeof m.then=="function")return nl(y,s,We(m),z);if(m.$$typeof===jl)return nl(y,s,Le(y,m),z);$e(y,m)}return typeof m=="string"&&m!==""||typeof m=="number"||typeof m=="bigint"?(m=""+m,s!==null&&s.tag===6?(u(y,s.sibling),z=e(s,m),z.return=y,y=z):(u(y,s),z=Ef(m,y.mode,z),z.return=y,y=z),f(y)):u(y,s)}return function(y,s,m,z){try{Ka=0;var N=nl(y,s,m,z);return sa=null,N}catch(U){if(U===ia||U===Je)throw U;var F=tt(29,U,null,y.mode);return F.lanes=z,F.return=y,F}finally{}}}var Yu=D0(!0),U0=D0(!1),uu=!1;function Bf(l){l.updateQueue={baseState:l.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Yf(l,t){l=l.updateQueue,t.updateQueue===l&&(t.updateQueue={baseState:l.baseState,firstBaseUpdate:l.firstBaseUpdate,lastBaseUpdate:l.lastBaseUpdate,shared:l.shared,callbacks:null})}function au(l){return{lane:l,tag:0,payload:null,callback:null,next:null}}function eu(l,t,u){var a=l.updateQueue;if(a===null)return null;if(a=a.shared,(I&2)!==0){var e=a.pending;return e===null?t.next=t:(t.next=e.next,e.next=t),a.pending=t,t=Xe(l),y0(l,null,u),t}return xe(l,a,t,u),Xe(l)}function wa(l,t,u){if(t=t.updateQueue,t!==null&&(t=t.shared,(u&4194048)!==0)){var a=t.lanes;a&=l.pendingLanes,u|=a,t.lanes=u,zi(l,u)}}function jf(l,t){var u=l.updateQueue,a=l.alternate;if(a!==null&&(a=a.updateQueue,u===a)){var e=null,n=null;if(u=u.firstBaseUpdate,u!==null){do{var f={lane:u.lane,tag:u.tag,payload:u.payload,callback:null,next:null};n===null?e=n=f:n=n.next=f,u=u.next}while(u!==null);n===null?e=n=t:n=n.next=t}else e=n=t;u={baseState:a.baseState,firstBaseUpdate:e,lastBaseUpdate:n,shared:a.shared,callbacks:a.callbacks},l.updateQueue=u;return}l=u.lastBaseUpdate,l===null?u.firstBaseUpdate=t:l.next=t,u.lastBaseUpdate=t}var Gf=!1;function Wa(){if(Gf){var l=ca;if(l!==null)throw l}}function $a(l,t,u,a){Gf=!1;var e=l.updateQueue;uu=!1;var n=e.firstBaseUpdate,f=e.lastBaseUpdate,c=e.shared.pending;if(c!==null){e.shared.pending=null;var i=c,d=i.next;i.next=null,f===null?n=d:f.next=d,f=i;var S=l.alternate;S!==null&&(S=S.updateQueue,c=S.lastBaseUpdate,c!==f&&(c===null?S.firstBaseUpdate=d:c.next=d,S.lastBaseUpdate=i))}if(n!==null){var r=e.baseState;f=0,S=d=i=null,c=n;do{var h=c.lane&-536870913,g=h!==c.lane;if(g?(Z&h)===h:(a&h)===h){h!==0&&h===fa&&(Gf=!0),S!==null&&(S=S.next={lane:0,tag:c.tag,payload:c.payload,callback:null,next:null});l:{var O=l,H=c;h=t;var nl=u;switch(H.tag){case 1:if(O=H.payload,typeof O=="function"){r=O.call(nl,r,h);break l}r=O;break l;case 3:O.flags=O.flags&-65537|128;case 0:if(O=H.payload,h=typeof O=="function"?O.call(nl,r,h):O,h==null)break l;r=R({},r,h);break l;case 2:uu=!0}}h=c.callback,h!==null&&(l.flags|=64,g&&(l.flags|=8192),g=e.callbacks,g===null?e.callbacks=[h]:g.push(h))}else g={lane:h,tag:c.tag,payload:c.payload,callback:c.callback,next:null},S===null?(d=S=g,i=r):S=S.next=g,f|=h;if(c=c.next,c===null){if(c=e.shared.pending,c===null)break;g=c,c=g.next,g.next=null,e.lastBaseUpdate=g,e.shared.pending=null}}while(!0);S===null&&(i=r),e.baseState=i,e.firstBaseUpdate=d,e.lastBaseUpdate=S,n===null&&(e.shared.lanes=0),su|=f,l.lanes=f,l.memoizedState=r}}function p0(l,t){if(typeof l!="function")throw Error(o(191,l));l.call(t)}function N0(l,t){var u=l.callbacks;if(u!==null)for(l.callbacks=null,l=0;l<u.length;l++)p0(u[l],t)}var va=v(null),Fe=v(0);function H0(l,t){l=Jt,_(Fe,l),_(va,t),Jt=l|t.baseLanes}function xf(){_(Fe,Jt),_(va,va.current)}function Xf(){Jt=Fe.current,T(va),T(Fe)}var ut=v(null),ot=null;function nu(l){var t=l.alternate;_(bl,bl.current&1),_(ut,l),ot===null&&(t===null||va.current!==null||t.memoizedState!==null)&&(ot=l)}function Qf(l){_(bl,bl.current),_(ut,l),ot===null&&(ot=l)}function R0(l){l.tag===22?(_(bl,bl.current),_(ut,l),ot===null&&(ot=l)):fu()}function fu(){_(bl,bl.current),_(ut,ut.current)}function at(l){T(ut),ot===l&&(ot=null),T(bl)}var bl=v(0);function ke(l){for(var t=l;t!==null;){if(t.tag===13){var u=t.memoizedState;if(u!==null&&(u=u.dehydrated,u===null||wc(u)||Wc(u)))return t}else if(t.tag===19&&(t.memoizedProps.revealOrder==="forwards"||t.memoizedProps.revealOrder==="backwards"||t.memoizedProps.revealOrder==="unstable_legacy-backwards"||t.memoizedProps.revealOrder==="together")){if((t.flags&128)!==0)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}var Gt=0,Y=null,al=null,Tl=null,Ie=!1,ya=!1,ju=!1,Pe=0,Fa=0,ma=null,By=0;function ol(){throw Error(o(321))}function Zf(l,t){if(t===null)return!1;for(var u=0;u<t.length&&u<l.length;u++)if(!lt(l[u],t[u]))return!1;return!0}function Vf(l,t,u,a,e,n){return Gt=n,Y=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,b.H=l===null||l.memoizedState===null?o1:ec,ju=!1,n=u(a,e),ju=!1,ya&&(n=C0(t,u,a,e)),q0(l),n}function q0(l){b.H=Pa;var t=al!==null&&al.next!==null;if(Gt=0,Tl=al=Y=null,Ie=!1,Fa=0,ma=null,t)throw Error(o(300));l===null||El||(l=l.dependencies,l!==null&&Ve(l)&&(El=!0))}function C0(l,t,u,a){Y=l;var e=0;do{if(ya&&(ma=null),Fa=0,ya=!1,25<=e)throw Error(o(301));if(e+=1,Tl=al=null,l.updateQueue!=null){var n=l.updateQueue;n.lastEffect=null,n.events=null,n.stores=null,n.memoCache!=null&&(n.memoCache.index=0)}b.H=g1,n=t(u,a)}while(ya);return n}function Yy(){var l=b.H,t=l.useState()[0];return t=typeof t.then=="function"?ka(t):t,l=l.useState()[0],(al!==null?al.memoizedState:null)!==l&&(Y.flags|=1024),t}function Lf(){var l=Pe!==0;return Pe=0,l}function Kf(l,t,u){t.updateQueue=l.updateQueue,t.flags&=-2053,l.lanes&=~u}function Jf(l){if(Ie){for(l=l.memoizedState;l!==null;){var t=l.queue;t!==null&&(t.pending=null),l=l.next}Ie=!1}Gt=0,Tl=al=Y=null,ya=!1,Fa=Pe=0,ma=null}function Xl(){var l={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Tl===null?Y.memoizedState=Tl=l:Tl=Tl.next=l,Tl}function zl(){if(al===null){var l=Y.alternate;l=l!==null?l.memoizedState:null}else l=al.next;var t=Tl===null?Y.memoizedState:Tl.next;if(t!==null)Tl=t,al=l;else{if(l===null)throw Y.alternate===null?Error(o(467)):Error(o(310));al=l,l={memoizedState:al.memoizedState,baseState:al.baseState,baseQueue:al.baseQueue,queue:al.queue,next:null},Tl===null?Y.memoizedState=Tl=l:Tl=Tl.next=l}return Tl}function ln(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function ka(l){var t=Fa;return Fa+=1,ma===null&&(ma=[]),l=_0(ma,l,t),t=Y,(Tl===null?t.memoizedState:Tl.next)===null&&(t=t.alternate,b.H=t===null||t.memoizedState===null?o1:ec),l}function tn(l){if(l!==null&&typeof l=="object"){if(typeof l.then=="function")return ka(l);if(l.$$typeof===jl)return Cl(l)}throw Error(o(438,String(l)))}function wf(l){var t=null,u=Y.updateQueue;if(u!==null&&(t=u.memoCache),t==null){var a=Y.alternate;a!==null&&(a=a.updateQueue,a!==null&&(a=a.memoCache,a!=null&&(t={data:a.data.map(function(e){return e.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),u===null&&(u=ln(),Y.updateQueue=u),u.memoCache=t,u=t.data[t.index],u===void 0)for(u=t.data[t.index]=Array(l),a=0;a<l;a++)u[a]=Qu;return t.index++,u}function xt(l,t){return typeof t=="function"?t(l):t}function un(l){var t=zl();return Wf(t,al,l)}function Wf(l,t,u){var a=l.queue;if(a===null)throw Error(o(311));a.lastRenderedReducer=u;var e=l.baseQueue,n=a.pending;if(n!==null){if(e!==null){var f=e.next;e.next=n.next,n.next=f}t.baseQueue=e=n,a.pending=null}if(n=l.baseState,e===null)l.memoizedState=n;else{t=e.next;var c=f=null,i=null,d=t,S=!1;do{var r=d.lane&-536870913;if(r!==d.lane?(Z&r)===r:(Gt&r)===r){var h=d.revertLane;if(h===0)i!==null&&(i=i.next={lane:0,revertLane:0,gesture:null,action:d.action,hasEagerState:d.hasEagerState,eagerState:d.eagerState,next:null}),r===fa&&(S=!0);else if((Gt&h)===h){d=d.next,h===fa&&(S=!0);continue}else r={lane:0,revertLane:d.revertLane,gesture:null,action:d.action,hasEagerState:d.hasEagerState,eagerState:d.eagerState,next:null},i===null?(c=i=r,f=n):i=i.next=r,Y.lanes|=h,su|=h;r=d.action,ju&&u(n,r),n=d.hasEagerState?d.eagerState:u(n,r)}else h={lane:r,revertLane:d.revertLane,gesture:d.gesture,action:d.action,hasEagerState:d.hasEagerState,eagerState:d.eagerState,next:null},i===null?(c=i=h,f=n):i=i.next=h,Y.lanes|=r,su|=r;d=d.next}while(d!==null&&d!==t);if(i===null?f=n:i.next=c,!lt(n,l.memoizedState)&&(El=!0,S&&(u=ca,u!==null)))throw u;l.memoizedState=n,l.baseState=f,l.baseQueue=i,a.lastRenderedState=n}return e===null&&(a.lanes=0),[l.memoizedState,a.dispatch]}function $f(l){var t=zl(),u=t.queue;if(u===null)throw Error(o(311));u.lastRenderedReducer=l;var a=u.dispatch,e=u.pending,n=t.memoizedState;if(e!==null){u.pending=null;var f=e=e.next;do n=l(n,f.action),f=f.next;while(f!==e);lt(n,t.memoizedState)||(El=!0),t.memoizedState=n,t.baseQueue===null&&(t.baseState=n),u.lastRenderedState=n}return[n,a]}function B0(l,t,u){var a=Y,e=zl(),n=K;if(n){if(u===void 0)throw Error(o(407));u=u()}else u=t();var f=!lt((al||e).memoizedState,u);if(f&&(e.memoizedState=u,El=!0),e=e.queue,If(G0.bind(null,a,e,l),[l]),e.getSnapshot!==t||f||Tl!==null&&Tl.memoizedState.tag&1){if(a.flags|=2048,da(9,{destroy:void 0},j0.bind(null,a,e,u,t),null),cl===null)throw Error(o(349));n||(Gt&127)!==0||Y0(a,t,u)}return u}function Y0(l,t,u){l.flags|=16384,l={getSnapshot:t,value:u},t=Y.updateQueue,t===null?(t=ln(),Y.updateQueue=t,t.stores=[l]):(u=t.stores,u===null?t.stores=[l]:u.push(l))}function j0(l,t,u,a){t.value=u,t.getSnapshot=a,x0(t)&&X0(l)}function G0(l,t,u){return u(function(){x0(t)&&X0(l)})}function x0(l){var t=l.getSnapshot;l=l.value;try{var u=t();return!lt(l,u)}catch{return!0}}function X0(l){var t=Uu(l,2);t!==null&&Fl(t,l,2)}function Ff(l){var t=Xl();if(typeof l=="function"){var u=l;if(l=u(),ju){$t(!0);try{u()}finally{$t(!1)}}}return t.memoizedState=t.baseState=l,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:xt,lastRenderedState:l},t}function Q0(l,t,u,a){return l.baseState=u,Wf(l,al,typeof a=="function"?a:xt)}function jy(l,t,u,a,e){if(nn(l))throw Error(o(485));if(l=t.action,l!==null){var n={payload:e,action:l,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(f){n.listeners.push(f)}};b.T!==null?u(!0):n.isTransition=!1,a(n),u=t.pending,u===null?(n.next=t.pending=n,Z0(t,n)):(n.next=u.next,t.pending=u.next=n)}}function Z0(l,t){var u=t.action,a=t.payload,e=l.state;if(t.isTransition){var n=b.T,f={};b.T=f;try{var c=u(e,a),i=b.S;i!==null&&i(f,c),V0(l,t,c)}catch(d){kf(l,t,d)}finally{n!==null&&f.types!==null&&(n.types=f.types),b.T=n}}else try{n=u(e,a),V0(l,t,n)}catch(d){kf(l,t,d)}}function V0(l,t,u){u!==null&&typeof u=="object"&&typeof u.then=="function"?u.then(function(a){L0(l,t,a)},function(a){return kf(l,t,a)}):L0(l,t,u)}function L0(l,t,u){t.status="fulfilled",t.value=u,K0(t),l.state=u,t=l.pending,t!==null&&(u=t.next,u===t?l.pending=null:(u=u.next,t.next=u,Z0(l,u)))}function kf(l,t,u){var a=l.pending;if(l.pending=null,a!==null){a=a.next;do t.status="rejected",t.reason=u,K0(t),t=t.next;while(t!==a)}l.action=null}function K0(l){l=l.listeners;for(var t=0;t<l.length;t++)(0,l[t])()}function J0(l,t){return t}function w0(l,t){if(K){var u=cl.formState;if(u!==null){l:{var a=Y;if(K){if(sl){t:{for(var e=sl,n=ht;e.nodeType!==8;){if(!n){e=null;break t}if(e=gt(e.nextSibling),e===null){e=null;break t}}n=e.data,e=n==="F!"||n==="F"?e:null}if(e){sl=gt(e.nextSibling),a=e.data==="F!";break l}}lu(a)}a=!1}a&&(t=u[0])}}return u=Xl(),u.memoizedState=u.baseState=t,a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:J0,lastRenderedState:t},u.queue=a,u=m1.bind(null,Y,a),a.dispatch=u,a=Ff(!1),n=ac.bind(null,Y,!1,a.queue),a=Xl(),e={state:t,dispatch:null,action:l,pending:null},a.queue=e,u=jy.bind(null,Y,e,n,u),e.dispatch=u,a.memoizedState=l,[t,u,!1]}function W0(l){var t=zl();return $0(t,al,l)}function $0(l,t,u){if(t=Wf(l,t,J0)[0],l=un(xt)[0],typeof t=="object"&&t!==null&&typeof t.then=="function")try{var a=ka(t)}catch(f){throw f===ia?Je:f}else a=t;t=zl();var e=t.queue,n=e.dispatch;return u!==t.memoizedState&&(Y.flags|=2048,da(9,{destroy:void 0},Gy.bind(null,e,u),null)),[a,n,l]}function Gy(l,t){l.action=t}function F0(l){var t=zl(),u=al;if(u!==null)return $0(t,u,l);zl(),t=t.memoizedState,u=zl();var a=u.queue.dispatch;return u.memoizedState=l,[t,a,!1]}function da(l,t,u,a){return l={tag:l,create:u,deps:a,inst:t,next:null},t=Y.updateQueue,t===null&&(t=ln(),Y.updateQueue=t),u=t.lastEffect,u===null?t.lastEffect=l.next=l:(a=u.next,u.next=l,l.next=a,t.lastEffect=l),l}function k0(){return zl().memoizedState}function an(l,t,u,a){var e=Xl();Y.flags|=l,e.memoizedState=da(1|t,{destroy:void 0},u,a===void 0?null:a)}function en(l,t,u,a){var e=zl();a=a===void 0?null:a;var n=e.memoizedState.inst;al!==null&&a!==null&&Zf(a,al.memoizedState.deps)?e.memoizedState=da(t,n,u,a):(Y.flags|=l,e.memoizedState=da(1|t,n,u,a))}function I0(l,t){an(8390656,8,l,t)}function If(l,t){en(2048,8,l,t)}function xy(l){Y.flags|=4;var t=Y.updateQueue;if(t===null)t=ln(),Y.updateQueue=t,t.events=[l];else{var u=t.events;u===null?t.events=[l]:u.push(l)}}function P0(l){var t=zl().memoizedState;return xy({ref:t,nextImpl:l}),function(){if((I&2)!==0)throw Error(o(440));return t.impl.apply(void 0,arguments)}}function l1(l,t){return en(4,2,l,t)}function t1(l,t){return en(4,4,l,t)}function u1(l,t){if(typeof t=="function"){l=l();var u=t(l);return function(){typeof u=="function"?u():t(null)}}if(t!=null)return l=l(),t.current=l,function(){t.current=null}}function a1(l,t,u){u=u!=null?u.concat([l]):null,en(4,4,u1.bind(null,t,l),u)}function Pf(){}function e1(l,t){var u=zl();t=t===void 0?null:t;var a=u.memoizedState;return t!==null&&Zf(t,a[1])?a[0]:(u.memoizedState=[l,t],l)}function n1(l,t){var u=zl();t=t===void 0?null:t;var a=u.memoizedState;if(t!==null&&Zf(t,a[1]))return a[0];if(a=l(),ju){$t(!0);try{l()}finally{$t(!1)}}return u.memoizedState=[a,t],a}function lc(l,t,u){return u===void 0||(Gt&1073741824)!==0&&(Z&261930)===0?l.memoizedState=t:(l.memoizedState=u,l=fs(),Y.lanes|=l,su|=l,u)}function f1(l,t,u,a){return lt(u,t)?u:va.current!==null?(l=lc(l,u,a),lt(l,t)||(El=!0),l):(Gt&42)===0||(Gt&1073741824)!==0&&(Z&261930)===0?(El=!0,l.memoizedState=u):(l=fs(),Y.lanes|=l,su|=l,t)}function c1(l,t,u,a,e){var n=A.p;A.p=n!==0&&8>n?n:8;var f=b.T,c={};b.T=c,ac(l,!1,t,u);try{var i=e(),d=b.S;if(d!==null&&d(c,i),i!==null&&typeof i=="object"&&typeof i.then=="function"){var S=Cy(i,a);Ia(l,t,S,ft(l))}else Ia(l,t,a,ft(l))}catch(r){Ia(l,t,{then:function(){},status:"rejected",reason:r},ft())}finally{A.p=n,f!==null&&c.types!==null&&(f.types=c.types),b.T=f}}function Xy(){}function tc(l,t,u,a){if(l.tag!==5)throw Error(o(476));var e=i1(l).queue;c1(l,e,t,q,u===null?Xy:function(){return s1(l),u(a)})}function i1(l){var t=l.memoizedState;if(t!==null)return t;t={memoizedState:q,baseState:q,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:xt,lastRenderedState:q},next:null};var u={};return t.next={memoizedState:u,baseState:u,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:xt,lastRenderedState:u},next:null},l.memoizedState=t,l=l.alternate,l!==null&&(l.memoizedState=t),t}function s1(l){var t=i1(l);t.next===null&&(t=l.alternate.memoizedState),Ia(l,t.next.queue,{},ft())}function uc(){return Cl(oe)}function v1(){return zl().memoizedState}function y1(){return zl().memoizedState}function Qy(l){for(var t=l.return;t!==null;){switch(t.tag){case 24:case 3:var u=ft();l=au(u);var a=eu(t,l,u);a!==null&&(Fl(a,t,u),wa(a,t,u)),t={cache:Hf()},l.payload=t;return}t=t.return}}function Zy(l,t,u){var a=ft();u={lane:a,revertLane:0,gesture:null,action:u,hasEagerState:!1,eagerState:null,next:null},nn(l)?d1(t,u):(u=rf(l,t,u,a),u!==null&&(Fl(u,l,a),h1(u,t,a)))}function m1(l,t,u){var a=ft();Ia(l,t,u,a)}function Ia(l,t,u,a){var e={lane:a,revertLane:0,gesture:null,action:u,hasEagerState:!1,eagerState:null,next:null};if(nn(l))d1(t,e);else{var n=l.alternate;if(l.lanes===0&&(n===null||n.lanes===0)&&(n=t.lastRenderedReducer,n!==null))try{var f=t.lastRenderedState,c=n(f,u);if(e.hasEagerState=!0,e.eagerState=c,lt(c,f))return xe(l,t,e,0),cl===null&&Ge(),!1}catch{}finally{}if(u=rf(l,t,e,a),u!==null)return Fl(u,l,a),h1(u,t,a),!0}return!1}function ac(l,t,u,a){if(a={lane:2,revertLane:Bc(),gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null},nn(l)){if(t)throw Error(o(479))}else t=rf(l,u,a,2),t!==null&&Fl(t,l,2)}function nn(l){var t=l.alternate;return l===Y||t!==null&&t===Y}function d1(l,t){ya=Ie=!0;var u=l.pending;u===null?t.next=t:(t.next=u.next,u.next=t),l.pending=t}function h1(l,t,u){if((u&4194048)!==0){var a=t.lanes;a&=l.pendingLanes,u|=a,t.lanes=u,zi(l,u)}}var Pa={readContext:Cl,use:tn,useCallback:ol,useContext:ol,useEffect:ol,useImperativeHandle:ol,useLayoutEffect:ol,useInsertionEffect:ol,useMemo:ol,useReducer:ol,useRef:ol,useState:ol,useDebugValue:ol,useDeferredValue:ol,useTransition:ol,useSyncExternalStore:ol,useId:ol,useHostTransitionStatus:ol,useFormState:ol,useActionState:ol,useOptimistic:ol,useMemoCache:ol,useCacheRefresh:ol};Pa.useEffectEvent=ol;var o1={readContext:Cl,use:tn,useCallback:function(l,t){return Xl().memoizedState=[l,t===void 0?null:t],l},useContext:Cl,useEffect:I0,useImperativeHandle:function(l,t,u){u=u!=null?u.concat([l]):null,an(4194308,4,u1.bind(null,t,l),u)},useLayoutEffect:function(l,t){return an(4194308,4,l,t)},useInsertionEffect:function(l,t){an(4,2,l,t)},useMemo:function(l,t){var u=Xl();t=t===void 0?null:t;var a=l();if(ju){$t(!0);try{l()}finally{$t(!1)}}return u.memoizedState=[a,t],a},useReducer:function(l,t,u){var a=Xl();if(u!==void 0){var e=u(t);if(ju){$t(!0);try{u(t)}finally{$t(!1)}}}else e=t;return a.memoizedState=a.baseState=e,l={pending:null,lanes:0,dispatch:null,lastRenderedReducer:l,lastRenderedState:e},a.queue=l,l=l.dispatch=Zy.bind(null,Y,l),[a.memoizedState,l]},useRef:function(l){var t=Xl();return l={current:l},t.memoizedState=l},useState:function(l){l=Ff(l);var t=l.queue,u=m1.bind(null,Y,t);return t.dispatch=u,[l.memoizedState,u]},useDebugValue:Pf,useDeferredValue:function(l,t){var u=Xl();return lc(u,l,t)},useTransition:function(){var l=Ff(!1);return l=c1.bind(null,Y,l.queue,!0,!1),Xl().memoizedState=l,[!1,l]},useSyncExternalStore:function(l,t,u){var a=Y,e=Xl();if(K){if(u===void 0)throw Error(o(407));u=u()}else{if(u=t(),cl===null)throw Error(o(349));(Z&127)!==0||Y0(a,t,u)}e.memoizedState=u;var n={value:u,getSnapshot:t};return e.queue=n,I0(G0.bind(null,a,n,l),[l]),a.flags|=2048,da(9,{destroy:void 0},j0.bind(null,a,n,u,t),null),u},useId:function(){var l=Xl(),t=cl.identifierPrefix;if(K){var u=Dt,a=Mt;u=(a&~(1<<32-Pl(a)-1)).toString(32)+u,t="_"+t+"R_"+u,u=Pe++,0<u&&(t+="H"+u.toString(32)),t+="_"}else u=By++,t="_"+t+"r_"+u.toString(32)+"_";return l.memoizedState=t},useHostTransitionStatus:uc,useFormState:w0,useActionState:w0,useOptimistic:function(l){var t=Xl();t.memoizedState=t.baseState=l;var u={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=u,t=ac.bind(null,Y,!0,u),u.dispatch=t,[l,t]},useMemoCache:wf,useCacheRefresh:function(){return Xl().memoizedState=Qy.bind(null,Y)},useEffectEvent:function(l){var t=Xl(),u={impl:l};return t.memoizedState=u,function(){if((I&2)!==0)throw Error(o(440));return u.impl.apply(void 0,arguments)}}},ec={readContext:Cl,use:tn,useCallback:e1,useContext:Cl,useEffect:If,useImperativeHandle:a1,useInsertionEffect:l1,useLayoutEffect:t1,useMemo:n1,useReducer:un,useRef:k0,useState:function(){return un(xt)},useDebugValue:Pf,useDeferredValue:function(l,t){var u=zl();return f1(u,al.memoizedState,l,t)},useTransition:function(){var l=un(xt)[0],t=zl().memoizedState;return[typeof l=="boolean"?l:ka(l),t]},useSyncExternalStore:B0,useId:v1,useHostTransitionStatus:uc,useFormState:W0,useActionState:W0,useOptimistic:function(l,t){var u=zl();return Q0(u,al,l,t)},useMemoCache:wf,useCacheRefresh:y1};ec.useEffectEvent=P0;var g1={readContext:Cl,use:tn,useCallback:e1,useContext:Cl,useEffect:If,useImperativeHandle:a1,useInsertionEffect:l1,useLayoutEffect:t1,useMemo:n1,useReducer:$f,useRef:k0,useState:function(){return $f(xt)},useDebugValue:Pf,useDeferredValue:function(l,t){var u=zl();return al===null?lc(u,l,t):f1(u,al.memoizedState,l,t)},useTransition:function(){var l=$f(xt)[0],t=zl().memoizedState;return[typeof l=="boolean"?l:ka(l),t]},useSyncExternalStore:B0,useId:v1,useHostTransitionStatus:uc,useFormState:F0,useActionState:F0,useOptimistic:function(l,t){var u=zl();return al!==null?Q0(u,al,l,t):(u.baseState=l,[l,u.queue.dispatch])},useMemoCache:wf,useCacheRefresh:y1};g1.useEffectEvent=P0;function nc(l,t,u,a){t=l.memoizedState,u=u(a,t),u=u==null?t:R({},t,u),l.memoizedState=u,l.lanes===0&&(l.updateQueue.baseState=u)}var fc={enqueueSetState:function(l,t,u){l=l._reactInternals;var a=ft(),e=au(a);e.payload=t,u!=null&&(e.callback=u),t=eu(l,e,a),t!==null&&(Fl(t,l,a),wa(t,l,a))},enqueueReplaceState:function(l,t,u){l=l._reactInternals;var a=ft(),e=au(a);e.tag=1,e.payload=t,u!=null&&(e.callback=u),t=eu(l,e,a),t!==null&&(Fl(t,l,a),wa(t,l,a))},enqueueForceUpdate:function(l,t){l=l._reactInternals;var u=ft(),a=au(u);a.tag=2,t!=null&&(a.callback=t),t=eu(l,a,u),t!==null&&(Fl(t,l,u),wa(t,l,u))}};function S1(l,t,u,a,e,n,f){return l=l.stateNode,typeof l.shouldComponentUpdate=="function"?l.shouldComponentUpdate(a,n,f):t.prototype&&t.prototype.isPureReactComponent?!xa(u,a)||!xa(e,n):!0}function b1(l,t,u,a){l=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(u,a),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(u,a),t.state!==l&&fc.enqueueReplaceState(t,t.state,null)}function Gu(l,t){var u=t;if("ref"in t){u={};for(var a in t)a!=="ref"&&(u[a]=t[a])}if(l=l.defaultProps){u===t&&(u=R({},u));for(var e in l)u[e]===void 0&&(u[e]=l[e])}return u}function z1(l){je(l)}function r1(l){console.error(l)}function T1(l){je(l)}function fn(l,t){try{var u=l.onUncaughtError;u(t.value,{componentStack:t.stack})}catch(a){setTimeout(function(){throw a})}}function E1(l,t,u){try{var a=l.onCaughtError;a(u.value,{componentStack:u.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(e){setTimeout(function(){throw e})}}function cc(l,t,u){return u=au(u),u.tag=3,u.payload={element:null},u.callback=function(){fn(l,t)},u}function A1(l){return l=au(l),l.tag=3,l}function _1(l,t,u,a){var e=u.type.getDerivedStateFromError;if(typeof e=="function"){var n=a.value;l.payload=function(){return e(n)},l.callback=function(){E1(t,u,a)}}var f=u.stateNode;f!==null&&typeof f.componentDidCatch=="function"&&(l.callback=function(){E1(t,u,a),typeof e!="function"&&(vu===null?vu=new Set([this]):vu.add(this));var c=a.stack;this.componentDidCatch(a.value,{componentStack:c!==null?c:""})})}function Vy(l,t,u,a,e){if(u.flags|=32768,a!==null&&typeof a=="object"&&typeof a.then=="function"){if(t=u.alternate,t!==null&&na(t,u,e,!0),u=ut.current,u!==null){switch(u.tag){case 31:case 13:return ot===null?zn():u.alternate===null&&gl===0&&(gl=3),u.flags&=-257,u.flags|=65536,u.lanes=e,a===we?u.flags|=16384:(t=u.updateQueue,t===null?u.updateQueue=new Set([a]):t.add(a),Rc(l,a,e)),!1;case 22:return u.flags|=65536,a===we?u.flags|=16384:(t=u.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([a])},u.updateQueue=t):(u=t.retryQueue,u===null?t.retryQueue=new Set([a]):u.add(a)),Rc(l,a,e)),!1}throw Error(o(435,u.tag))}return Rc(l,a,e),zn(),!1}if(K)return t=ut.current,t!==null?((t.flags&65536)===0&&(t.flags|=256),t.flags|=65536,t.lanes=e,a!==Mf&&(l=Error(o(422),{cause:a}),Za(yt(l,u)))):(a!==Mf&&(t=Error(o(423),{cause:a}),Za(yt(t,u))),l=l.current.alternate,l.flags|=65536,e&=-e,l.lanes|=e,a=yt(a,u),e=cc(l.stateNode,a,e),jf(l,e),gl!==4&&(gl=2)),!1;var n=Error(o(520),{cause:a});if(n=yt(n,u),ce===null?ce=[n]:ce.push(n),gl!==4&&(gl=2),t===null)return!0;a=yt(a,u),u=t;do{switch(u.tag){case 3:return u.flags|=65536,l=e&-e,u.lanes|=l,l=cc(u.stateNode,a,l),jf(u,l),!1;case 1:if(t=u.type,n=u.stateNode,(u.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||n!==null&&typeof n.componentDidCatch=="function"&&(vu===null||!vu.has(n))))return u.flags|=65536,e&=-e,u.lanes|=e,e=A1(e),_1(e,l,u,a),jf(u,e),!1}u=u.return}while(u!==null);return!1}var ic=Error(o(461)),El=!1;function Bl(l,t,u,a){t.child=l===null?U0(t,null,u,a):Yu(t,l.child,u,a)}function O1(l,t,u,a,e){u=u.render;var n=t.ref;if("ref"in a){var f={};for(var c in a)c!=="ref"&&(f[c]=a[c])}else f=a;return Ru(t),a=Vf(l,t,u,f,n,e),c=Lf(),l!==null&&!El?(Kf(l,t,e),Xt(l,t,e)):(K&&c&&_f(t),t.flags|=1,Bl(l,t,a,e),t.child)}function M1(l,t,u,a,e){if(l===null){var n=u.type;return typeof n=="function"&&!Tf(n)&&n.defaultProps===void 0&&u.compare===null?(t.tag=15,t.type=n,D1(l,t,n,a,e)):(l=Qe(u.type,null,a,t,t.mode,e),l.ref=t.ref,l.return=t,t.child=l)}if(n=l.child,!gc(l,e)){var f=n.memoizedProps;if(u=u.compare,u=u!==null?u:xa,u(f,a)&&l.ref===t.ref)return Xt(l,t,e)}return t.flags|=1,l=Ct(n,a),l.ref=t.ref,l.return=t,t.child=l}function D1(l,t,u,a,e){if(l!==null){var n=l.memoizedProps;if(xa(n,a)&&l.ref===t.ref)if(El=!1,t.pendingProps=a=n,gc(l,e))(l.flags&131072)!==0&&(El=!0);else return t.lanes=l.lanes,Xt(l,t,e)}return sc(l,t,u,a,e)}function U1(l,t,u,a){var e=a.children,n=l!==null?l.memoizedState:null;if(l===null&&t.stateNode===null&&(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),a.mode==="hidden"){if((t.flags&128)!==0){if(n=n!==null?n.baseLanes|u:u,l!==null){for(a=t.child=l.child,e=0;a!==null;)e=e|a.lanes|a.childLanes,a=a.sibling;a=e&~n}else a=0,t.child=null;return p1(l,t,n,u,a)}if((u&536870912)!==0)t.memoizedState={baseLanes:0,cachePool:null},l!==null&&Ke(t,n!==null?n.cachePool:null),n!==null?H0(t,n):xf(),R0(t);else return a=t.lanes=536870912,p1(l,t,n!==null?n.baseLanes|u:u,u,a)}else n!==null?(Ke(t,n.cachePool),H0(t,n),fu(),t.memoizedState=null):(l!==null&&Ke(t,null),xf(),fu());return Bl(l,t,e,u),t.child}function le(l,t){return l!==null&&l.tag===22||t.stateNode!==null||(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),t.sibling}function p1(l,t,u,a,e){var n=qf();return n=n===null?null:{parent:rl._currentValue,pool:n},t.memoizedState={baseLanes:u,cachePool:n},l!==null&&Ke(t,null),xf(),R0(t),l!==null&&na(l,t,a,!0),t.childLanes=e,null}function cn(l,t){return t=vn({mode:t.mode,children:t.children},l.mode),t.ref=l.ref,l.child=t,t.return=l,t}function N1(l,t,u){return Yu(t,l.child,null,u),l=cn(t,t.pendingProps),l.flags|=2,at(t),t.memoizedState=null,l}function Ly(l,t,u){var a=t.pendingProps,e=(t.flags&128)!==0;if(t.flags&=-129,l===null){if(K){if(a.mode==="hidden")return l=cn(t,a),t.lanes=536870912,le(null,l);if(Qf(t),(l=sl)?(l=Zs(l,ht),l=l!==null&&l.data==="&"?l:null,l!==null&&(t.memoizedState={dehydrated:l,treeContext:It!==null?{id:Mt,overflow:Dt}:null,retryLane:536870912,hydrationErrors:null},u=d0(l),u.return=t,t.child=u,ql=t,sl=null)):l=null,l===null)throw lu(t);return t.lanes=536870912,null}return cn(t,a)}var n=l.memoizedState;if(n!==null){var f=n.dehydrated;if(Qf(t),e)if(t.flags&256)t.flags&=-257,t=N1(l,t,u);else if(t.memoizedState!==null)t.child=l.child,t.flags|=128,t=null;else throw Error(o(558));else if(El||na(l,t,u,!1),e=(u&l.childLanes)!==0,El||e){if(a=cl,a!==null&&(f=ri(a,u),f!==0&&f!==n.retryLane))throw n.retryLane=f,Uu(l,f),Fl(a,l,f),ic;zn(),t=N1(l,t,u)}else l=n.treeContext,sl=gt(f.nextSibling),ql=t,K=!0,Pt=null,ht=!1,l!==null&&g0(t,l),t=cn(t,a),t.flags|=4096;return t}return l=Ct(l.child,{mode:a.mode,children:a.children}),l.ref=t.ref,t.child=l,l.return=t,l}function sn(l,t){var u=t.ref;if(u===null)l!==null&&l.ref!==null&&(t.flags|=4194816);else{if(typeof u!="function"&&typeof u!="object")throw Error(o(284));(l===null||l.ref!==u)&&(t.flags|=4194816)}}function sc(l,t,u,a,e){return Ru(t),u=Vf(l,t,u,a,void 0,e),a=Lf(),l!==null&&!El?(Kf(l,t,e),Xt(l,t,e)):(K&&a&&_f(t),t.flags|=1,Bl(l,t,u,e),t.child)}function H1(l,t,u,a,e,n){return Ru(t),t.updateQueue=null,u=C0(t,a,u,e),q0(l),a=Lf(),l!==null&&!El?(Kf(l,t,n),Xt(l,t,n)):(K&&a&&_f(t),t.flags|=1,Bl(l,t,u,n),t.child)}function R1(l,t,u,a,e){if(Ru(t),t.stateNode===null){var n=ta,f=u.contextType;typeof f=="object"&&f!==null&&(n=Cl(f)),n=new u(a,n),t.memoizedState=n.state!==null&&n.state!==void 0?n.state:null,n.updater=fc,t.stateNode=n,n._reactInternals=t,n=t.stateNode,n.props=a,n.state=t.memoizedState,n.refs={},Bf(t),f=u.contextType,n.context=typeof f=="object"&&f!==null?Cl(f):ta,n.state=t.memoizedState,f=u.getDerivedStateFromProps,typeof f=="function"&&(nc(t,u,f,a),n.state=t.memoizedState),typeof u.getDerivedStateFromProps=="function"||typeof n.getSnapshotBeforeUpdate=="function"||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(f=n.state,typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount(),f!==n.state&&fc.enqueueReplaceState(n,n.state,null),$a(t,a,n,e),Wa(),n.state=t.memoizedState),typeof n.componentDidMount=="function"&&(t.flags|=4194308),a=!0}else if(l===null){n=t.stateNode;var c=t.memoizedProps,i=Gu(u,c);n.props=i;var d=n.context,S=u.contextType;f=ta,typeof S=="object"&&S!==null&&(f=Cl(S));var r=u.getDerivedStateFromProps;S=typeof r=="function"||typeof n.getSnapshotBeforeUpdate=="function",c=t.pendingProps!==c,S||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(c||d!==f)&&b1(t,n,a,f),uu=!1;var h=t.memoizedState;n.state=h,$a(t,a,n,e),Wa(),d=t.memoizedState,c||h!==d||uu?(typeof r=="function"&&(nc(t,u,r,a),d=t.memoizedState),(i=uu||S1(t,u,i,a,h,d,f))?(S||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount()),typeof n.componentDidMount=="function"&&(t.flags|=4194308)):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=a,t.memoizedState=d),n.props=a,n.state=d,n.context=f,a=i):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),a=!1)}else{n=t.stateNode,Yf(l,t),f=t.memoizedProps,S=Gu(u,f),n.props=S,r=t.pendingProps,h=n.context,d=u.contextType,i=ta,typeof d=="object"&&d!==null&&(i=Cl(d)),c=u.getDerivedStateFromProps,(d=typeof c=="function"||typeof n.getSnapshotBeforeUpdate=="function")||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(f!==r||h!==i)&&b1(t,n,a,i),uu=!1,h=t.memoizedState,n.state=h,$a(t,a,n,e),Wa();var g=t.memoizedState;f!==r||h!==g||uu||l!==null&&l.dependencies!==null&&Ve(l.dependencies)?(typeof c=="function"&&(nc(t,u,c,a),g=t.memoizedState),(S=uu||S1(t,u,S,a,h,g,i)||l!==null&&l.dependencies!==null&&Ve(l.dependencies))?(d||typeof n.UNSAFE_componentWillUpdate!="function"&&typeof n.componentWillUpdate!="function"||(typeof n.componentWillUpdate=="function"&&n.componentWillUpdate(a,g,i),typeof n.UNSAFE_componentWillUpdate=="function"&&n.UNSAFE_componentWillUpdate(a,g,i)),typeof n.componentDidUpdate=="function"&&(t.flags|=4),typeof n.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof n.componentDidUpdate!="function"||f===l.memoizedProps&&h===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||f===l.memoizedProps&&h===l.memoizedState||(t.flags|=1024),t.memoizedProps=a,t.memoizedState=g),n.props=a,n.state=g,n.context=i,a=S):(typeof n.componentDidUpdate!="function"||f===l.memoizedProps&&h===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||f===l.memoizedProps&&h===l.memoizedState||(t.flags|=1024),a=!1)}return n=a,sn(l,t),a=(t.flags&128)!==0,n||a?(n=t.stateNode,u=a&&typeof u.getDerivedStateFromError!="function"?null:n.render(),t.flags|=1,l!==null&&a?(t.child=Yu(t,l.child,null,e),t.child=Yu(t,null,u,e)):Bl(l,t,u,e),t.memoizedState=n.state,l=t.child):l=Xt(l,t,e),l}function q1(l,t,u,a){return Nu(),t.flags|=256,Bl(l,t,u,a),t.child}var vc={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function yc(l){return{baseLanes:l,cachePool:E0()}}function mc(l,t,u){return l=l!==null?l.childLanes&~u:0,t&&(l|=nt),l}function C1(l,t,u){var a=t.pendingProps,e=!1,n=(t.flags&128)!==0,f;if((f=n)||(f=l!==null&&l.memoizedState===null?!1:(bl.current&2)!==0),f&&(e=!0,t.flags&=-129),f=(t.flags&32)!==0,t.flags&=-33,l===null){if(K){if(e?nu(t):fu(),(l=sl)?(l=Zs(l,ht),l=l!==null&&l.data!=="&"?l:null,l!==null&&(t.memoizedState={dehydrated:l,treeContext:It!==null?{id:Mt,overflow:Dt}:null,retryLane:536870912,hydrationErrors:null},u=d0(l),u.return=t,t.child=u,ql=t,sl=null)):l=null,l===null)throw lu(t);return Wc(l)?t.lanes=32:t.lanes=536870912,null}var c=a.children;return a=a.fallback,e?(fu(),e=t.mode,c=vn({mode:"hidden",children:c},e),a=pu(a,e,u,null),c.return=t,a.return=t,c.sibling=a,t.child=c,a=t.child,a.memoizedState=yc(u),a.childLanes=mc(l,f,u),t.memoizedState=vc,le(null,a)):(nu(t),dc(t,c))}var i=l.memoizedState;if(i!==null&&(c=i.dehydrated,c!==null)){if(n)t.flags&256?(nu(t),t.flags&=-257,t=hc(l,t,u)):t.memoizedState!==null?(fu(),t.child=l.child,t.flags|=128,t=null):(fu(),c=a.fallback,e=t.mode,a=vn({mode:"visible",children:a.children},e),c=pu(c,e,u,null),c.flags|=2,a.return=t,c.return=t,a.sibling=c,t.child=a,Yu(t,l.child,null,u),a=t.child,a.memoizedState=yc(u),a.childLanes=mc(l,f,u),t.memoizedState=vc,t=le(null,a));else if(nu(t),Wc(c)){if(f=c.nextSibling&&c.nextSibling.dataset,f)var d=f.dgst;f=d,a=Error(o(419)),a.stack="",a.digest=f,Za({value:a,source:null,stack:null}),t=hc(l,t,u)}else if(El||na(l,t,u,!1),f=(u&l.childLanes)!==0,El||f){if(f=cl,f!==null&&(a=ri(f,u),a!==0&&a!==i.retryLane))throw i.retryLane=a,Uu(l,a),Fl(f,l,a),ic;wc(c)||zn(),t=hc(l,t,u)}else wc(c)?(t.flags|=192,t.child=l.child,t=null):(l=i.treeContext,sl=gt(c.nextSibling),ql=t,K=!0,Pt=null,ht=!1,l!==null&&g0(t,l),t=dc(t,a.children),t.flags|=4096);return t}return e?(fu(),c=a.fallback,e=t.mode,i=l.child,d=i.sibling,a=Ct(i,{mode:"hidden",children:a.children}),a.subtreeFlags=i.subtreeFlags&65011712,d!==null?c=Ct(d,c):(c=pu(c,e,u,null),c.flags|=2),c.return=t,a.return=t,a.sibling=c,t.child=a,le(null,a),a=t.child,c=l.child.memoizedState,c===null?c=yc(u):(e=c.cachePool,e!==null?(i=rl._currentValue,e=e.parent!==i?{parent:i,pool:i}:e):e=E0(),c={baseLanes:c.baseLanes|u,cachePool:e}),a.memoizedState=c,a.childLanes=mc(l,f,u),t.memoizedState=vc,le(l.child,a)):(nu(t),u=l.child,l=u.sibling,u=Ct(u,{mode:"visible",children:a.children}),u.return=t,u.sibling=null,l!==null&&(f=t.deletions,f===null?(t.deletions=[l],t.flags|=16):f.push(l)),t.child=u,t.memoizedState=null,u)}function dc(l,t){return t=vn({mode:"visible",children:t},l.mode),t.return=l,l.child=t}function vn(l,t){return l=tt(22,l,null,t),l.lanes=0,l}function hc(l,t,u){return Yu(t,l.child,null,u),l=dc(t,t.pendingProps.children),l.flags|=2,t.memoizedState=null,l}function B1(l,t,u){l.lanes|=t;var a=l.alternate;a!==null&&(a.lanes|=t),pf(l.return,t,u)}function oc(l,t,u,a,e,n){var f=l.memoizedState;f===null?l.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:a,tail:u,tailMode:e,treeForkCount:n}:(f.isBackwards=t,f.rendering=null,f.renderingStartTime=0,f.last=a,f.tail=u,f.tailMode=e,f.treeForkCount=n)}function Y1(l,t,u){var a=t.pendingProps,e=a.revealOrder,n=a.tail;a=a.children;var f=bl.current,c=(f&2)!==0;if(c?(f=f&1|2,t.flags|=128):f&=1,_(bl,f),Bl(l,t,a,u),a=K?Qa:0,!c&&l!==null&&(l.flags&128)!==0)l:for(l=t.child;l!==null;){if(l.tag===13)l.memoizedState!==null&&B1(l,u,t);else if(l.tag===19)B1(l,u,t);else if(l.child!==null){l.child.return=l,l=l.child;continue}if(l===t)break l;for(;l.sibling===null;){if(l.return===null||l.return===t)break l;l=l.return}l.sibling.return=l.return,l=l.sibling}switch(e){case"forwards":for(u=t.child,e=null;u!==null;)l=u.alternate,l!==null&&ke(l)===null&&(e=u),u=u.sibling;u=e,u===null?(e=t.child,t.child=null):(e=u.sibling,u.sibling=null),oc(t,!1,e,u,n,a);break;case"backwards":case"unstable_legacy-backwards":for(u=null,e=t.child,t.child=null;e!==null;){if(l=e.alternate,l!==null&&ke(l)===null){t.child=e;break}l=e.sibling,e.sibling=u,u=e,e=l}oc(t,!0,u,null,n,a);break;case"together":oc(t,!1,null,null,void 0,a);break;default:t.memoizedState=null}return t.child}function Xt(l,t,u){if(l!==null&&(t.dependencies=l.dependencies),su|=t.lanes,(u&t.childLanes)===0)if(l!==null){if(na(l,t,u,!1),(u&t.childLanes)===0)return null}else return null;if(l!==null&&t.child!==l.child)throw Error(o(153));if(t.child!==null){for(l=t.child,u=Ct(l,l.pendingProps),t.child=u,u.return=t;l.sibling!==null;)l=l.sibling,u=u.sibling=Ct(l,l.pendingProps),u.return=t;u.sibling=null}return t.child}function gc(l,t){return(l.lanes&t)!==0?!0:(l=l.dependencies,!!(l!==null&&Ve(l)))}function Ky(l,t,u){switch(t.tag){case 3:xl(t,t.stateNode.containerInfo),tu(t,rl,l.memoizedState.cache),Nu();break;case 27:case 5:Ma(t);break;case 4:xl(t,t.stateNode.containerInfo);break;case 10:tu(t,t.type,t.memoizedProps.value);break;case 31:if(t.memoizedState!==null)return t.flags|=128,Qf(t),null;break;case 13:var a=t.memoizedState;if(a!==null)return a.dehydrated!==null?(nu(t),t.flags|=128,null):(u&t.child.childLanes)!==0?C1(l,t,u):(nu(t),l=Xt(l,t,u),l!==null?l.sibling:null);nu(t);break;case 19:var e=(l.flags&128)!==0;if(a=(u&t.childLanes)!==0,a||(na(l,t,u,!1),a=(u&t.childLanes)!==0),e){if(a)return Y1(l,t,u);t.flags|=128}if(e=t.memoizedState,e!==null&&(e.rendering=null,e.tail=null,e.lastEffect=null),_(bl,bl.current),a)break;return null;case 22:return t.lanes=0,U1(l,t,u,t.pendingProps);case 24:tu(t,rl,l.memoizedState.cache)}return Xt(l,t,u)}function j1(l,t,u){if(l!==null)if(l.memoizedProps!==t.pendingProps)El=!0;else{if(!gc(l,u)&&(t.flags&128)===0)return El=!1,Ky(l,t,u);El=(l.flags&131072)!==0}else El=!1,K&&(t.flags&1048576)!==0&&o0(t,Qa,t.index);switch(t.lanes=0,t.tag){case 16:l:{var a=t.pendingProps;if(l=Cu(t.elementType),t.type=l,typeof l=="function")Tf(l)?(a=Gu(l,a),t.tag=1,t=R1(null,t,l,a,u)):(t.tag=0,t=sc(null,t,l,a,u));else{if(l!=null){var e=l.$$typeof;if(e===ct){t.tag=11,t=O1(null,t,l,a,u);break l}else if(e===L){t.tag=14,t=M1(null,t,l,a,u);break l}}throw t=Nt(l)||l,Error(o(306,t,""))}}return t;case 0:return sc(l,t,t.type,t.pendingProps,u);case 1:return a=t.type,e=Gu(a,t.pendingProps),R1(l,t,a,e,u);case 3:l:{if(xl(t,t.stateNode.containerInfo),l===null)throw Error(o(387));a=t.pendingProps;var n=t.memoizedState;e=n.element,Yf(l,t),$a(t,a,null,u);var f=t.memoizedState;if(a=f.cache,tu(t,rl,a),a!==n.cache&&Nf(t,[rl],u,!0),Wa(),a=f.element,n.isDehydrated)if(n={element:a,isDehydrated:!1,cache:f.cache},t.updateQueue.baseState=n,t.memoizedState=n,t.flags&256){t=q1(l,t,a,u);break l}else if(a!==e){e=yt(Error(o(424)),t),Za(e),t=q1(l,t,a,u);break l}else{switch(l=t.stateNode.containerInfo,l.nodeType){case 9:l=l.body;break;default:l=l.nodeName==="HTML"?l.ownerDocument.body:l}for(sl=gt(l.firstChild),ql=t,K=!0,Pt=null,ht=!0,u=U0(t,null,a,u),t.child=u;u;)u.flags=u.flags&-3|4096,u=u.sibling}else{if(Nu(),a===e){t=Xt(l,t,u);break l}Bl(l,t,a,u)}t=t.child}return t;case 26:return sn(l,t),l===null?(u=Ws(t.type,null,t.pendingProps,null))?t.memoizedState=u:K||(u=t.type,l=t.pendingProps,a=Mn(x.current).createElement(u),a[Rl]=t,a[Ll]=l,Yl(a,u,l),pl(a),t.stateNode=a):t.memoizedState=Ws(t.type,l.memoizedProps,t.pendingProps,l.memoizedState),null;case 27:return Ma(t),l===null&&K&&(a=t.stateNode=Ks(t.type,t.pendingProps,x.current),ql=t,ht=!0,e=sl,hu(t.type)?($c=e,sl=gt(a.firstChild)):sl=e),Bl(l,t,t.pendingProps.children,u),sn(l,t),l===null&&(t.flags|=4194304),t.child;case 5:return l===null&&K&&((e=a=sl)&&(a=Tm(a,t.type,t.pendingProps,ht),a!==null?(t.stateNode=a,ql=t,sl=gt(a.firstChild),ht=!1,e=!0):e=!1),e||lu(t)),Ma(t),e=t.type,n=t.pendingProps,f=l!==null?l.memoizedProps:null,a=n.children,Lc(e,n)?a=null:f!==null&&Lc(e,f)&&(t.flags|=32),t.memoizedState!==null&&(e=Vf(l,t,Yy,null,null,u),oe._currentValue=e),sn(l,t),Bl(l,t,a,u),t.child;case 6:return l===null&&K&&((l=u=sl)&&(u=Em(u,t.pendingProps,ht),u!==null?(t.stateNode=u,ql=t,sl=null,l=!0):l=!1),l||lu(t)),null;case 13:return C1(l,t,u);case 4:return xl(t,t.stateNode.containerInfo),a=t.pendingProps,l===null?t.child=Yu(t,null,a,u):Bl(l,t,a,u),t.child;case 11:return O1(l,t,t.type,t.pendingProps,u);case 7:return Bl(l,t,t.pendingProps,u),t.child;case 8:return Bl(l,t,t.pendingProps.children,u),t.child;case 12:return Bl(l,t,t.pendingProps.children,u),t.child;case 10:return a=t.pendingProps,tu(t,t.type,a.value),Bl(l,t,a.children,u),t.child;case 9:return e=t.type._context,a=t.pendingProps.children,Ru(t),e=Cl(e),a=a(e),t.flags|=1,Bl(l,t,a,u),t.child;case 14:return M1(l,t,t.type,t.pendingProps,u);case 15:return D1(l,t,t.type,t.pendingProps,u);case 19:return Y1(l,t,u);case 31:return Ly(l,t,u);case 22:return U1(l,t,u,t.pendingProps);case 24:return Ru(t),a=Cl(rl),l===null?(e=qf(),e===null&&(e=cl,n=Hf(),e.pooledCache=n,n.refCount++,n!==null&&(e.pooledCacheLanes|=u),e=n),t.memoizedState={parent:a,cache:e},Bf(t),tu(t,rl,e)):((l.lanes&u)!==0&&(Yf(l,t),$a(t,null,null,u),Wa()),e=l.memoizedState,n=t.memoizedState,e.parent!==a?(e={parent:a,cache:a},t.memoizedState=e,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=e),tu(t,rl,a)):(a=n.cache,tu(t,rl,a),a!==e.cache&&Nf(t,[rl],u,!0))),Bl(l,t,t.pendingProps.children,u),t.child;case 29:throw t.pendingProps}throw Error(o(156,t.tag))}function Qt(l){l.flags|=4}function Sc(l,t,u,a,e){if((t=(l.mode&32)!==0)&&(t=!1),t){if(l.flags|=16777216,(e&335544128)===e)if(l.stateNode.complete)l.flags|=8192;else if(vs())l.flags|=8192;else throw Bu=we,Cf}else l.flags&=-16777217}function G1(l,t){if(t.type!=="stylesheet"||(t.state.loading&4)!==0)l.flags&=-16777217;else if(l.flags|=16777216,!Ps(t))if(vs())l.flags|=8192;else throw Bu=we,Cf}function yn(l,t){t!==null&&(l.flags|=4),l.flags&16384&&(t=l.tag!==22?Si():536870912,l.lanes|=t,Sa|=t)}function te(l,t){if(!K)switch(l.tailMode){case"hidden":t=l.tail;for(var u=null;t!==null;)t.alternate!==null&&(u=t),t=t.sibling;u===null?l.tail=null:u.sibling=null;break;case"collapsed":u=l.tail;for(var a=null;u!==null;)u.alternate!==null&&(a=u),u=u.sibling;a===null?t||l.tail===null?l.tail=null:l.tail.sibling=null:a.sibling=null}}function vl(l){var t=l.alternate!==null&&l.alternate.child===l.child,u=0,a=0;if(t)for(var e=l.child;e!==null;)u|=e.lanes|e.childLanes,a|=e.subtreeFlags&65011712,a|=e.flags&65011712,e.return=l,e=e.sibling;else for(e=l.child;e!==null;)u|=e.lanes|e.childLanes,a|=e.subtreeFlags,a|=e.flags,e.return=l,e=e.sibling;return l.subtreeFlags|=a,l.childLanes=u,t}function Jy(l,t,u){var a=t.pendingProps;switch(Of(t),t.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return vl(t),null;case 1:return vl(t),null;case 3:return u=t.stateNode,a=null,l!==null&&(a=l.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),jt(rl),Sl(),u.pendingContext&&(u.context=u.pendingContext,u.pendingContext=null),(l===null||l.child===null)&&(ea(t)?Qt(t):l===null||l.memoizedState.isDehydrated&&(t.flags&256)===0||(t.flags|=1024,Df())),vl(t),null;case 26:var e=t.type,n=t.memoizedState;return l===null?(Qt(t),n!==null?(vl(t),G1(t,n)):(vl(t),Sc(t,e,null,a,u))):n?n!==l.memoizedState?(Qt(t),vl(t),G1(t,n)):(vl(t),t.flags&=-16777217):(l=l.memoizedProps,l!==a&&Qt(t),vl(t),Sc(t,e,l,a,u)),null;case 27:if(Te(t),u=x.current,e=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==a&&Qt(t);else{if(!a){if(t.stateNode===null)throw Error(o(166));return vl(t),null}l=D.current,ea(t)?S0(t):(l=Ks(e,a,u),t.stateNode=l,Qt(t))}return vl(t),null;case 5:if(Te(t),e=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==a&&Qt(t);else{if(!a){if(t.stateNode===null)throw Error(o(166));return vl(t),null}if(n=D.current,ea(t))S0(t);else{var f=Mn(x.current);switch(n){case 1:n=f.createElementNS("http://www.w3.org/2000/svg",e);break;case 2:n=f.createElementNS("http://www.w3.org/1998/Math/MathML",e);break;default:switch(e){case"svg":n=f.createElementNS("http://www.w3.org/2000/svg",e);break;case"math":n=f.createElementNS("http://www.w3.org/1998/Math/MathML",e);break;case"script":n=f.createElement("div"),n.innerHTML="<script><\/script>",n=n.removeChild(n.firstChild);break;case"select":n=typeof a.is=="string"?f.createElement("select",{is:a.is}):f.createElement("select"),a.multiple?n.multiple=!0:a.size&&(n.size=a.size);break;default:n=typeof a.is=="string"?f.createElement(e,{is:a.is}):f.createElement(e)}}n[Rl]=t,n[Ll]=a;l:for(f=t.child;f!==null;){if(f.tag===5||f.tag===6)n.appendChild(f.stateNode);else if(f.tag!==4&&f.tag!==27&&f.child!==null){f.child.return=f,f=f.child;continue}if(f===t)break l;for(;f.sibling===null;){if(f.return===null||f.return===t)break l;f=f.return}f.sibling.return=f.return,f=f.sibling}t.stateNode=n;l:switch(Yl(n,e,a),e){case"button":case"input":case"select":case"textarea":a=!!a.autoFocus;break l;case"img":a=!0;break l;default:a=!1}a&&Qt(t)}}return vl(t),Sc(t,t.type,l===null?null:l.memoizedProps,t.pendingProps,u),null;case 6:if(l&&t.stateNode!=null)l.memoizedProps!==a&&Qt(t);else{if(typeof a!="string"&&t.stateNode===null)throw Error(o(166));if(l=x.current,ea(t)){if(l=t.stateNode,u=t.memoizedProps,a=null,e=ql,e!==null)switch(e.tag){case 27:case 5:a=e.memoizedProps}l[Rl]=t,l=!!(l.nodeValue===u||a!==null&&a.suppressHydrationWarning===!0||Cs(l.nodeValue,u)),l||lu(t,!0)}else l=Mn(l).createTextNode(a),l[Rl]=t,t.stateNode=l}return vl(t),null;case 31:if(u=t.memoizedState,l===null||l.memoizedState!==null){if(a=ea(t),u!==null){if(l===null){if(!a)throw Error(o(318));if(l=t.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(o(557));l[Rl]=t}else Nu(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;vl(t),l=!1}else u=Df(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=u),l=!0;if(!l)return t.flags&256?(at(t),t):(at(t),null);if((t.flags&128)!==0)throw Error(o(558))}return vl(t),null;case 13:if(a=t.memoizedState,l===null||l.memoizedState!==null&&l.memoizedState.dehydrated!==null){if(e=ea(t),a!==null&&a.dehydrated!==null){if(l===null){if(!e)throw Error(o(318));if(e=t.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(o(317));e[Rl]=t}else Nu(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;vl(t),e=!1}else e=Df(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=e),e=!0;if(!e)return t.flags&256?(at(t),t):(at(t),null)}return at(t),(t.flags&128)!==0?(t.lanes=u,t):(u=a!==null,l=l!==null&&l.memoizedState!==null,u&&(a=t.child,e=null,a.alternate!==null&&a.alternate.memoizedState!==null&&a.alternate.memoizedState.cachePool!==null&&(e=a.alternate.memoizedState.cachePool.pool),n=null,a.memoizedState!==null&&a.memoizedState.cachePool!==null&&(n=a.memoizedState.cachePool.pool),n!==e&&(a.flags|=2048)),u!==l&&u&&(t.child.flags|=8192),yn(t,t.updateQueue),vl(t),null);case 4:return Sl(),l===null&&xc(t.stateNode.containerInfo),vl(t),null;case 10:return jt(t.type),vl(t),null;case 19:if(T(bl),a=t.memoizedState,a===null)return vl(t),null;if(e=(t.flags&128)!==0,n=a.rendering,n===null)if(e)te(a,!1);else{if(gl!==0||l!==null&&(l.flags&128)!==0)for(l=t.child;l!==null;){if(n=ke(l),n!==null){for(t.flags|=128,te(a,!1),l=n.updateQueue,t.updateQueue=l,yn(t,l),t.subtreeFlags=0,l=u,u=t.child;u!==null;)m0(u,l),u=u.sibling;return _(bl,bl.current&1|2),K&&Bt(t,a.treeForkCount),t.child}l=l.sibling}a.tail!==null&&kl()>gn&&(t.flags|=128,e=!0,te(a,!1),t.lanes=4194304)}else{if(!e)if(l=ke(n),l!==null){if(t.flags|=128,e=!0,l=l.updateQueue,t.updateQueue=l,yn(t,l),te(a,!0),a.tail===null&&a.tailMode==="hidden"&&!n.alternate&&!K)return vl(t),null}else 2*kl()-a.renderingStartTime>gn&&u!==536870912&&(t.flags|=128,e=!0,te(a,!1),t.lanes=4194304);a.isBackwards?(n.sibling=t.child,t.child=n):(l=a.last,l!==null?l.sibling=n:t.child=n,a.last=n)}return a.tail!==null?(l=a.tail,a.rendering=l,a.tail=l.sibling,a.renderingStartTime=kl(),l.sibling=null,u=bl.current,_(bl,e?u&1|2:u&1),K&&Bt(t,a.treeForkCount),l):(vl(t),null);case 22:case 23:return at(t),Xf(),a=t.memoizedState!==null,l!==null?l.memoizedState!==null!==a&&(t.flags|=8192):a&&(t.flags|=8192),a?(u&536870912)!==0&&(t.flags&128)===0&&(vl(t),t.subtreeFlags&6&&(t.flags|=8192)):vl(t),u=t.updateQueue,u!==null&&yn(t,u.retryQueue),u=null,l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(u=l.memoizedState.cachePool.pool),a=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(a=t.memoizedState.cachePool.pool),a!==u&&(t.flags|=2048),l!==null&&T(qu),null;case 24:return u=null,l!==null&&(u=l.memoizedState.cache),t.memoizedState.cache!==u&&(t.flags|=2048),jt(rl),vl(t),null;case 25:return null;case 30:return null}throw Error(o(156,t.tag))}function wy(l,t){switch(Of(t),t.tag){case 1:return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 3:return jt(rl),Sl(),l=t.flags,(l&65536)!==0&&(l&128)===0?(t.flags=l&-65537|128,t):null;case 26:case 27:case 5:return Te(t),null;case 31:if(t.memoizedState!==null){if(at(t),t.alternate===null)throw Error(o(340));Nu()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 13:if(at(t),l=t.memoizedState,l!==null&&l.dehydrated!==null){if(t.alternate===null)throw Error(o(340));Nu()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 19:return T(bl),null;case 4:return Sl(),null;case 10:return jt(t.type),null;case 22:case 23:return at(t),Xf(),l!==null&&T(qu),l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 24:return jt(rl),null;case 25:return null;default:return null}}function x1(l,t){switch(Of(t),t.tag){case 3:jt(rl),Sl();break;case 26:case 27:case 5:Te(t);break;case 4:Sl();break;case 31:t.memoizedState!==null&&at(t);break;case 13:at(t);break;case 19:T(bl);break;case 10:jt(t.type);break;case 22:case 23:at(t),Xf(),l!==null&&T(qu);break;case 24:jt(rl)}}function ue(l,t){try{var u=t.updateQueue,a=u!==null?u.lastEffect:null;if(a!==null){var e=a.next;u=e;do{if((u.tag&l)===l){a=void 0;var n=u.create,f=u.inst;a=n(),f.destroy=a}u=u.next}while(u!==e)}}catch(c){tl(t,t.return,c)}}function cu(l,t,u){try{var a=t.updateQueue,e=a!==null?a.lastEffect:null;if(e!==null){var n=e.next;a=n;do{if((a.tag&l)===l){var f=a.inst,c=f.destroy;if(c!==void 0){f.destroy=void 0,e=t;var i=u,d=c;try{d()}catch(S){tl(e,i,S)}}}a=a.next}while(a!==n)}}catch(S){tl(t,t.return,S)}}function X1(l){var t=l.updateQueue;if(t!==null){var u=l.stateNode;try{N0(t,u)}catch(a){tl(l,l.return,a)}}}function Q1(l,t,u){u.props=Gu(l.type,l.memoizedProps),u.state=l.memoizedState;try{u.componentWillUnmount()}catch(a){tl(l,t,a)}}function ae(l,t){try{var u=l.ref;if(u!==null){switch(l.tag){case 26:case 27:case 5:var a=l.stateNode;break;case 30:a=l.stateNode;break;default:a=l.stateNode}typeof u=="function"?l.refCleanup=u(a):u.current=a}}catch(e){tl(l,t,e)}}function Ut(l,t){var u=l.ref,a=l.refCleanup;if(u!==null)if(typeof a=="function")try{a()}catch(e){tl(l,t,e)}finally{l.refCleanup=null,l=l.alternate,l!=null&&(l.refCleanup=null)}else if(typeof u=="function")try{u(null)}catch(e){tl(l,t,e)}else u.current=null}function Z1(l){var t=l.type,u=l.memoizedProps,a=l.stateNode;try{l:switch(t){case"button":case"input":case"select":case"textarea":u.autoFocus&&a.focus();break l;case"img":u.src?a.src=u.src:u.srcSet&&(a.srcset=u.srcSet)}}catch(e){tl(l,l.return,e)}}function bc(l,t,u){try{var a=l.stateNode;om(a,l.type,u,t),a[Ll]=t}catch(e){tl(l,l.return,e)}}function V1(l){return l.tag===5||l.tag===3||l.tag===26||l.tag===27&&hu(l.type)||l.tag===4}function zc(l){l:for(;;){for(;l.sibling===null;){if(l.return===null||V1(l.return))return null;l=l.return}for(l.sibling.return=l.return,l=l.sibling;l.tag!==5&&l.tag!==6&&l.tag!==18;){if(l.tag===27&&hu(l.type)||l.flags&2||l.child===null||l.tag===4)continue l;l.child.return=l,l=l.child}if(!(l.flags&2))return l.stateNode}}function rc(l,t,u){var a=l.tag;if(a===5||a===6)l=l.stateNode,t?(u.nodeType===9?u.body:u.nodeName==="HTML"?u.ownerDocument.body:u).insertBefore(l,t):(t=u.nodeType===9?u.body:u.nodeName==="HTML"?u.ownerDocument.body:u,t.appendChild(l),u=u._reactRootContainer,u!=null||t.onclick!==null||(t.onclick=Rt));else if(a!==4&&(a===27&&hu(l.type)&&(u=l.stateNode,t=null),l=l.child,l!==null))for(rc(l,t,u),l=l.sibling;l!==null;)rc(l,t,u),l=l.sibling}function mn(l,t,u){var a=l.tag;if(a===5||a===6)l=l.stateNode,t?u.insertBefore(l,t):u.appendChild(l);else if(a!==4&&(a===27&&hu(l.type)&&(u=l.stateNode),l=l.child,l!==null))for(mn(l,t,u),l=l.sibling;l!==null;)mn(l,t,u),l=l.sibling}function L1(l){var t=l.stateNode,u=l.memoizedProps;try{for(var a=l.type,e=t.attributes;e.length;)t.removeAttributeNode(e[0]);Yl(t,a,u),t[Rl]=l,t[Ll]=u}catch(n){tl(l,l.return,n)}}var Zt=!1,Al=!1,Tc=!1,K1=typeof WeakSet=="function"?WeakSet:Set,Nl=null;function Wy(l,t){if(l=l.containerInfo,Zc=qn,l=a0(l),hf(l)){if("selectionStart"in l)var u={start:l.selectionStart,end:l.selectionEnd};else l:{u=(u=l.ownerDocument)&&u.defaultView||window;var a=u.getSelection&&u.getSelection();if(a&&a.rangeCount!==0){u=a.anchorNode;var e=a.anchorOffset,n=a.focusNode;a=a.focusOffset;try{u.nodeType,n.nodeType}catch{u=null;break l}var f=0,c=-1,i=-1,d=0,S=0,r=l,h=null;t:for(;;){for(var g;r!==u||e!==0&&r.nodeType!==3||(c=f+e),r!==n||a!==0&&r.nodeType!==3||(i=f+a),r.nodeType===3&&(f+=r.nodeValue.length),(g=r.firstChild)!==null;)h=r,r=g;for(;;){if(r===l)break t;if(h===u&&++d===e&&(c=f),h===n&&++S===a&&(i=f),(g=r.nextSibling)!==null)break;r=h,h=r.parentNode}r=g}u=c===-1||i===-1?null:{start:c,end:i}}else u=null}u=u||{start:0,end:0}}else u=null;for(Vc={focusedElem:l,selectionRange:u},qn=!1,Nl=t;Nl!==null;)if(t=Nl,l=t.child,(t.subtreeFlags&1028)!==0&&l!==null)l.return=t,Nl=l;else for(;Nl!==null;){switch(t=Nl,n=t.alternate,l=t.flags,t.tag){case 0:if((l&4)!==0&&(l=t.updateQueue,l=l!==null?l.events:null,l!==null))for(u=0;u<l.length;u++)e=l[u],e.ref.impl=e.nextImpl;break;case 11:case 15:break;case 1:if((l&1024)!==0&&n!==null){l=void 0,u=t,e=n.memoizedProps,n=n.memoizedState,a=u.stateNode;try{var O=Gu(u.type,e);l=a.getSnapshotBeforeUpdate(O,n),a.__reactInternalSnapshotBeforeUpdate=l}catch(H){tl(u,u.return,H)}}break;case 3:if((l&1024)!==0){if(l=t.stateNode.containerInfo,u=l.nodeType,u===9)Jc(l);else if(u===1)switch(l.nodeName){case"HEAD":case"HTML":case"BODY":Jc(l);break;default:l.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((l&1024)!==0)throw Error(o(163))}if(l=t.sibling,l!==null){l.return=t.return,Nl=l;break}Nl=t.return}}function J1(l,t,u){var a=u.flags;switch(u.tag){case 0:case 11:case 15:Lt(l,u),a&4&&ue(5,u);break;case 1:if(Lt(l,u),a&4)if(l=u.stateNode,t===null)try{l.componentDidMount()}catch(f){tl(u,u.return,f)}else{var e=Gu(u.type,t.memoizedProps);t=t.memoizedState;try{l.componentDidUpdate(e,t,l.__reactInternalSnapshotBeforeUpdate)}catch(f){tl(u,u.return,f)}}a&64&&X1(u),a&512&&ae(u,u.return);break;case 3:if(Lt(l,u),a&64&&(l=u.updateQueue,l!==null)){if(t=null,u.child!==null)switch(u.child.tag){case 27:case 5:t=u.child.stateNode;break;case 1:t=u.child.stateNode}try{N0(l,t)}catch(f){tl(u,u.return,f)}}break;case 27:t===null&&a&4&&L1(u);case 26:case 5:Lt(l,u),t===null&&a&4&&Z1(u),a&512&&ae(u,u.return);break;case 12:Lt(l,u);break;case 31:Lt(l,u),a&4&&$1(l,u);break;case 13:Lt(l,u),a&4&&F1(l,u),a&64&&(l=u.memoizedState,l!==null&&(l=l.dehydrated,l!==null&&(u=am.bind(null,u),Am(l,u))));break;case 22:if(a=u.memoizedState!==null||Zt,!a){t=t!==null&&t.memoizedState!==null||Al,e=Zt;var n=Al;Zt=a,(Al=t)&&!n?Kt(l,u,(u.subtreeFlags&8772)!==0):Lt(l,u),Zt=e,Al=n}break;case 30:break;default:Lt(l,u)}}function w1(l){var t=l.alternate;t!==null&&(l.alternate=null,w1(t)),l.child=null,l.deletions=null,l.sibling=null,l.tag===5&&(t=l.stateNode,t!==null&&Fn(t)),l.stateNode=null,l.return=null,l.dependencies=null,l.memoizedProps=null,l.memoizedState=null,l.pendingProps=null,l.stateNode=null,l.updateQueue=null}var dl=null,Jl=!1;function Vt(l,t,u){for(u=u.child;u!==null;)W1(l,t,u),u=u.sibling}function W1(l,t,u){if(Il&&typeof Il.onCommitFiberUnmount=="function")try{Il.onCommitFiberUnmount(Da,u)}catch{}switch(u.tag){case 26:Al||Ut(u,t),Vt(l,t,u),u.memoizedState?u.memoizedState.count--:u.stateNode&&(u=u.stateNode,u.parentNode.removeChild(u));break;case 27:Al||Ut(u,t);var a=dl,e=Jl;hu(u.type)&&(dl=u.stateNode,Jl=!1),Vt(l,t,u),me(u.stateNode),dl=a,Jl=e;break;case 5:Al||Ut(u,t);case 6:if(a=dl,e=Jl,dl=null,Vt(l,t,u),dl=a,Jl=e,dl!==null)if(Jl)try{(dl.nodeType===9?dl.body:dl.nodeName==="HTML"?dl.ownerDocument.body:dl).removeChild(u.stateNode)}catch(n){tl(u,t,n)}else try{dl.removeChild(u.stateNode)}catch(n){tl(u,t,n)}break;case 18:dl!==null&&(Jl?(l=dl,Xs(l.nodeType===9?l.body:l.nodeName==="HTML"?l.ownerDocument.body:l,u.stateNode),Oa(l)):Xs(dl,u.stateNode));break;case 4:a=dl,e=Jl,dl=u.stateNode.containerInfo,Jl=!0,Vt(l,t,u),dl=a,Jl=e;break;case 0:case 11:case 14:case 15:cu(2,u,t),Al||cu(4,u,t),Vt(l,t,u);break;case 1:Al||(Ut(u,t),a=u.stateNode,typeof a.componentWillUnmount=="function"&&Q1(u,t,a)),Vt(l,t,u);break;case 21:Vt(l,t,u);break;case 22:Al=(a=Al)||u.memoizedState!==null,Vt(l,t,u),Al=a;break;default:Vt(l,t,u)}}function $1(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null))){l=l.dehydrated;try{Oa(l)}catch(u){tl(t,t.return,u)}}}function F1(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null&&(l=l.dehydrated,l!==null))))try{Oa(l)}catch(u){tl(t,t.return,u)}}function $y(l){switch(l.tag){case 31:case 13:case 19:var t=l.stateNode;return t===null&&(t=l.stateNode=new K1),t;case 22:return l=l.stateNode,t=l._retryCache,t===null&&(t=l._retryCache=new K1),t;default:throw Error(o(435,l.tag))}}function dn(l,t){var u=$y(l);t.forEach(function(a){if(!u.has(a)){u.add(a);var e=em.bind(null,l,a);a.then(e,e)}})}function wl(l,t){var u=t.deletions;if(u!==null)for(var a=0;a<u.length;a++){var e=u[a],n=l,f=t,c=f;l:for(;c!==null;){switch(c.tag){case 27:if(hu(c.type)){dl=c.stateNode,Jl=!1;break l}break;case 5:dl=c.stateNode,Jl=!1;break l;case 3:case 4:dl=c.stateNode.containerInfo,Jl=!0;break l}c=c.return}if(dl===null)throw Error(o(160));W1(n,f,e),dl=null,Jl=!1,n=e.alternate,n!==null&&(n.return=null),e.return=null}if(t.subtreeFlags&13886)for(t=t.child;t!==null;)k1(t,l),t=t.sibling}var rt=null;function k1(l,t){var u=l.alternate,a=l.flags;switch(l.tag){case 0:case 11:case 14:case 15:wl(t,l),Wl(l),a&4&&(cu(3,l,l.return),ue(3,l),cu(5,l,l.return));break;case 1:wl(t,l),Wl(l),a&512&&(Al||u===null||Ut(u,u.return)),a&64&&Zt&&(l=l.updateQueue,l!==null&&(a=l.callbacks,a!==null&&(u=l.shared.hiddenCallbacks,l.shared.hiddenCallbacks=u===null?a:u.concat(a))));break;case 26:var e=rt;if(wl(t,l),Wl(l),a&512&&(Al||u===null||Ut(u,u.return)),a&4){var n=u!==null?u.memoizedState:null;if(a=l.memoizedState,u===null)if(a===null)if(l.stateNode===null){l:{a=l.type,u=l.memoizedProps,e=e.ownerDocument||e;t:switch(a){case"title":n=e.getElementsByTagName("title")[0],(!n||n[Na]||n[Rl]||n.namespaceURI==="http://www.w3.org/2000/svg"||n.hasAttribute("itemprop"))&&(n=e.createElement(a),e.head.insertBefore(n,e.querySelector("head > title"))),Yl(n,a,u),n[Rl]=l,pl(n),a=n;break l;case"link":var f=ks("link","href",e).get(a+(u.href||""));if(f){for(var c=0;c<f.length;c++)if(n=f[c],n.getAttribute("href")===(u.href==null||u.href===""?null:u.href)&&n.getAttribute("rel")===(u.rel==null?null:u.rel)&&n.getAttribute("title")===(u.title==null?null:u.title)&&n.getAttribute("crossorigin")===(u.crossOrigin==null?null:u.crossOrigin)){f.splice(c,1);break t}}n=e.createElement(a),Yl(n,a,u),e.head.appendChild(n);break;case"meta":if(f=ks("meta","content",e).get(a+(u.content||""))){for(c=0;c<f.length;c++)if(n=f[c],n.getAttribute("content")===(u.content==null?null:""+u.content)&&n.getAttribute("name")===(u.name==null?null:u.name)&&n.getAttribute("property")===(u.property==null?null:u.property)&&n.getAttribute("http-equiv")===(u.httpEquiv==null?null:u.httpEquiv)&&n.getAttribute("charset")===(u.charSet==null?null:u.charSet)){f.splice(c,1);break t}}n=e.createElement(a),Yl(n,a,u),e.head.appendChild(n);break;default:throw Error(o(468,a))}n[Rl]=l,pl(n),a=n}l.stateNode=a}else Is(e,l.type,l.stateNode);else l.stateNode=Fs(e,a,l.memoizedProps);else n!==a?(n===null?u.stateNode!==null&&(u=u.stateNode,u.parentNode.removeChild(u)):n.count--,a===null?Is(e,l.type,l.stateNode):Fs(e,a,l.memoizedProps)):a===null&&l.stateNode!==null&&bc(l,l.memoizedProps,u.memoizedProps)}break;case 27:wl(t,l),Wl(l),a&512&&(Al||u===null||Ut(u,u.return)),u!==null&&a&4&&bc(l,l.memoizedProps,u.memoizedProps);break;case 5:if(wl(t,l),Wl(l),a&512&&(Al||u===null||Ut(u,u.return)),l.flags&32){e=l.stateNode;try{Wu(e,"")}catch(O){tl(l,l.return,O)}}a&4&&l.stateNode!=null&&(e=l.memoizedProps,bc(l,e,u!==null?u.memoizedProps:e)),a&1024&&(Tc=!0);break;case 6:if(wl(t,l),Wl(l),a&4){if(l.stateNode===null)throw Error(o(162));a=l.memoizedProps,u=l.stateNode;try{u.nodeValue=a}catch(O){tl(l,l.return,O)}}break;case 3:if(pn=null,e=rt,rt=Dn(t.containerInfo),wl(t,l),rt=e,Wl(l),a&4&&u!==null&&u.memoizedState.isDehydrated)try{Oa(t.containerInfo)}catch(O){tl(l,l.return,O)}Tc&&(Tc=!1,I1(l));break;case 4:a=rt,rt=Dn(l.stateNode.containerInfo),wl(t,l),Wl(l),rt=a;break;case 12:wl(t,l),Wl(l);break;case 31:wl(t,l),Wl(l),a&4&&(a=l.updateQueue,a!==null&&(l.updateQueue=null,dn(l,a)));break;case 13:wl(t,l),Wl(l),l.child.flags&8192&&l.memoizedState!==null!=(u!==null&&u.memoizedState!==null)&&(on=kl()),a&4&&(a=l.updateQueue,a!==null&&(l.updateQueue=null,dn(l,a)));break;case 22:e=l.memoizedState!==null;var i=u!==null&&u.memoizedState!==null,d=Zt,S=Al;if(Zt=d||e,Al=S||i,wl(t,l),Al=S,Zt=d,Wl(l),a&8192)l:for(t=l.stateNode,t._visibility=e?t._visibility&-2:t._visibility|1,e&&(u===null||i||Zt||Al||xu(l)),u=null,t=l;;){if(t.tag===5||t.tag===26){if(u===null){i=u=t;try{if(n=i.stateNode,e)f=n.style,typeof f.setProperty=="function"?f.setProperty("display","none","important"):f.display="none";else{c=i.stateNode;var r=i.memoizedProps.style,h=r!=null&&r.hasOwnProperty("display")?r.display:null;c.style.display=h==null||typeof h=="boolean"?"":(""+h).trim()}}catch(O){tl(i,i.return,O)}}}else if(t.tag===6){if(u===null){i=t;try{i.stateNode.nodeValue=e?"":i.memoizedProps}catch(O){tl(i,i.return,O)}}}else if(t.tag===18){if(u===null){i=t;try{var g=i.stateNode;e?Qs(g,!0):Qs(i.stateNode,!1)}catch(O){tl(i,i.return,O)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===l)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break l;for(;t.sibling===null;){if(t.return===null||t.return===l)break l;u===t&&(u=null),t=t.return}u===t&&(u=null),t.sibling.return=t.return,t=t.sibling}a&4&&(a=l.updateQueue,a!==null&&(u=a.retryQueue,u!==null&&(a.retryQueue=null,dn(l,u))));break;case 19:wl(t,l),Wl(l),a&4&&(a=l.updateQueue,a!==null&&(l.updateQueue=null,dn(l,a)));break;case 30:break;case 21:break;default:wl(t,l),Wl(l)}}function Wl(l){var t=l.flags;if(t&2){try{for(var u,a=l.return;a!==null;){if(V1(a)){u=a;break}a=a.return}if(u==null)throw Error(o(160));switch(u.tag){case 27:var e=u.stateNode,n=zc(l);mn(l,n,e);break;case 5:var f=u.stateNode;u.flags&32&&(Wu(f,""),u.flags&=-33);var c=zc(l);mn(l,c,f);break;case 3:case 4:var i=u.stateNode.containerInfo,d=zc(l);rc(l,d,i);break;default:throw Error(o(161))}}catch(S){tl(l,l.return,S)}l.flags&=-3}t&4096&&(l.flags&=-4097)}function I1(l){if(l.subtreeFlags&1024)for(l=l.child;l!==null;){var t=l;I1(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),l=l.sibling}}function Lt(l,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)J1(l,t.alternate,t),t=t.sibling}function xu(l){for(l=l.child;l!==null;){var t=l;switch(t.tag){case 0:case 11:case 14:case 15:cu(4,t,t.return),xu(t);break;case 1:Ut(t,t.return);var u=t.stateNode;typeof u.componentWillUnmount=="function"&&Q1(t,t.return,u),xu(t);break;case 27:me(t.stateNode);case 26:case 5:Ut(t,t.return),xu(t);break;case 22:t.memoizedState===null&&xu(t);break;case 30:xu(t);break;default:xu(t)}l=l.sibling}}function Kt(l,t,u){for(u=u&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var a=t.alternate,e=l,n=t,f=n.flags;switch(n.tag){case 0:case 11:case 15:Kt(e,n,u),ue(4,n);break;case 1:if(Kt(e,n,u),a=n,e=a.stateNode,typeof e.componentDidMount=="function")try{e.componentDidMount()}catch(d){tl(a,a.return,d)}if(a=n,e=a.updateQueue,e!==null){var c=a.stateNode;try{var i=e.shared.hiddenCallbacks;if(i!==null)for(e.shared.hiddenCallbacks=null,e=0;e<i.length;e++)p0(i[e],c)}catch(d){tl(a,a.return,d)}}u&&f&64&&X1(n),ae(n,n.return);break;case 27:L1(n);case 26:case 5:Kt(e,n,u),u&&a===null&&f&4&&Z1(n),ae(n,n.return);break;case 12:Kt(e,n,u);break;case 31:Kt(e,n,u),u&&f&4&&$1(e,n);break;case 13:Kt(e,n,u),u&&f&4&&F1(e,n);break;case 22:n.memoizedState===null&&Kt(e,n,u),ae(n,n.return);break;case 30:break;default:Kt(e,n,u)}t=t.sibling}}function Ec(l,t){var u=null;l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(u=l.memoizedState.cachePool.pool),l=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(l=t.memoizedState.cachePool.pool),l!==u&&(l!=null&&l.refCount++,u!=null&&Va(u))}function Ac(l,t){l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&Va(l))}function Tt(l,t,u,a){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)P1(l,t,u,a),t=t.sibling}function P1(l,t,u,a){var e=t.flags;switch(t.tag){case 0:case 11:case 15:Tt(l,t,u,a),e&2048&&ue(9,t);break;case 1:Tt(l,t,u,a);break;case 3:Tt(l,t,u,a),e&2048&&(l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&Va(l)));break;case 12:if(e&2048){Tt(l,t,u,a),l=t.stateNode;try{var n=t.memoizedProps,f=n.id,c=n.onPostCommit;typeof c=="function"&&c(f,t.alternate===null?"mount":"update",l.passiveEffectDuration,-0)}catch(i){tl(t,t.return,i)}}else Tt(l,t,u,a);break;case 31:Tt(l,t,u,a);break;case 13:Tt(l,t,u,a);break;case 23:break;case 22:n=t.stateNode,f=t.alternate,t.memoizedState!==null?n._visibility&2?Tt(l,t,u,a):ee(l,t):n._visibility&2?Tt(l,t,u,a):(n._visibility|=2,ha(l,t,u,a,(t.subtreeFlags&10256)!==0||!1)),e&2048&&Ec(f,t);break;case 24:Tt(l,t,u,a),e&2048&&Ac(t.alternate,t);break;default:Tt(l,t,u,a)}}function ha(l,t,u,a,e){for(e=e&&((t.subtreeFlags&10256)!==0||!1),t=t.child;t!==null;){var n=l,f=t,c=u,i=a,d=f.flags;switch(f.tag){case 0:case 11:case 15:ha(n,f,c,i,e),ue(8,f);break;case 23:break;case 22:var S=f.stateNode;f.memoizedState!==null?S._visibility&2?ha(n,f,c,i,e):ee(n,f):(S._visibility|=2,ha(n,f,c,i,e)),e&&d&2048&&Ec(f.alternate,f);break;case 24:ha(n,f,c,i,e),e&&d&2048&&Ac(f.alternate,f);break;default:ha(n,f,c,i,e)}t=t.sibling}}function ee(l,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var u=l,a=t,e=a.flags;switch(a.tag){case 22:ee(u,a),e&2048&&Ec(a.alternate,a);break;case 24:ee(u,a),e&2048&&Ac(a.alternate,a);break;default:ee(u,a)}t=t.sibling}}var ne=8192;function oa(l,t,u){if(l.subtreeFlags&ne)for(l=l.child;l!==null;)ls(l,t,u),l=l.sibling}function ls(l,t,u){switch(l.tag){case 26:oa(l,t,u),l.flags&ne&&l.memoizedState!==null&&Bm(u,rt,l.memoizedState,l.memoizedProps);break;case 5:oa(l,t,u);break;case 3:case 4:var a=rt;rt=Dn(l.stateNode.containerInfo),oa(l,t,u),rt=a;break;case 22:l.memoizedState===null&&(a=l.alternate,a!==null&&a.memoizedState!==null?(a=ne,ne=16777216,oa(l,t,u),ne=a):oa(l,t,u));break;default:oa(l,t,u)}}function ts(l){var t=l.alternate;if(t!==null&&(l=t.child,l!==null)){t.child=null;do t=l.sibling,l.sibling=null,l=t;while(l!==null)}}function fe(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var u=0;u<t.length;u++){var a=t[u];Nl=a,as(a,l)}ts(l)}if(l.subtreeFlags&10256)for(l=l.child;l!==null;)us(l),l=l.sibling}function us(l){switch(l.tag){case 0:case 11:case 15:fe(l),l.flags&2048&&cu(9,l,l.return);break;case 3:fe(l);break;case 12:fe(l);break;case 22:var t=l.stateNode;l.memoizedState!==null&&t._visibility&2&&(l.return===null||l.return.tag!==13)?(t._visibility&=-3,hn(l)):fe(l);break;default:fe(l)}}function hn(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var u=0;u<t.length;u++){var a=t[u];Nl=a,as(a,l)}ts(l)}for(l=l.child;l!==null;){switch(t=l,t.tag){case 0:case 11:case 15:cu(8,t,t.return),hn(t);break;case 22:u=t.stateNode,u._visibility&2&&(u._visibility&=-3,hn(t));break;default:hn(t)}l=l.sibling}}function as(l,t){for(;Nl!==null;){var u=Nl;switch(u.tag){case 0:case 11:case 15:cu(8,u,t);break;case 23:case 22:if(u.memoizedState!==null&&u.memoizedState.cachePool!==null){var a=u.memoizedState.cachePool.pool;a!=null&&a.refCount++}break;case 24:Va(u.memoizedState.cache)}if(a=u.child,a!==null)a.return=u,Nl=a;else l:for(u=l;Nl!==null;){a=Nl;var e=a.sibling,n=a.return;if(w1(a),a===u){Nl=null;break l}if(e!==null){e.return=n,Nl=e;break l}Nl=n}}}var Fy={getCacheForType:function(l){var t=Cl(rl),u=t.data.get(l);return u===void 0&&(u=l(),t.data.set(l,u)),u},cacheSignal:function(){return Cl(rl).controller.signal}},ky=typeof WeakMap=="function"?WeakMap:Map,I=0,cl=null,X=null,Z=0,ll=0,et=null,iu=!1,ga=!1,_c=!1,Jt=0,gl=0,su=0,Xu=0,Oc=0,nt=0,Sa=0,ce=null,$l=null,Mc=!1,on=0,es=0,gn=1/0,Sn=null,vu=null,_l=0,yu=null,ba=null,wt=0,Dc=0,Uc=null,ns=null,ie=0,pc=null;function ft(){return(I&2)!==0&&Z!==0?Z&-Z:b.T!==null?Bc():Ti()}function fs(){if(nt===0)if((Z&536870912)===0||K){var l=_e;_e<<=1,(_e&3932160)===0&&(_e=262144),nt=l}else nt=536870912;return l=ut.current,l!==null&&(l.flags|=32),nt}function Fl(l,t,u){(l===cl&&(ll===2||ll===9)||l.cancelPendingCommit!==null)&&(za(l,0),mu(l,Z,nt,!1)),pa(l,u),((I&2)===0||l!==cl)&&(l===cl&&((I&2)===0&&(Xu|=u),gl===4&&mu(l,Z,nt,!1)),pt(l))}function cs(l,t,u){if((I&6)!==0)throw Error(o(327));var a=!u&&(t&127)===0&&(t&l.expiredLanes)===0||Ua(l,t),e=a?lm(l,t):Hc(l,t,!0),n=a;do{if(e===0){ga&&!a&&mu(l,t,0,!1);break}else{if(u=l.current.alternate,n&&!Iy(u)){e=Hc(l,t,!1),n=!1;continue}if(e===2){if(n=t,l.errorRecoveryDisabledLanes&n)var f=0;else f=l.pendingLanes&-536870913,f=f!==0?f:f&536870912?536870912:0;if(f!==0){t=f;l:{var c=l;e=ce;var i=c.current.memoizedState.isDehydrated;if(i&&(za(c,f).flags|=256),f=Hc(c,f,!1),f!==2){if(_c&&!i){c.errorRecoveryDisabledLanes|=n,Xu|=n,e=4;break l}n=$l,$l=e,n!==null&&($l===null?$l=n:$l.push.apply($l,n))}e=f}if(n=!1,e!==2)continue}}if(e===1){za(l,0),mu(l,t,0,!0);break}l:{switch(a=l,n=e,n){case 0:case 1:throw Error(o(345));case 4:if((t&4194048)!==t)break;case 6:mu(a,t,nt,!iu);break l;case 2:$l=null;break;case 3:case 5:break;default:throw Error(o(329))}if((t&62914560)===t&&(e=on+300-kl(),10<e)){if(mu(a,t,nt,!iu),Me(a,0,!0)!==0)break l;wt=t,a.timeoutHandle=Gs(is.bind(null,a,u,$l,Sn,Mc,t,nt,Xu,Sa,iu,n,"Throttled",-0,0),e);break l}is(a,u,$l,Sn,Mc,t,nt,Xu,Sa,iu,n,null,-0,0)}}break}while(!0);pt(l)}function is(l,t,u,a,e,n,f,c,i,d,S,r,h,g){if(l.timeoutHandle=-1,r=t.subtreeFlags,r&8192||(r&16785408)===16785408){r={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:Rt},ls(t,n,r);var O=(n&62914560)===n?on-kl():(n&4194048)===n?es-kl():0;if(O=Ym(r,O),O!==null){wt=n,l.cancelPendingCommit=O(gs.bind(null,l,t,n,u,a,e,f,c,i,S,r,null,h,g)),mu(l,n,f,!d);return}}gs(l,t,n,u,a,e,f,c,i)}function Iy(l){for(var t=l;;){var u=t.tag;if((u===0||u===11||u===15)&&t.flags&16384&&(u=t.updateQueue,u!==null&&(u=u.stores,u!==null)))for(var a=0;a<u.length;a++){var e=u[a],n=e.getSnapshot;e=e.value;try{if(!lt(n(),e))return!1}catch{return!1}}if(u=t.child,t.subtreeFlags&16384&&u!==null)u.return=t,t=u;else{if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function mu(l,t,u,a){t&=~Oc,t&=~Xu,l.suspendedLanes|=t,l.pingedLanes&=~t,a&&(l.warmLanes|=t),a=l.expirationTimes;for(var e=t;0<e;){var n=31-Pl(e),f=1<<n;a[n]=-1,e&=~f}u!==0&&bi(l,u,t)}function bn(){return(I&6)===0?(se(0),!1):!0}function Nc(){if(X!==null){if(ll===0)var l=X.return;else l=X,Yt=Hu=null,Jf(l),sa=null,Ka=0,l=X;for(;l!==null;)x1(l.alternate,l),l=l.return;X=null}}function za(l,t){var u=l.timeoutHandle;u!==-1&&(l.timeoutHandle=-1,bm(u)),u=l.cancelPendingCommit,u!==null&&(l.cancelPendingCommit=null,u()),wt=0,Nc(),cl=l,X=u=Ct(l.current,null),Z=t,ll=0,et=null,iu=!1,ga=Ua(l,t),_c=!1,Sa=nt=Oc=Xu=su=gl=0,$l=ce=null,Mc=!1,(t&8)!==0&&(t|=t&32);var a=l.entangledLanes;if(a!==0)for(l=l.entanglements,a&=t;0<a;){var e=31-Pl(a),n=1<<e;t|=l[e],a&=~n}return Jt=t,Ge(),u}function ss(l,t){Y=null,b.H=Pa,t===ia||t===Je?(t=O0(),ll=3):t===Cf?(t=O0(),ll=4):ll=t===ic?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,et=t,X===null&&(gl=1,fn(l,yt(t,l.current)))}function vs(){var l=ut.current;return l===null?!0:(Z&4194048)===Z?ot===null:(Z&62914560)===Z||(Z&536870912)!==0?l===ot:!1}function ys(){var l=b.H;return b.H=Pa,l===null?Pa:l}function ms(){var l=b.A;return b.A=Fy,l}function zn(){gl=4,iu||(Z&4194048)!==Z&&ut.current!==null||(ga=!0),(su&134217727)===0&&(Xu&134217727)===0||cl===null||mu(cl,Z,nt,!1)}function Hc(l,t,u){var a=I;I|=2;var e=ys(),n=ms();(cl!==l||Z!==t)&&(Sn=null,za(l,t)),t=!1;var f=gl;l:do try{if(ll!==0&&X!==null){var c=X,i=et;switch(ll){case 8:Nc(),f=6;break l;case 3:case 2:case 9:case 6:ut.current===null&&(t=!0);var d=ll;if(ll=0,et=null,ra(l,c,i,d),u&&ga){f=0;break l}break;default:d=ll,ll=0,et=null,ra(l,c,i,d)}}Py(),f=gl;break}catch(S){ss(l,S)}while(!0);return t&&l.shellSuspendCounter++,Yt=Hu=null,I=a,b.H=e,b.A=n,X===null&&(cl=null,Z=0,Ge()),f}function Py(){for(;X!==null;)ds(X)}function lm(l,t){var u=I;I|=2;var a=ys(),e=ms();cl!==l||Z!==t?(Sn=null,gn=kl()+500,za(l,t)):ga=Ua(l,t);l:do try{if(ll!==0&&X!==null){t=X;var n=et;t:switch(ll){case 1:ll=0,et=null,ra(l,t,n,1);break;case 2:case 9:if(A0(n)){ll=0,et=null,hs(t);break}t=function(){ll!==2&&ll!==9||cl!==l||(ll=7),pt(l)},n.then(t,t);break l;case 3:ll=7;break l;case 4:ll=5;break l;case 7:A0(n)?(ll=0,et=null,hs(t)):(ll=0,et=null,ra(l,t,n,7));break;case 5:var f=null;switch(X.tag){case 26:f=X.memoizedState;case 5:case 27:var c=X;if(f?Ps(f):c.stateNode.complete){ll=0,et=null;var i=c.sibling;if(i!==null)X=i;else{var d=c.return;d!==null?(X=d,rn(d)):X=null}break t}}ll=0,et=null,ra(l,t,n,5);break;case 6:ll=0,et=null,ra(l,t,n,6);break;case 8:Nc(),gl=6;break l;default:throw Error(o(462))}}tm();break}catch(S){ss(l,S)}while(!0);return Yt=Hu=null,b.H=a,b.A=e,I=u,X!==null?0:(cl=null,Z=0,Ge(),gl)}function tm(){for(;X!==null&&!_v();)ds(X)}function ds(l){var t=j1(l.alternate,l,Jt);l.memoizedProps=l.pendingProps,t===null?rn(l):X=t}function hs(l){var t=l,u=t.alternate;switch(t.tag){case 15:case 0:t=H1(u,t,t.pendingProps,t.type,void 0,Z);break;case 11:t=H1(u,t,t.pendingProps,t.type.render,t.ref,Z);break;case 5:Jf(t);default:x1(u,t),t=X=m0(t,Jt),t=j1(u,t,Jt)}l.memoizedProps=l.pendingProps,t===null?rn(l):X=t}function ra(l,t,u,a){Yt=Hu=null,Jf(t),sa=null,Ka=0;var e=t.return;try{if(Vy(l,e,t,u,Z)){gl=1,fn(l,yt(u,l.current)),X=null;return}}catch(n){if(e!==null)throw X=e,n;gl=1,fn(l,yt(u,l.current)),X=null;return}t.flags&32768?(K||a===1?l=!0:ga||(Z&536870912)!==0?l=!1:(iu=l=!0,(a===2||a===9||a===3||a===6)&&(a=ut.current,a!==null&&a.tag===13&&(a.flags|=16384))),os(t,l)):rn(t)}function rn(l){var t=l;do{if((t.flags&32768)!==0){os(t,iu);return}l=t.return;var u=Jy(t.alternate,t,Jt);if(u!==null){X=u;return}if(t=t.sibling,t!==null){X=t;return}X=t=l}while(t!==null);gl===0&&(gl=5)}function os(l,t){do{var u=wy(l.alternate,l);if(u!==null){u.flags&=32767,X=u;return}if(u=l.return,u!==null&&(u.flags|=32768,u.subtreeFlags=0,u.deletions=null),!t&&(l=l.sibling,l!==null)){X=l;return}X=l=u}while(l!==null);gl=6,X=null}function gs(l,t,u,a,e,n,f,c,i){l.cancelPendingCommit=null;do Tn();while(_l!==0);if((I&6)!==0)throw Error(o(327));if(t!==null){if(t===l.current)throw Error(o(177));if(n=t.lanes|t.childLanes,n|=zf,Cv(l,u,n,f,c,i),l===cl&&(X=cl=null,Z=0),ba=t,yu=l,wt=u,Dc=n,Uc=e,ns=a,(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?(l.callbackNode=null,l.callbackPriority=0,nm(Ee,function(){return Ts(),null})):(l.callbackNode=null,l.callbackPriority=0),a=(t.flags&13878)!==0,(t.subtreeFlags&13878)!==0||a){a=b.T,b.T=null,e=A.p,A.p=2,f=I,I|=4;try{Wy(l,t,u)}finally{I=f,A.p=e,b.T=a}}_l=1,Ss(),bs(),zs()}}function Ss(){if(_l===1){_l=0;var l=yu,t=ba,u=(t.flags&13878)!==0;if((t.subtreeFlags&13878)!==0||u){u=b.T,b.T=null;var a=A.p;A.p=2;var e=I;I|=4;try{k1(t,l);var n=Vc,f=a0(l.containerInfo),c=n.focusedElem,i=n.selectionRange;if(f!==c&&c&&c.ownerDocument&&u0(c.ownerDocument.documentElement,c)){if(i!==null&&hf(c)){var d=i.start,S=i.end;if(S===void 0&&(S=d),"selectionStart"in c)c.selectionStart=d,c.selectionEnd=Math.min(S,c.value.length);else{var r=c.ownerDocument||document,h=r&&r.defaultView||window;if(h.getSelection){var g=h.getSelection(),O=c.textContent.length,H=Math.min(i.start,O),nl=i.end===void 0?H:Math.min(i.end,O);!g.extend&&H>nl&&(f=nl,nl=H,H=f);var y=t0(c,H),s=t0(c,nl);if(y&&s&&(g.rangeCount!==1||g.anchorNode!==y.node||g.anchorOffset!==y.offset||g.focusNode!==s.node||g.focusOffset!==s.offset)){var m=r.createRange();m.setStart(y.node,y.offset),g.removeAllRanges(),H>nl?(g.addRange(m),g.extend(s.node,s.offset)):(m.setEnd(s.node,s.offset),g.addRange(m))}}}}for(r=[],g=c;g=g.parentNode;)g.nodeType===1&&r.push({element:g,left:g.scrollLeft,top:g.scrollTop});for(typeof c.focus=="function"&&c.focus(),c=0;c<r.length;c++){var z=r[c];z.element.scrollLeft=z.left,z.element.scrollTop=z.top}}qn=!!Zc,Vc=Zc=null}finally{I=e,A.p=a,b.T=u}}l.current=t,_l=2}}function bs(){if(_l===2){_l=0;var l=yu,t=ba,u=(t.flags&8772)!==0;if((t.subtreeFlags&8772)!==0||u){u=b.T,b.T=null;var a=A.p;A.p=2;var e=I;I|=4;try{J1(l,t.alternate,t)}finally{I=e,A.p=a,b.T=u}}_l=3}}function zs(){if(_l===4||_l===3){_l=0,Ov();var l=yu,t=ba,u=wt,a=ns;(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?_l=5:(_l=0,ba=yu=null,rs(l,l.pendingLanes));var e=l.pendingLanes;if(e===0&&(vu=null),Wn(u),t=t.stateNode,Il&&typeof Il.onCommitFiberRoot=="function")try{Il.onCommitFiberRoot(Da,t,void 0,(t.current.flags&128)===128)}catch{}if(a!==null){t=b.T,e=A.p,A.p=2,b.T=null;try{for(var n=l.onRecoverableError,f=0;f<a.length;f++){var c=a[f];n(c.value,{componentStack:c.stack})}}finally{b.T=t,A.p=e}}(wt&3)!==0&&Tn(),pt(l),e=l.pendingLanes,(u&261930)!==0&&(e&42)!==0?l===pc?ie++:(ie=0,pc=l):ie=0,se(0)}}function rs(l,t){(l.pooledCacheLanes&=t)===0&&(t=l.pooledCache,t!=null&&(l.pooledCache=null,Va(t)))}function Tn(){return Ss(),bs(),zs(),Ts()}function Ts(){if(_l!==5)return!1;var l=yu,t=Dc;Dc=0;var u=Wn(wt),a=b.T,e=A.p;try{A.p=32>u?32:u,b.T=null,u=Uc,Uc=null;var n=yu,f=wt;if(_l=0,ba=yu=null,wt=0,(I&6)!==0)throw Error(o(331));var c=I;if(I|=4,us(n.current),P1(n,n.current,f,u),I=c,se(0,!1),Il&&typeof Il.onPostCommitFiberRoot=="function")try{Il.onPostCommitFiberRoot(Da,n)}catch{}return!0}finally{A.p=e,b.T=a,rs(l,t)}}function Es(l,t,u){t=yt(u,t),t=cc(l.stateNode,t,2),l=eu(l,t,2),l!==null&&(pa(l,2),pt(l))}function tl(l,t,u){if(l.tag===3)Es(l,l,u);else for(;t!==null;){if(t.tag===3){Es(t,l,u);break}else if(t.tag===1){var a=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof a.componentDidCatch=="function"&&(vu===null||!vu.has(a))){l=yt(u,l),u=A1(2),a=eu(t,u,2),a!==null&&(_1(u,a,t,l),pa(a,2),pt(a));break}}t=t.return}}function Rc(l,t,u){var a=l.pingCache;if(a===null){a=l.pingCache=new ky;var e=new Set;a.set(t,e)}else e=a.get(t),e===void 0&&(e=new Set,a.set(t,e));e.has(u)||(_c=!0,e.add(u),l=um.bind(null,l,t,u),t.then(l,l))}function um(l,t,u){var a=l.pingCache;a!==null&&a.delete(t),l.pingedLanes|=l.suspendedLanes&u,l.warmLanes&=~u,cl===l&&(Z&u)===u&&(gl===4||gl===3&&(Z&62914560)===Z&&300>kl()-on?(I&2)===0&&za(l,0):Oc|=u,Sa===Z&&(Sa=0)),pt(l)}function As(l,t){t===0&&(t=Si()),l=Uu(l,t),l!==null&&(pa(l,t),pt(l))}function am(l){var t=l.memoizedState,u=0;t!==null&&(u=t.retryLane),As(l,u)}function em(l,t){var u=0;switch(l.tag){case 31:case 13:var a=l.stateNode,e=l.memoizedState;e!==null&&(u=e.retryLane);break;case 19:a=l.stateNode;break;case 22:a=l.stateNode._retryCache;break;default:throw Error(o(314))}a!==null&&a.delete(t),As(l,u)}function nm(l,t){return Ln(l,t)}var En=null,Ta=null,qc=!1,An=!1,Cc=!1,du=0;function pt(l){l!==Ta&&l.next===null&&(Ta===null?En=Ta=l:Ta=Ta.next=l),An=!0,qc||(qc=!0,cm())}function se(l,t){if(!Cc&&An){Cc=!0;do for(var u=!1,a=En;a!==null;){if(l!==0){var e=a.pendingLanes;if(e===0)var n=0;else{var f=a.suspendedLanes,c=a.pingedLanes;n=(1<<31-Pl(42|l)+1)-1,n&=e&~(f&~c),n=n&201326741?n&201326741|1:n?n|2:0}n!==0&&(u=!0,Ds(a,n))}else n=Z,n=Me(a,a===cl?n:0,a.cancelPendingCommit!==null||a.timeoutHandle!==-1),(n&3)===0||Ua(a,n)||(u=!0,Ds(a,n));a=a.next}while(u);Cc=!1}}function fm(){_s()}function _s(){An=qc=!1;var l=0;du!==0&&Sm()&&(l=du);for(var t=kl(),u=null,a=En;a!==null;){var e=a.next,n=Os(a,t);n===0?(a.next=null,u===null?En=e:u.next=e,e===null&&(Ta=u)):(u=a,(l!==0||(n&3)!==0)&&(An=!0)),a=e}_l!==0&&_l!==5||se(l),du!==0&&(du=0)}function Os(l,t){for(var u=l.suspendedLanes,a=l.pingedLanes,e=l.expirationTimes,n=l.pendingLanes&-62914561;0<n;){var f=31-Pl(n),c=1<<f,i=e[f];i===-1?((c&u)===0||(c&a)!==0)&&(e[f]=qv(c,t)):i<=t&&(l.expiredLanes|=c),n&=~c}if(t=cl,u=Z,u=Me(l,l===t?u:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),a=l.callbackNode,u===0||l===t&&(ll===2||ll===9)||l.cancelPendingCommit!==null)return a!==null&&a!==null&&Kn(a),l.callbackNode=null,l.callbackPriority=0;if((u&3)===0||Ua(l,u)){if(t=u&-u,t===l.callbackPriority)return t;switch(a!==null&&Kn(a),Wn(u)){case 2:case 8:u=oi;break;case 32:u=Ee;break;case 268435456:u=gi;break;default:u=Ee}return a=Ms.bind(null,l),u=Ln(u,a),l.callbackPriority=t,l.callbackNode=u,t}return a!==null&&a!==null&&Kn(a),l.callbackPriority=2,l.callbackNode=null,2}function Ms(l,t){if(_l!==0&&_l!==5)return l.callbackNode=null,l.callbackPriority=0,null;var u=l.callbackNode;if(Tn()&&l.callbackNode!==u)return null;var a=Z;return a=Me(l,l===cl?a:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),a===0?null:(cs(l,a,t),Os(l,kl()),l.callbackNode!=null&&l.callbackNode===u?Ms.bind(null,l):null)}function Ds(l,t){if(Tn())return null;cs(l,t,!0)}function cm(){zm(function(){(I&6)!==0?Ln(hi,fm):_s()})}function Bc(){if(du===0){var l=fa;l===0&&(l=Ae,Ae<<=1,(Ae&261888)===0&&(Ae=256)),du=l}return du}function Us(l){return l==null||typeof l=="symbol"||typeof l=="boolean"?null:typeof l=="function"?l:Ne(""+l)}function ps(l,t){var u=t.ownerDocument.createElement("input");return u.name=t.name,u.value=t.value,l.id&&u.setAttribute("form",l.id),t.parentNode.insertBefore(u,t),l=new FormData(l),u.parentNode.removeChild(u),l}function im(l,t,u,a,e){if(t==="submit"&&u&&u.stateNode===e){var n=Us((e[Ll]||null).action),f=a.submitter;f&&(t=(t=f[Ll]||null)?Us(t.formAction):f.getAttribute("formAction"),t!==null&&(n=t,f=null));var c=new Ce("action","action",null,a,e);l.push({event:c,listeners:[{instance:null,listener:function(){if(a.defaultPrevented){if(du!==0){var i=f?ps(e,f):new FormData(e);tc(u,{pending:!0,data:i,method:e.method,action:n},null,i)}}else typeof n=="function"&&(c.preventDefault(),i=f?ps(e,f):new FormData(e),tc(u,{pending:!0,data:i,method:e.method,action:n},n,i))},currentTarget:e}]})}}for(var Yc=0;Yc<bf.length;Yc++){var jc=bf[Yc],sm=jc.toLowerCase(),vm=jc[0].toUpperCase()+jc.slice(1);zt(sm,"on"+vm)}zt(f0,"onAnimationEnd"),zt(c0,"onAnimationIteration"),zt(i0,"onAnimationStart"),zt("dblclick","onDoubleClick"),zt("focusin","onFocus"),zt("focusout","onBlur"),zt(My,"onTransitionRun"),zt(Dy,"onTransitionStart"),zt(Uy,"onTransitionCancel"),zt(s0,"onTransitionEnd"),Ju("onMouseEnter",["mouseout","mouseover"]),Ju("onMouseLeave",["mouseout","mouseover"]),Ju("onPointerEnter",["pointerout","pointerover"]),Ju("onPointerLeave",["pointerout","pointerover"]),_u("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),_u("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),_u("onBeforeInput",["compositionend","keypress","textInput","paste"]),_u("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),_u("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),_u("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var ve="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),ym=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(ve));function Ns(l,t){t=(t&4)!==0;for(var u=0;u<l.length;u++){var a=l[u],e=a.event;a=a.listeners;l:{var n=void 0;if(t)for(var f=a.length-1;0<=f;f--){var c=a[f],i=c.instance,d=c.currentTarget;if(c=c.listener,i!==n&&e.isPropagationStopped())break l;n=c,e.currentTarget=d;try{n(e)}catch(S){je(S)}e.currentTarget=null,n=i}else for(f=0;f<a.length;f++){if(c=a[f],i=c.instance,d=c.currentTarget,c=c.listener,i!==n&&e.isPropagationStopped())break l;n=c,e.currentTarget=d;try{n(e)}catch(S){je(S)}e.currentTarget=null,n=i}}}}function Q(l,t){var u=t[$n];u===void 0&&(u=t[$n]=new Set);var a=l+"__bubble";u.has(a)||(Hs(t,l,2,!1),u.add(a))}function Gc(l,t,u){var a=0;t&&(a|=4),Hs(u,l,a,t)}var _n="_reactListening"+Math.random().toString(36).slice(2);function xc(l){if(!l[_n]){l[_n]=!0,_i.forEach(function(u){u!=="selectionchange"&&(ym.has(u)||Gc(u,!1,l),Gc(u,!0,l))});var t=l.nodeType===9?l:l.ownerDocument;t===null||t[_n]||(t[_n]=!0,Gc("selectionchange",!1,t))}}function Hs(l,t,u,a){switch(fv(t)){case 2:var e=xm;break;case 8:e=Xm;break;default:e=li}u=e.bind(null,t,u,l),e=void 0,!ef||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(e=!0),a?e!==void 0?l.addEventListener(t,u,{capture:!0,passive:e}):l.addEventListener(t,u,!0):e!==void 0?l.addEventListener(t,u,{passive:e}):l.addEventListener(t,u,!1)}function Xc(l,t,u,a,e){var n=a;if((t&1)===0&&(t&2)===0&&a!==null)l:for(;;){if(a===null)return;var f=a.tag;if(f===3||f===4){var c=a.stateNode.containerInfo;if(c===e)break;if(f===4)for(f=a.return;f!==null;){var i=f.tag;if((i===3||i===4)&&f.stateNode.containerInfo===e)return;f=f.return}for(;c!==null;){if(f=Vu(c),f===null)return;if(i=f.tag,i===5||i===6||i===26||i===27){a=n=f;continue l}c=c.parentNode}}a=a.return}Yi(function(){var d=n,S=uf(u),r=[];l:{var h=v0.get(l);if(h!==void 0){var g=Ce,O=l;switch(l){case"keypress":if(Re(u)===0)break l;case"keydown":case"keyup":g=ey;break;case"focusin":O="focus",g=sf;break;case"focusout":O="blur",g=sf;break;case"beforeblur":case"afterblur":g=sf;break;case"click":if(u.button===2)break l;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":g=xi;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":g=Jv;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":g=cy;break;case f0:case c0:case i0:g=$v;break;case s0:g=sy;break;case"scroll":case"scrollend":g=Lv;break;case"wheel":g=yy;break;case"copy":case"cut":case"paste":g=kv;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":g=Qi;break;case"toggle":case"beforetoggle":g=dy}var H=(t&4)!==0,nl=!H&&(l==="scroll"||l==="scrollend"),y=H?h!==null?h+"Capture":null:h;H=[];for(var s=d,m;s!==null;){var z=s;if(m=z.stateNode,z=z.tag,z!==5&&z!==26&&z!==27||m===null||y===null||(z=Ra(s,y),z!=null&&H.push(ye(s,z,m))),nl)break;s=s.return}0<H.length&&(h=new g(h,O,null,u,S),r.push({event:h,listeners:H}))}}if((t&7)===0){l:{if(h=l==="mouseover"||l==="pointerover",g=l==="mouseout"||l==="pointerout",h&&u!==tf&&(O=u.relatedTarget||u.fromElement)&&(Vu(O)||O[Zu]))break l;if((g||h)&&(h=S.window===S?S:(h=S.ownerDocument)?h.defaultView||h.parentWindow:window,g?(O=u.relatedTarget||u.toElement,g=d,O=O?Vu(O):null,O!==null&&(nl=w(O),H=O.tag,O!==nl||H!==5&&H!==27&&H!==6)&&(O=null)):(g=null,O=d),g!==O)){if(H=xi,z="onMouseLeave",y="onMouseEnter",s="mouse",(l==="pointerout"||l==="pointerover")&&(H=Qi,z="onPointerLeave",y="onPointerEnter",s="pointer"),nl=g==null?h:Ha(g),m=O==null?h:Ha(O),h=new H(z,s+"leave",g,u,S),h.target=nl,h.relatedTarget=m,z=null,Vu(S)===d&&(H=new H(y,s+"enter",O,u,S),H.target=m,H.relatedTarget=nl,z=H),nl=z,g&&O)t:{for(H=mm,y=g,s=O,m=0,z=y;z;z=H(z))m++;z=0;for(var N=s;N;N=H(N))z++;for(;0<m-z;)y=H(y),m--;for(;0<z-m;)s=H(s),z--;for(;m--;){if(y===s||s!==null&&y===s.alternate){H=y;break t}y=H(y),s=H(s)}H=null}else H=null;g!==null&&Rs(r,h,g,H,!1),O!==null&&nl!==null&&Rs(r,nl,O,H,!0)}}l:{if(h=d?Ha(d):window,g=h.nodeName&&h.nodeName.toLowerCase(),g==="select"||g==="input"&&h.type==="file")var F=$i;else if(wi(h))if(Fi)F=Ay;else{F=Ty;var U=ry}else g=h.nodeName,!g||g.toLowerCase()!=="input"||h.type!=="checkbox"&&h.type!=="radio"?d&&lf(d.elementType)&&(F=$i):F=Ey;if(F&&(F=F(l,d))){Wi(r,F,u,S);break l}U&&U(l,h,d),l==="focusout"&&d&&h.type==="number"&&d.memoizedProps.value!=null&&Pn(h,"number",h.value)}switch(U=d?Ha(d):window,l){case"focusin":(wi(U)||U.contentEditable==="true")&&(Iu=U,of=d,Xa=null);break;case"focusout":Xa=of=Iu=null;break;case"mousedown":gf=!0;break;case"contextmenu":case"mouseup":case"dragend":gf=!1,e0(r,u,S);break;case"selectionchange":if(Oy)break;case"keydown":case"keyup":e0(r,u,S)}var G;if(yf)l:{switch(l){case"compositionstart":var V="onCompositionStart";break l;case"compositionend":V="onCompositionEnd";break l;case"compositionupdate":V="onCompositionUpdate";break l}V=void 0}else ku?Ki(l,u)&&(V="onCompositionEnd"):l==="keydown"&&u.keyCode===229&&(V="onCompositionStart");V&&(Zi&&u.locale!=="ko"&&(ku||V!=="onCompositionStart"?V==="onCompositionEnd"&&ku&&(G=ji()):(kt=S,nf="value"in kt?kt.value:kt.textContent,ku=!0)),U=On(d,V),0<U.length&&(V=new Xi(V,l,null,u,S),r.push({event:V,listeners:U}),G?V.data=G:(G=Ji(u),G!==null&&(V.data=G)))),(G=oy?gy(l,u):Sy(l,u))&&(V=On(d,"onBeforeInput"),0<V.length&&(U=new Xi("onBeforeInput","beforeinput",null,u,S),r.push({event:U,listeners:V}),U.data=G)),im(r,l,d,u,S)}Ns(r,t)})}function ye(l,t,u){return{instance:l,listener:t,currentTarget:u}}function On(l,t){for(var u=t+"Capture",a=[];l!==null;){var e=l,n=e.stateNode;if(e=e.tag,e!==5&&e!==26&&e!==27||n===null||(e=Ra(l,u),e!=null&&a.unshift(ye(l,e,n)),e=Ra(l,t),e!=null&&a.push(ye(l,e,n))),l.tag===3)return a;l=l.return}return[]}function mm(l){if(l===null)return null;do l=l.return;while(l&&l.tag!==5&&l.tag!==27);return l||null}function Rs(l,t,u,a,e){for(var n=t._reactName,f=[];u!==null&&u!==a;){var c=u,i=c.alternate,d=c.stateNode;if(c=c.tag,i!==null&&i===a)break;c!==5&&c!==26&&c!==27||d===null||(i=d,e?(d=Ra(u,n),d!=null&&f.unshift(ye(u,d,i))):e||(d=Ra(u,n),d!=null&&f.push(ye(u,d,i)))),u=u.return}f.length!==0&&l.push({event:t,listeners:f})}var dm=/\r\n?/g,hm=/\u0000|\uFFFD/g;function qs(l){return(typeof l=="string"?l:""+l).replace(dm,`
`).replace(hm,"")}function Cs(l,t){return t=qs(t),qs(l)===t}function el(l,t,u,a,e,n){switch(u){case"children":typeof a=="string"?t==="body"||t==="textarea"&&a===""||Wu(l,a):(typeof a=="number"||typeof a=="bigint")&&t!=="body"&&Wu(l,""+a);break;case"className":Ue(l,"class",a);break;case"tabIndex":Ue(l,"tabindex",a);break;case"dir":case"role":case"viewBox":case"width":case"height":Ue(l,u,a);break;case"style":Ci(l,a,n);break;case"data":if(t!=="object"){Ue(l,"data",a);break}case"src":case"href":if(a===""&&(t!=="a"||u!=="href")){l.removeAttribute(u);break}if(a==null||typeof a=="function"||typeof a=="symbol"||typeof a=="boolean"){l.removeAttribute(u);break}a=Ne(""+a),l.setAttribute(u,a);break;case"action":case"formAction":if(typeof a=="function"){l.setAttribute(u,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof n=="function"&&(u==="formAction"?(t!=="input"&&el(l,t,"name",e.name,e,null),el(l,t,"formEncType",e.formEncType,e,null),el(l,t,"formMethod",e.formMethod,e,null),el(l,t,"formTarget",e.formTarget,e,null)):(el(l,t,"encType",e.encType,e,null),el(l,t,"method",e.method,e,null),el(l,t,"target",e.target,e,null)));if(a==null||typeof a=="symbol"||typeof a=="boolean"){l.removeAttribute(u);break}a=Ne(""+a),l.setAttribute(u,a);break;case"onClick":a!=null&&(l.onclick=Rt);break;case"onScroll":a!=null&&Q("scroll",l);break;case"onScrollEnd":a!=null&&Q("scrollend",l);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(o(61));if(u=a.__html,u!=null){if(e.children!=null)throw Error(o(60));l.innerHTML=u}}break;case"multiple":l.multiple=a&&typeof a!="function"&&typeof a!="symbol";break;case"muted":l.muted=a&&typeof a!="function"&&typeof a!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(a==null||typeof a=="function"||typeof a=="boolean"||typeof a=="symbol"){l.removeAttribute("xlink:href");break}u=Ne(""+a),l.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",u);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":a!=null&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(u,""+a):l.removeAttribute(u);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":a&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(u,""):l.removeAttribute(u);break;case"capture":case"download":a===!0?l.setAttribute(u,""):a!==!1&&a!=null&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(u,a):l.removeAttribute(u);break;case"cols":case"rows":case"size":case"span":a!=null&&typeof a!="function"&&typeof a!="symbol"&&!isNaN(a)&&1<=a?l.setAttribute(u,a):l.removeAttribute(u);break;case"rowSpan":case"start":a==null||typeof a=="function"||typeof a=="symbol"||isNaN(a)?l.removeAttribute(u):l.setAttribute(u,a);break;case"popover":Q("beforetoggle",l),Q("toggle",l),De(l,"popover",a);break;case"xlinkActuate":Ht(l,"http://www.w3.org/1999/xlink","xlink:actuate",a);break;case"xlinkArcrole":Ht(l,"http://www.w3.org/1999/xlink","xlink:arcrole",a);break;case"xlinkRole":Ht(l,"http://www.w3.org/1999/xlink","xlink:role",a);break;case"xlinkShow":Ht(l,"http://www.w3.org/1999/xlink","xlink:show",a);break;case"xlinkTitle":Ht(l,"http://www.w3.org/1999/xlink","xlink:title",a);break;case"xlinkType":Ht(l,"http://www.w3.org/1999/xlink","xlink:type",a);break;case"xmlBase":Ht(l,"http://www.w3.org/XML/1998/namespace","xml:base",a);break;case"xmlLang":Ht(l,"http://www.w3.org/XML/1998/namespace","xml:lang",a);break;case"xmlSpace":Ht(l,"http://www.w3.org/XML/1998/namespace","xml:space",a);break;case"is":De(l,"is",a);break;case"innerText":case"textContent":break;default:(!(2<u.length)||u[0]!=="o"&&u[0]!=="O"||u[1]!=="n"&&u[1]!=="N")&&(u=Zv.get(u)||u,De(l,u,a))}}function Qc(l,t,u,a,e,n){switch(u){case"style":Ci(l,a,n);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(o(61));if(u=a.__html,u!=null){if(e.children!=null)throw Error(o(60));l.innerHTML=u}}break;case"children":typeof a=="string"?Wu(l,a):(typeof a=="number"||typeof a=="bigint")&&Wu(l,""+a);break;case"onScroll":a!=null&&Q("scroll",l);break;case"onScrollEnd":a!=null&&Q("scrollend",l);break;case"onClick":a!=null&&(l.onclick=Rt);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!Oi.hasOwnProperty(u))l:{if(u[0]==="o"&&u[1]==="n"&&(e=u.endsWith("Capture"),t=u.slice(2,e?u.length-7:void 0),n=l[Ll]||null,n=n!=null?n[u]:null,typeof n=="function"&&l.removeEventListener(t,n,e),typeof a=="function")){typeof n!="function"&&n!==null&&(u in l?l[u]=null:l.hasAttribute(u)&&l.removeAttribute(u)),l.addEventListener(t,a,e);break l}u in l?l[u]=a:a===!0?l.setAttribute(u,""):De(l,u,a)}}}function Yl(l,t,u){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":Q("error",l),Q("load",l);var a=!1,e=!1,n;for(n in u)if(u.hasOwnProperty(n)){var f=u[n];if(f!=null)switch(n){case"src":a=!0;break;case"srcSet":e=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(o(137,t));default:el(l,t,n,f,u,null)}}e&&el(l,t,"srcSet",u.srcSet,u,null),a&&el(l,t,"src",u.src,u,null);return;case"input":Q("invalid",l);var c=n=f=e=null,i=null,d=null;for(a in u)if(u.hasOwnProperty(a)){var S=u[a];if(S!=null)switch(a){case"name":e=S;break;case"type":f=S;break;case"checked":i=S;break;case"defaultChecked":d=S;break;case"value":n=S;break;case"defaultValue":c=S;break;case"children":case"dangerouslySetInnerHTML":if(S!=null)throw Error(o(137,t));break;default:el(l,t,a,S,u,null)}}Ni(l,n,c,i,d,f,e,!1);return;case"select":Q("invalid",l),a=f=n=null;for(e in u)if(u.hasOwnProperty(e)&&(c=u[e],c!=null))switch(e){case"value":n=c;break;case"defaultValue":f=c;break;case"multiple":a=c;default:el(l,t,e,c,u,null)}t=n,u=f,l.multiple=!!a,t!=null?wu(l,!!a,t,!1):u!=null&&wu(l,!!a,u,!0);return;case"textarea":Q("invalid",l),n=e=a=null;for(f in u)if(u.hasOwnProperty(f)&&(c=u[f],c!=null))switch(f){case"value":a=c;break;case"defaultValue":e=c;break;case"children":n=c;break;case"dangerouslySetInnerHTML":if(c!=null)throw Error(o(91));break;default:el(l,t,f,c,u,null)}Ri(l,a,e,n);return;case"option":for(i in u)if(u.hasOwnProperty(i)&&(a=u[i],a!=null))switch(i){case"selected":l.selected=a&&typeof a!="function"&&typeof a!="symbol";break;default:el(l,t,i,a,u,null)}return;case"dialog":Q("beforetoggle",l),Q("toggle",l),Q("cancel",l),Q("close",l);break;case"iframe":case"object":Q("load",l);break;case"video":case"audio":for(a=0;a<ve.length;a++)Q(ve[a],l);break;case"image":Q("error",l),Q("load",l);break;case"details":Q("toggle",l);break;case"embed":case"source":case"link":Q("error",l),Q("load",l);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(d in u)if(u.hasOwnProperty(d)&&(a=u[d],a!=null))switch(d){case"children":case"dangerouslySetInnerHTML":throw Error(o(137,t));default:el(l,t,d,a,u,null)}return;default:if(lf(t)){for(S in u)u.hasOwnProperty(S)&&(a=u[S],a!==void 0&&Qc(l,t,S,a,u,void 0));return}}for(c in u)u.hasOwnProperty(c)&&(a=u[c],a!=null&&el(l,t,c,a,u,null))}function om(l,t,u,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var e=null,n=null,f=null,c=null,i=null,d=null,S=null;for(g in u){var r=u[g];if(u.hasOwnProperty(g)&&r!=null)switch(g){case"checked":break;case"value":break;case"defaultValue":i=r;default:a.hasOwnProperty(g)||el(l,t,g,null,a,r)}}for(var h in a){var g=a[h];if(r=u[h],a.hasOwnProperty(h)&&(g!=null||r!=null))switch(h){case"type":n=g;break;case"name":e=g;break;case"checked":d=g;break;case"defaultChecked":S=g;break;case"value":f=g;break;case"defaultValue":c=g;break;case"children":case"dangerouslySetInnerHTML":if(g!=null)throw Error(o(137,t));break;default:g!==r&&el(l,t,h,g,a,r)}}In(l,f,c,i,d,S,n,e);return;case"select":g=f=c=h=null;for(n in u)if(i=u[n],u.hasOwnProperty(n)&&i!=null)switch(n){case"value":break;case"multiple":g=i;default:a.hasOwnProperty(n)||el(l,t,n,null,a,i)}for(e in a)if(n=a[e],i=u[e],a.hasOwnProperty(e)&&(n!=null||i!=null))switch(e){case"value":h=n;break;case"defaultValue":c=n;break;case"multiple":f=n;default:n!==i&&el(l,t,e,n,a,i)}t=c,u=f,a=g,h!=null?wu(l,!!u,h,!1):!!a!=!!u&&(t!=null?wu(l,!!u,t,!0):wu(l,!!u,u?[]:"",!1));return;case"textarea":g=h=null;for(c in u)if(e=u[c],u.hasOwnProperty(c)&&e!=null&&!a.hasOwnProperty(c))switch(c){case"value":break;case"children":break;default:el(l,t,c,null,a,e)}for(f in a)if(e=a[f],n=u[f],a.hasOwnProperty(f)&&(e!=null||n!=null))switch(f){case"value":h=e;break;case"defaultValue":g=e;break;case"children":break;case"dangerouslySetInnerHTML":if(e!=null)throw Error(o(91));break;default:e!==n&&el(l,t,f,e,a,n)}Hi(l,h,g);return;case"option":for(var O in u)if(h=u[O],u.hasOwnProperty(O)&&h!=null&&!a.hasOwnProperty(O))switch(O){case"selected":l.selected=!1;break;default:el(l,t,O,null,a,h)}for(i in a)if(h=a[i],g=u[i],a.hasOwnProperty(i)&&h!==g&&(h!=null||g!=null))switch(i){case"selected":l.selected=h&&typeof h!="function"&&typeof h!="symbol";break;default:el(l,t,i,h,a,g)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var H in u)h=u[H],u.hasOwnProperty(H)&&h!=null&&!a.hasOwnProperty(H)&&el(l,t,H,null,a,h);for(d in a)if(h=a[d],g=u[d],a.hasOwnProperty(d)&&h!==g&&(h!=null||g!=null))switch(d){case"children":case"dangerouslySetInnerHTML":if(h!=null)throw Error(o(137,t));break;default:el(l,t,d,h,a,g)}return;default:if(lf(t)){for(var nl in u)h=u[nl],u.hasOwnProperty(nl)&&h!==void 0&&!a.hasOwnProperty(nl)&&Qc(l,t,nl,void 0,a,h);for(S in a)h=a[S],g=u[S],!a.hasOwnProperty(S)||h===g||h===void 0&&g===void 0||Qc(l,t,S,h,a,g);return}}for(var y in u)h=u[y],u.hasOwnProperty(y)&&h!=null&&!a.hasOwnProperty(y)&&el(l,t,y,null,a,h);for(r in a)h=a[r],g=u[r],!a.hasOwnProperty(r)||h===g||h==null&&g==null||el(l,t,r,h,a,g)}function Bs(l){switch(l){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function gm(){if(typeof performance.getEntriesByType=="function"){for(var l=0,t=0,u=performance.getEntriesByType("resource"),a=0;a<u.length;a++){var e=u[a],n=e.transferSize,f=e.initiatorType,c=e.duration;if(n&&c&&Bs(f)){for(f=0,c=e.responseEnd,a+=1;a<u.length;a++){var i=u[a],d=i.startTime;if(d>c)break;var S=i.transferSize,r=i.initiatorType;S&&Bs(r)&&(i=i.responseEnd,f+=S*(i<c?1:(c-d)/(i-d)))}if(--a,t+=8*(n+f)/(e.duration/1e3),l++,10<l)break}}if(0<l)return t/l/1e6}return navigator.connection&&(l=navigator.connection.downlink,typeof l=="number")?l:5}var Zc=null,Vc=null;function Mn(l){return l.nodeType===9?l:l.ownerDocument}function Ys(l){switch(l){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function js(l,t){if(l===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return l===1&&t==="foreignObject"?0:l}function Lc(l,t){return l==="textarea"||l==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var Kc=null;function Sm(){var l=window.event;return l&&l.type==="popstate"?l===Kc?!1:(Kc=l,!0):(Kc=null,!1)}var Gs=typeof setTimeout=="function"?setTimeout:void 0,bm=typeof clearTimeout=="function"?clearTimeout:void 0,xs=typeof Promise=="function"?Promise:void 0,zm=typeof queueMicrotask=="function"?queueMicrotask:typeof xs<"u"?function(l){return xs.resolve(null).then(l).catch(rm)}:Gs;function rm(l){setTimeout(function(){throw l})}function hu(l){return l==="head"}function Xs(l,t){var u=t,a=0;do{var e=u.nextSibling;if(l.removeChild(u),e&&e.nodeType===8)if(u=e.data,u==="/$"||u==="/&"){if(a===0){l.removeChild(e),Oa(t);return}a--}else if(u==="$"||u==="$?"||u==="$~"||u==="$!"||u==="&")a++;else if(u==="html")me(l.ownerDocument.documentElement);else if(u==="head"){u=l.ownerDocument.head,me(u);for(var n=u.firstChild;n;){var f=n.nextSibling,c=n.nodeName;n[Na]||c==="SCRIPT"||c==="STYLE"||c==="LINK"&&n.rel.toLowerCase()==="stylesheet"||u.removeChild(n),n=f}}else u==="body"&&me(l.ownerDocument.body);u=e}while(u);Oa(t)}function Qs(l,t){var u=l;l=0;do{var a=u.nextSibling;if(u.nodeType===1?t?(u._stashedDisplay=u.style.display,u.style.display="none"):(u.style.display=u._stashedDisplay||"",u.getAttribute("style")===""&&u.removeAttribute("style")):u.nodeType===3&&(t?(u._stashedText=u.nodeValue,u.nodeValue=""):u.nodeValue=u._stashedText||""),a&&a.nodeType===8)if(u=a.data,u==="/$"){if(l===0)break;l--}else u!=="$"&&u!=="$?"&&u!=="$~"&&u!=="$!"||l++;u=a}while(u)}function Jc(l){var t=l.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var u=t;switch(t=t.nextSibling,u.nodeName){case"HTML":case"HEAD":case"BODY":Jc(u),Fn(u);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(u.rel.toLowerCase()==="stylesheet")continue}l.removeChild(u)}}function Tm(l,t,u,a){for(;l.nodeType===1;){var e=u;if(l.nodeName.toLowerCase()!==t.toLowerCase()){if(!a&&(l.nodeName!=="INPUT"||l.type!=="hidden"))break}else if(a){if(!l[Na])switch(t){case"meta":if(!l.hasAttribute("itemprop"))break;return l;case"link":if(n=l.getAttribute("rel"),n==="stylesheet"&&l.hasAttribute("data-precedence"))break;if(n!==e.rel||l.getAttribute("href")!==(e.href==null||e.href===""?null:e.href)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin)||l.getAttribute("title")!==(e.title==null?null:e.title))break;return l;case"style":if(l.hasAttribute("data-precedence"))break;return l;case"script":if(n=l.getAttribute("src"),(n!==(e.src==null?null:e.src)||l.getAttribute("type")!==(e.type==null?null:e.type)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin))&&n&&l.hasAttribute("async")&&!l.hasAttribute("itemprop"))break;return l;default:return l}}else if(t==="input"&&l.type==="hidden"){var n=e.name==null?null:""+e.name;if(e.type==="hidden"&&l.getAttribute("name")===n)return l}else return l;if(l=gt(l.nextSibling),l===null)break}return null}function Em(l,t,u){if(t==="")return null;for(;l.nodeType!==3;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!u||(l=gt(l.nextSibling),l===null))return null;return l}function Zs(l,t){for(;l.nodeType!==8;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!t||(l=gt(l.nextSibling),l===null))return null;return l}function wc(l){return l.data==="$?"||l.data==="$~"}function Wc(l){return l.data==="$!"||l.data==="$?"&&l.ownerDocument.readyState!=="loading"}function Am(l,t){var u=l.ownerDocument;if(l.data==="$~")l._reactRetry=t;else if(l.data!=="$?"||u.readyState!=="loading")t();else{var a=function(){t(),u.removeEventListener("DOMContentLoaded",a)};u.addEventListener("DOMContentLoaded",a),l._reactRetry=a}}function gt(l){for(;l!=null;l=l.nextSibling){var t=l.nodeType;if(t===1||t===3)break;if(t===8){if(t=l.data,t==="$"||t==="$!"||t==="$?"||t==="$~"||t==="&"||t==="F!"||t==="F")break;if(t==="/$"||t==="/&")return null}}return l}var $c=null;function Vs(l){l=l.nextSibling;for(var t=0;l;){if(l.nodeType===8){var u=l.data;if(u==="/$"||u==="/&"){if(t===0)return gt(l.nextSibling);t--}else u!=="$"&&u!=="$!"&&u!=="$?"&&u!=="$~"&&u!=="&"||t++}l=l.nextSibling}return null}function Ls(l){l=l.previousSibling;for(var t=0;l;){if(l.nodeType===8){var u=l.data;if(u==="$"||u==="$!"||u==="$?"||u==="$~"||u==="&"){if(t===0)return l;t--}else u!=="/$"&&u!=="/&"||t++}l=l.previousSibling}return null}function Ks(l,t,u){switch(t=Mn(u),l){case"html":if(l=t.documentElement,!l)throw Error(o(452));return l;case"head":if(l=t.head,!l)throw Error(o(453));return l;case"body":if(l=t.body,!l)throw Error(o(454));return l;default:throw Error(o(451))}}function me(l){for(var t=l.attributes;t.length;)l.removeAttributeNode(t[0]);Fn(l)}var St=new Map,Js=new Set;function Dn(l){return typeof l.getRootNode=="function"?l.getRootNode():l.nodeType===9?l:l.ownerDocument}var Wt=A.d;A.d={f:_m,r:Om,D:Mm,C:Dm,L:Um,m:pm,X:Hm,S:Nm,M:Rm};function _m(){var l=Wt.f(),t=bn();return l||t}function Om(l){var t=Lu(l);t!==null&&t.tag===5&&t.type==="form"?s1(t):Wt.r(l)}var Ea=typeof document>"u"?null:document;function ws(l,t,u){var a=Ea;if(a&&typeof t=="string"&&t){var e=st(t);e='link[rel="'+l+'"][href="'+e+'"]',typeof u=="string"&&(e+='[crossorigin="'+u+'"]'),Js.has(e)||(Js.add(e),l={rel:l,crossOrigin:u,href:t},a.querySelector(e)===null&&(t=a.createElement("link"),Yl(t,"link",l),pl(t),a.head.appendChild(t)))}}function Mm(l){Wt.D(l),ws("dns-prefetch",l,null)}function Dm(l,t){Wt.C(l,t),ws("preconnect",l,t)}function Um(l,t,u){Wt.L(l,t,u);var a=Ea;if(a&&l&&t){var e='link[rel="preload"][as="'+st(t)+'"]';t==="image"&&u&&u.imageSrcSet?(e+='[imagesrcset="'+st(u.imageSrcSet)+'"]',typeof u.imageSizes=="string"&&(e+='[imagesizes="'+st(u.imageSizes)+'"]')):e+='[href="'+st(l)+'"]';var n=e;switch(t){case"style":n=Aa(l);break;case"script":n=_a(l)}St.has(n)||(l=R({rel:"preload",href:t==="image"&&u&&u.imageSrcSet?void 0:l,as:t},u),St.set(n,l),a.querySelector(e)!==null||t==="style"&&a.querySelector(de(n))||t==="script"&&a.querySelector(he(n))||(t=a.createElement("link"),Yl(t,"link",l),pl(t),a.head.appendChild(t)))}}function pm(l,t){Wt.m(l,t);var u=Ea;if(u&&l){var a=t&&typeof t.as=="string"?t.as:"script",e='link[rel="modulepreload"][as="'+st(a)+'"][href="'+st(l)+'"]',n=e;switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":n=_a(l)}if(!St.has(n)&&(l=R({rel:"modulepreload",href:l},t),St.set(n,l),u.querySelector(e)===null)){switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(u.querySelector(he(n)))return}a=u.createElement("link"),Yl(a,"link",l),pl(a),u.head.appendChild(a)}}}function Nm(l,t,u){Wt.S(l,t,u);var a=Ea;if(a&&l){var e=Ku(a).hoistableStyles,n=Aa(l);t=t||"default";var f=e.get(n);if(!f){var c={loading:0,preload:null};if(f=a.querySelector(de(n)))c.loading=5;else{l=R({rel:"stylesheet",href:l,"data-precedence":t},u),(u=St.get(n))&&Fc(l,u);var i=f=a.createElement("link");pl(i),Yl(i,"link",l),i._p=new Promise(function(d,S){i.onload=d,i.onerror=S}),i.addEventListener("load",function(){c.loading|=1}),i.addEventListener("error",function(){c.loading|=2}),c.loading|=4,Un(f,t,a)}f={type:"stylesheet",instance:f,count:1,state:c},e.set(n,f)}}}function Hm(l,t){Wt.X(l,t);var u=Ea;if(u&&l){var a=Ku(u).hoistableScripts,e=_a(l),n=a.get(e);n||(n=u.querySelector(he(e)),n||(l=R({src:l,async:!0},t),(t=St.get(e))&&kc(l,t),n=u.createElement("script"),pl(n),Yl(n,"link",l),u.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},a.set(e,n))}}function Rm(l,t){Wt.M(l,t);var u=Ea;if(u&&l){var a=Ku(u).hoistableScripts,e=_a(l),n=a.get(e);n||(n=u.querySelector(he(e)),n||(l=R({src:l,async:!0,type:"module"},t),(t=St.get(e))&&kc(l,t),n=u.createElement("script"),pl(n),Yl(n,"link",l),u.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},a.set(e,n))}}function Ws(l,t,u,a){var e=(e=x.current)?Dn(e):null;if(!e)throw Error(o(446));switch(l){case"meta":case"title":return null;case"style":return typeof u.precedence=="string"&&typeof u.href=="string"?(t=Aa(u.href),u=Ku(e).hoistableStyles,a=u.get(t),a||(a={type:"style",instance:null,count:0,state:null},u.set(t,a)),a):{type:"void",instance:null,count:0,state:null};case"link":if(u.rel==="stylesheet"&&typeof u.href=="string"&&typeof u.precedence=="string"){l=Aa(u.href);var n=Ku(e).hoistableStyles,f=n.get(l);if(f||(e=e.ownerDocument||e,f={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},n.set(l,f),(n=e.querySelector(de(l)))&&!n._p&&(f.instance=n,f.state.loading=5),St.has(l)||(u={rel:"preload",as:"style",href:u.href,crossOrigin:u.crossOrigin,integrity:u.integrity,media:u.media,hrefLang:u.hrefLang,referrerPolicy:u.referrerPolicy},St.set(l,u),n||qm(e,l,u,f.state))),t&&a===null)throw Error(o(528,""));return f}if(t&&a!==null)throw Error(o(529,""));return null;case"script":return t=u.async,u=u.src,typeof u=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=_a(u),u=Ku(e).hoistableScripts,a=u.get(t),a||(a={type:"script",instance:null,count:0,state:null},u.set(t,a)),a):{type:"void",instance:null,count:0,state:null};default:throw Error(o(444,l))}}function Aa(l){return'href="'+st(l)+'"'}function de(l){return'link[rel="stylesheet"]['+l+"]"}function $s(l){return R({},l,{"data-precedence":l.precedence,precedence:null})}function qm(l,t,u,a){l.querySelector('link[rel="preload"][as="style"]['+t+"]")?a.loading=1:(t=l.createElement("link"),a.preload=t,t.addEventListener("load",function(){return a.loading|=1}),t.addEventListener("error",function(){return a.loading|=2}),Yl(t,"link",u),pl(t),l.head.appendChild(t))}function _a(l){return'[src="'+st(l)+'"]'}function he(l){return"script[async]"+l}function Fs(l,t,u){if(t.count++,t.instance===null)switch(t.type){case"style":var a=l.querySelector('style[data-href~="'+st(u.href)+'"]');if(a)return t.instance=a,pl(a),a;var e=R({},u,{"data-href":u.href,"data-precedence":u.precedence,href:null,precedence:null});return a=(l.ownerDocument||l).createElement("style"),pl(a),Yl(a,"style",e),Un(a,u.precedence,l),t.instance=a;case"stylesheet":e=Aa(u.href);var n=l.querySelector(de(e));if(n)return t.state.loading|=4,t.instance=n,pl(n),n;a=$s(u),(e=St.get(e))&&Fc(a,e),n=(l.ownerDocument||l).createElement("link"),pl(n);var f=n;return f._p=new Promise(function(c,i){f.onload=c,f.onerror=i}),Yl(n,"link",a),t.state.loading|=4,Un(n,u.precedence,l),t.instance=n;case"script":return n=_a(u.src),(e=l.querySelector(he(n)))?(t.instance=e,pl(e),e):(a=u,(e=St.get(n))&&(a=R({},u),kc(a,e)),l=l.ownerDocument||l,e=l.createElement("script"),pl(e),Yl(e,"link",a),l.head.appendChild(e),t.instance=e);case"void":return null;default:throw Error(o(443,t.type))}else t.type==="stylesheet"&&(t.state.loading&4)===0&&(a=t.instance,t.state.loading|=4,Un(a,u.precedence,l));return t.instance}function Un(l,t,u){for(var a=u.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),e=a.length?a[a.length-1]:null,n=e,f=0;f<a.length;f++){var c=a[f];if(c.dataset.precedence===t)n=c;else if(n!==e)break}n?n.parentNode.insertBefore(l,n.nextSibling):(t=u.nodeType===9?u.head:u,t.insertBefore(l,t.firstChild))}function Fc(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.title==null&&(l.title=t.title)}function kc(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.integrity==null&&(l.integrity=t.integrity)}var pn=null;function ks(l,t,u){if(pn===null){var a=new Map,e=pn=new Map;e.set(u,a)}else e=pn,a=e.get(u),a||(a=new Map,e.set(u,a));if(a.has(l))return a;for(a.set(l,null),u=u.getElementsByTagName(l),e=0;e<u.length;e++){var n=u[e];if(!(n[Na]||n[Rl]||l==="link"&&n.getAttribute("rel")==="stylesheet")&&n.namespaceURI!=="http://www.w3.org/2000/svg"){var f=n.getAttribute(t)||"";f=l+f;var c=a.get(f);c?c.push(n):a.set(f,[n])}}return a}function Is(l,t,u){l=l.ownerDocument||l,l.head.insertBefore(u,t==="title"?l.querySelector("head > title"):null)}function Cm(l,t,u){if(u===1||t.itemProp!=null)return!1;switch(l){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return l=t.disabled,typeof t.precedence=="string"&&l==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function Ps(l){return!(l.type==="stylesheet"&&(l.state.loading&3)===0)}function Bm(l,t,u,a){if(u.type==="stylesheet"&&(typeof a.media!="string"||matchMedia(a.media).matches!==!1)&&(u.state.loading&4)===0){if(u.instance===null){var e=Aa(a.href),n=t.querySelector(de(e));if(n){t=n._p,t!==null&&typeof t=="object"&&typeof t.then=="function"&&(l.count++,l=Nn.bind(l),t.then(l,l)),u.state.loading|=4,u.instance=n,pl(n);return}n=t.ownerDocument||t,a=$s(a),(e=St.get(e))&&Fc(a,e),n=n.createElement("link"),pl(n);var f=n;f._p=new Promise(function(c,i){f.onload=c,f.onerror=i}),Yl(n,"link",a),u.instance=n}l.stylesheets===null&&(l.stylesheets=new Map),l.stylesheets.set(u,t),(t=u.state.preload)&&(u.state.loading&3)===0&&(l.count++,u=Nn.bind(l),t.addEventListener("load",u),t.addEventListener("error",u))}}var Ic=0;function Ym(l,t){return l.stylesheets&&l.count===0&&Rn(l,l.stylesheets),0<l.count||0<l.imgCount?function(u){var a=setTimeout(function(){if(l.stylesheets&&Rn(l,l.stylesheets),l.unsuspend){var n=l.unsuspend;l.unsuspend=null,n()}},6e4+t);0<l.imgBytes&&Ic===0&&(Ic=62500*gm());var e=setTimeout(function(){if(l.waitingForImages=!1,l.count===0&&(l.stylesheets&&Rn(l,l.stylesheets),l.unsuspend)){var n=l.unsuspend;l.unsuspend=null,n()}},(l.imgBytes>Ic?50:800)+t);return l.unsuspend=u,function(){l.unsuspend=null,clearTimeout(a),clearTimeout(e)}}:null}function Nn(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)Rn(this,this.stylesheets);else if(this.unsuspend){var l=this.unsuspend;this.unsuspend=null,l()}}}var Hn=null;function Rn(l,t){l.stylesheets=null,l.unsuspend!==null&&(l.count++,Hn=new Map,t.forEach(jm,l),Hn=null,Nn.call(l))}function jm(l,t){if(!(t.state.loading&4)){var u=Hn.get(l);if(u)var a=u.get(null);else{u=new Map,Hn.set(l,u);for(var e=l.querySelectorAll("link[data-precedence],style[data-precedence]"),n=0;n<e.length;n++){var f=e[n];(f.nodeName==="LINK"||f.getAttribute("media")!=="not all")&&(u.set(f.dataset.precedence,f),a=f)}a&&u.set(null,a)}e=t.instance,f=e.getAttribute("data-precedence"),n=u.get(f)||a,n===a&&u.set(null,e),u.set(f,e),this.count++,a=Nn.bind(this),e.addEventListener("load",a),e.addEventListener("error",a),n?n.parentNode.insertBefore(e,n.nextSibling):(l=l.nodeType===9?l.head:l,l.insertBefore(e,l.firstChild)),t.state.loading|=4}}var oe={$$typeof:jl,Provider:null,Consumer:null,_currentValue:q,_currentValue2:q,_threadCount:0};function Gm(l,t,u,a,e,n,f,c,i){this.tag=1,this.containerInfo=l,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Jn(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Jn(0),this.hiddenUpdates=Jn(null),this.identifierPrefix=a,this.onUncaughtError=e,this.onCaughtError=n,this.onRecoverableError=f,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=i,this.incompleteTransitions=new Map}function lv(l,t,u,a,e,n,f,c,i,d,S,r){return l=new Gm(l,t,u,f,i,d,S,r,c),t=1,n===!0&&(t|=24),n=tt(3,null,null,t),l.current=n,n.stateNode=l,t=Hf(),t.refCount++,l.pooledCache=t,t.refCount++,n.memoizedState={element:a,isDehydrated:u,cache:t},Bf(n),l}function tv(l){return l?(l=ta,l):ta}function uv(l,t,u,a,e,n){e=tv(e),a.context===null?a.context=e:a.pendingContext=e,a=au(t),a.payload={element:u},n=n===void 0?null:n,n!==null&&(a.callback=n),u=eu(l,a,t),u!==null&&(Fl(u,l,t),wa(u,l,t))}function av(l,t){if(l=l.memoizedState,l!==null&&l.dehydrated!==null){var u=l.retryLane;l.retryLane=u!==0&&u<t?u:t}}function Pc(l,t){av(l,t),(l=l.alternate)&&av(l,t)}function ev(l){if(l.tag===13||l.tag===31){var t=Uu(l,67108864);t!==null&&Fl(t,l,67108864),Pc(l,67108864)}}function nv(l){if(l.tag===13||l.tag===31){var t=ft();t=wn(t);var u=Uu(l,t);u!==null&&Fl(u,l,t),Pc(l,t)}}var qn=!0;function xm(l,t,u,a){var e=b.T;b.T=null;var n=A.p;try{A.p=2,li(l,t,u,a)}finally{A.p=n,b.T=e}}function Xm(l,t,u,a){var e=b.T;b.T=null;var n=A.p;try{A.p=8,li(l,t,u,a)}finally{A.p=n,b.T=e}}function li(l,t,u,a){if(qn){var e=ti(a);if(e===null)Xc(l,t,a,Cn,u),cv(l,a);else if(Zm(e,l,t,u,a))a.stopPropagation();else if(cv(l,a),t&4&&-1<Qm.indexOf(l)){for(;e!==null;){var n=Lu(e);if(n!==null)switch(n.tag){case 3:if(n=n.stateNode,n.current.memoizedState.isDehydrated){var f=Au(n.pendingLanes);if(f!==0){var c=n;for(c.pendingLanes|=2,c.entangledLanes|=2;f;){var i=1<<31-Pl(f);c.entanglements[1]|=i,f&=~i}pt(n),(I&6)===0&&(gn=kl()+500,se(0))}}break;case 31:case 13:c=Uu(n,2),c!==null&&Fl(c,n,2),bn(),Pc(n,2)}if(n=ti(a),n===null&&Xc(l,t,a,Cn,u),n===e)break;e=n}e!==null&&a.stopPropagation()}else Xc(l,t,a,null,u)}}function ti(l){return l=uf(l),ui(l)}var Cn=null;function ui(l){if(Cn=null,l=Vu(l),l!==null){var t=w(l);if(t===null)l=null;else{var u=t.tag;if(u===13){if(l=ml(t),l!==null)return l;l=null}else if(u===31){if(l=Ol(t),l!==null)return l;l=null}else if(u===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;l=null}else t!==l&&(l=null)}}return Cn=l,null}function fv(l){switch(l){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Mv()){case hi:return 2;case oi:return 8;case Ee:case Dv:return 32;case gi:return 268435456;default:return 32}default:return 32}}var ai=!1,ou=null,gu=null,Su=null,ge=new Map,Se=new Map,bu=[],Qm="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function cv(l,t){switch(l){case"focusin":case"focusout":ou=null;break;case"dragenter":case"dragleave":gu=null;break;case"mouseover":case"mouseout":Su=null;break;case"pointerover":case"pointerout":ge.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":Se.delete(t.pointerId)}}function be(l,t,u,a,e,n){return l===null||l.nativeEvent!==n?(l={blockedOn:t,domEventName:u,eventSystemFlags:a,nativeEvent:n,targetContainers:[e]},t!==null&&(t=Lu(t),t!==null&&ev(t)),l):(l.eventSystemFlags|=a,t=l.targetContainers,e!==null&&t.indexOf(e)===-1&&t.push(e),l)}function Zm(l,t,u,a,e){switch(t){case"focusin":return ou=be(ou,l,t,u,a,e),!0;case"dragenter":return gu=be(gu,l,t,u,a,e),!0;case"mouseover":return Su=be(Su,l,t,u,a,e),!0;case"pointerover":var n=e.pointerId;return ge.set(n,be(ge.get(n)||null,l,t,u,a,e)),!0;case"gotpointercapture":return n=e.pointerId,Se.set(n,be(Se.get(n)||null,l,t,u,a,e)),!0}return!1}function iv(l){var t=Vu(l.target);if(t!==null){var u=w(t);if(u!==null){if(t=u.tag,t===13){if(t=ml(u),t!==null){l.blockedOn=t,Ei(l.priority,function(){nv(u)});return}}else if(t===31){if(t=Ol(u),t!==null){l.blockedOn=t,Ei(l.priority,function(){nv(u)});return}}else if(t===3&&u.stateNode.current.memoizedState.isDehydrated){l.blockedOn=u.tag===3?u.stateNode.containerInfo:null;return}}}l.blockedOn=null}function Bn(l){if(l.blockedOn!==null)return!1;for(var t=l.targetContainers;0<t.length;){var u=ti(l.nativeEvent);if(u===null){u=l.nativeEvent;var a=new u.constructor(u.type,u);tf=a,u.target.dispatchEvent(a),tf=null}else return t=Lu(u),t!==null&&ev(t),l.blockedOn=u,!1;t.shift()}return!0}function sv(l,t,u){Bn(l)&&u.delete(t)}function Vm(){ai=!1,ou!==null&&Bn(ou)&&(ou=null),gu!==null&&Bn(gu)&&(gu=null),Su!==null&&Bn(Su)&&(Su=null),ge.forEach(sv),Se.forEach(sv)}function Yn(l,t){l.blockedOn===t&&(l.blockedOn=null,ai||(ai=!0,M.unstable_scheduleCallback(M.unstable_NormalPriority,Vm)))}var jn=null;function vv(l){jn!==l&&(jn=l,M.unstable_scheduleCallback(M.unstable_NormalPriority,function(){jn===l&&(jn=null);for(var t=0;t<l.length;t+=3){var u=l[t],a=l[t+1],e=l[t+2];if(typeof a!="function"){if(ui(a||u)===null)continue;break}var n=Lu(u);n!==null&&(l.splice(t,3),t-=3,tc(n,{pending:!0,data:e,method:u.method,action:a},a,e))}}))}function Oa(l){function t(i){return Yn(i,l)}ou!==null&&Yn(ou,l),gu!==null&&Yn(gu,l),Su!==null&&Yn(Su,l),ge.forEach(t),Se.forEach(t);for(var u=0;u<bu.length;u++){var a=bu[u];a.blockedOn===l&&(a.blockedOn=null)}for(;0<bu.length&&(u=bu[0],u.blockedOn===null);)iv(u),u.blockedOn===null&&bu.shift();if(u=(l.ownerDocument||l).$$reactFormReplay,u!=null)for(a=0;a<u.length;a+=3){var e=u[a],n=u[a+1],f=e[Ll]||null;if(typeof n=="function")f||vv(u);else if(f){var c=null;if(n&&n.hasAttribute("formAction")){if(e=n,f=n[Ll]||null)c=f.formAction;else if(ui(e)!==null)continue}else c=f.action;typeof c=="function"?u[a+1]=c:(u.splice(a,3),a-=3),vv(u)}}}function yv(){function l(n){n.canIntercept&&n.info==="react-transition"&&n.intercept({handler:function(){return new Promise(function(f){return e=f})},focusReset:"manual",scroll:"manual"})}function t(){e!==null&&(e(),e=null),a||setTimeout(u,20)}function u(){if(!a&&!navigation.transition){var n=navigation.currentEntry;n&&n.url!=null&&navigation.navigate(n.url,{state:n.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var a=!1,e=null;return navigation.addEventListener("navigate",l),navigation.addEventListener("navigatesuccess",t),navigation.addEventListener("navigateerror",t),setTimeout(u,100),function(){a=!0,navigation.removeEventListener("navigate",l),navigation.removeEventListener("navigatesuccess",t),navigation.removeEventListener("navigateerror",t),e!==null&&(e(),e=null)}}}function ei(l){this._internalRoot=l}Gn.prototype.render=ei.prototype.render=function(l){var t=this._internalRoot;if(t===null)throw Error(o(409));var u=t.current,a=ft();uv(u,a,l,t,null,null)},Gn.prototype.unmount=ei.prototype.unmount=function(){var l=this._internalRoot;if(l!==null){this._internalRoot=null;var t=l.containerInfo;uv(l.current,2,null,l,null,null),bn(),t[Zu]=null}};function Gn(l){this._internalRoot=l}Gn.prototype.unstable_scheduleHydration=function(l){if(l){var t=Ti();l={blockedOn:null,target:l,priority:t};for(var u=0;u<bu.length&&t!==0&&t<bu[u].priority;u++);bu.splice(u,0,l),u===0&&iv(l)}};var mv=yl.version;if(mv!=="19.2.0")throw Error(o(527,mv,"19.2.0"));A.findDOMNode=function(l){var t=l._reactInternals;if(t===void 0)throw typeof l.render=="function"?Error(o(188)):(l=Object.keys(l).join(","),Error(o(268,l)));return l=E(t),l=l!==null?$(l):null,l=l===null?null:l.stateNode,l};var Lm={bundleType:0,version:"19.2.0",rendererPackageName:"react-dom",currentDispatcherRef:b,reconcilerVersion:"19.2.0"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var xn=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!xn.isDisabled&&xn.supportsFiber)try{Da=xn.inject(Lm),Il=xn}catch{}}return re.createRoot=function(l,t){if(!j(l))throw Error(o(299));var u=!1,a="",e=z1,n=r1,f=T1;return t!=null&&(t.unstable_strictMode===!0&&(u=!0),t.identifierPrefix!==void 0&&(a=t.identifierPrefix),t.onUncaughtError!==void 0&&(e=t.onUncaughtError),t.onCaughtError!==void 0&&(n=t.onCaughtError),t.onRecoverableError!==void 0&&(f=t.onRecoverableError)),t=lv(l,1,!1,null,null,u,a,null,e,n,f,yv),l[Zu]=t.current,xc(l),new ei(t)},re.hydrateRoot=function(l,t,u){if(!j(l))throw Error(o(299));var a=!1,e="",n=z1,f=r1,c=T1,i=null;return u!=null&&(u.unstable_strictMode===!0&&(a=!0),u.identifierPrefix!==void 0&&(e=u.identifierPrefix),u.onUncaughtError!==void 0&&(n=u.onUncaughtError),u.onCaughtError!==void 0&&(f=u.onCaughtError),u.onRecoverableError!==void 0&&(c=u.onRecoverableError),u.formState!==void 0&&(i=u.formState)),t=lv(l,1,!0,t,u??null,a,e,i,n,f,c,yv),t.context=tv(null),u=t.current,a=ft(),a=wn(a),e=au(a),e.callback=null,eu(u,e,a),u=a,t.current.lanes=u,pa(t,u),pt(t),l[Zu]=t.current,xc(l),new Gn(t)},re.version="19.2.0",re}var Ev;function ld(){if(Ev)return ci.exports;Ev=1;function M(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(M)}catch(yl){console.error(yl)}}return M(),ci.exports=Pm(),ci.exports}var td=ld();function ud(){return J.jsxs("svg",{className:"h-12 w-12 bi bi-arrow-repeat animate-spin",fill:"currentColor",viewBox:"0 0 16 16",xmlns:"http://www.w3.org/2000/svg",children:[J.jsx("path",{d:"M11.534 7h3.932a.25.25 0 0 1 .192.41l-1.966 2.36a.25.25 0 0 1-.384 0l-1.966-2.36a.25.25 0 0 1 .192-.41zm-11 2h3.932a.25.25 0 0 0 .192-.41L2.692 6.23a.25.25 0 0 0-.384 0L.342 8.59A.25.25 0 0 0 .534 9z"}),J.jsx("path",{fillRule:"evenodd",d:"M8 3c-1.552 0-2.94.707-3.857 1.818a.5.5 0 1 1-.771-.636A6.002 6.002 0 0 1 13.917 7H12.9A5.002 5.002 0 0 0 8 3zM3.1 9a5.002 5.002 0 0 0 8.757 2.182.5.5 0 1 1 .771.636A6.002 6.002 0 0 1 2.083 9H3.1z"})]})}function ad(){const[M,yl]=ru.useState(""),[W,o]=ru.useState(8),[j,w]=ru.useState(2.5),[ml,Ol]=ru.useState(null),[p,E]=ru.useState(!1),$="http://127.0.0.1:8000",R=["a raccoon in a hat","a pig in a hat","a dog walking in a cyber city with joy"],il=async()=>{if(!M)return alert("Please enter a prompt");E(!0),Ol(null);const hl=new FormData;hl.append("prompt",M),hl.append("num_steps",W.toString()),hl.append("guidance",j.toString());try{const Et=await(await fetch(`${$}/generate`,{method:"POST",body:hl})).json();Ol(`data:image/png;base64,${Et.image}`)}catch(Ul){console.error(Ul),alert("Failed to generate image.")}finally{E(!1)}},[Ml,Hl]=ru.useState("light"),Dl=()=>{Hl(Ml==="light"?"dark":"light")};return ru.useEffect(()=>{document.body.className=Ml},[Ml]),J.jsxs("div",{className:"flex flex-col items-center",children:[J.jsx("nav",{className:"flex absolute top-3 right-3",children:J.jsx("div",{className:"flex-container",children:Ml=="light"?J.jsx("svg",{onClick:Dl,className:"w-5 h-5",fill:"currentColor",viewBox:"0 0 20 20",xmlns:"http://www.w3.org/2000/svg",children:J.jsx("path",{d:"M10 2a1 1 0 011 1v1a1 1 0 11-2 0V3a1 1 0 011-1zm4 8a4 4 0 11-8 0 4 4 0 018 0zm-.464 4.95l.707.707a1 1 0 001.414-1.414l-.707-.707a1 1 0 00-1.414 1.414zm2.12-10.607a1 1 0 010 1.414l-.706.707a1 1 0 11-1.414-1.414l.707-.707a1 1 0 011.414 0zM17 11a1 1 0 100-2h-1a1 1 0 100 2h1zm-7 4a1 1 0 011 1v1a1 1 0 11-2 0v-1a1 1 0 011-1zM5.05 6.464A1 1 0 106.465 5.05l-.708-.707a1 1 0 00-1.414 1.414l.707.707zm1.414 8.486l-.707.707a1 1 0 01-1.414-1.414l.707-.707a1 1 0 011.414 1.414zM4 11a1 1 0 100-2H3a1 1 0 000 2h1z"})}):J.jsx("svg",{onClick:Dl,className:"w-5 h-5",fill:"currentColor",viewBox:"0 0 20 20",xmlns:"http://www.w3.org/2000/svg",children:J.jsx("path",{d:"M17.293 13.293A8 8 0 016.707 2.707a8.001 8.001 0 1010.586 10.586z"})})})}),J.jsxs("div",{className:"w-full max-w-6xl rounded-2xl shadow-md p-6",children:[J.jsx("h1",{className:"text-l font-semibold text-center",children:"Image Generator"}),J.jsxs("div",{className:"grid grid-cols-1 md:grid-cols-2 gap-8",children:[J.jsxs("div",{className:"flex flex-col gap-5",children:[J.jsx("div",{children:J.jsx("textarea",{value:M,onChange:hl=>yl(hl.target.value),className:"w-full rounded-md p-2 focus:outline-none focus:ring-2 focus:ring-gray-300 bg-white",placeholder:"Enter your prompt...",rows:1})}),J.jsxs("div",{children:[J.jsx("label",{className:"block text-sm font-medium mb-2 text-left",children:"Sample Prompts"}),J.jsx("div",{className:"grid grid-cols-1 gap-2",children:R.map((hl,Ul)=>J.jsx("button",{onClick:()=>yl(hl),className:"text-left bg-gray-100 hover:bg-gray-200 rounded-md px-3 py-2 transition",children:hl},Ul))})]}),J.jsxs("div",{children:[J.jsxs("label",{className:"block text-sm font-medium mb-2 text-left",children:["Step: ",W]}),J.jsx("input",{type:"range",min:4,max:100,step:1,value:W,onChange:hl=>o(Number(hl.target.value)),className:"w-full accent-gray-600"})]}),J.jsxs("div",{children:[J.jsxs("label",{className:"block text-sm font-medium mb-2 text-left",children:["Scale: ",j.toFixed(1)]}),J.jsx("input",{type:"range",min:1,max:10,step:.1,value:j,onChange:hl=>w(Number(hl.target.value)),className:"w-full accent-gray-600"})]}),J.jsx("button",{onClick:il,disabled:p,className:`w-full py-2 mt-3 rounded-md font-semibold text-white ${p?"bg-gray-400 cursor-wait":"bg-gray-700 hover:bg-gray-800"}`,children:p?"Generating...":"Generate"})]}),J.jsx("div",{className:"flex justify-center items-center border rounded-lg",children:ml?J.jsx("img",{src:ml,alt:"Generated",className:"max-h-full rounded-md shadow"}):J.jsx("p",{className:"text-gray-500 italic",children:p?J.jsxs("div",{className:"grid grid-cols-1 grid-rows-1 place-items-center",children:["Generating image...",J.jsx(ud,{})]}):"Output image will appear here."})})]})]})]})}td.createRoot(document.getElementById("root")).render(J.jsx(ru.StrictMode,{children:J.jsx(ad,{})}));
